<?php
class OSF_Import {
	private $config, $path_rev, $homepage, $blogpage, $settings;

	public function __construct() {
		if ( is_admin() ) {
			$this->path_rev = trailingslashit( wp_upload_dir()['basedir'] ) . 'opal_rev_sliders_import/';
			add_action( 'after_setup_theme', array( $this, 'init' ) );
		}
	}

	public function init() {
		$this->init_hooks();
		add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
	}

	public function init_hooks() {
		add_action( 'osf_before_import_customizer', array( $this, 'reset_theme_mods' ) );
		if ( get_option( 'otf-oneclick-first-import', 'yes' ) === 'yes' ) {
			add_filter( 'pt-ocdi/import_files', array( $this, 'import_file_base' ) );
			add_action( 'pt-ocdi/after_import', array( $this, 'after_import_setup' ) );
			add_action( 'pt-ocdi/after_import', array( $this, 'after_import_setup_base' ), 20 );
		} else {
			add_filter( 'pt-ocdi/import_files', array( $this, 'import_files' ) );
			add_action( 'pt-ocdi/after_import', array( $this, 'after_import_setup' ) );
			add_filter( 'pt-ocdi/enable_grid_layout_import_popup_confirmation', '__return_false' );
			add_filter( 'otf-ocdi/reload_page', '__return_false' );
		}
	}

	public function import_file_base() {
		$this->init_data();
		$imports   = array();
		$import    = array(
			'import_file_name'  => 'Home 1',
			'local_import_file' => trailingslashit( LEXRIDER_CORE_PLUGIN_DIR ) . 'dummy-data/content.xml',
			'import_notice'     => 'Basic import includes default version from our demo and a few products, blog posts and portfolio projects. It is a required minimum to see how our theme built and to be able to import additional versions or pages.',
			'slug'              => '1',
			'customizer'        => esc_url( 'http://source.wpopal.com/lexrider/dummy_data/lexrider/customizer.json' ),
			'elementor'         => esc_url( 'http://source.wpopal.com/lexrider/dummy_data/lexrider/elementor.json' ),
			'settings'          => esc_url( 'http://source.wpopal.com/lexrider/dummy_data/lexrider/settings.json' ),
		);
		$imports[] = $import;

		return $imports;
	}

	public function import_files() {
		$this->init_data();
		$imports = array();
		foreach ( $this->config as $key => $item ) {
			$import = array(
				'import_file_name'         => $item['name'],
				'import_preview_image_url' => $item['screenshot'],
				'slug'                     => $key,
				'settings'                 => esc_url( 'http://source.wpopal.com/lexrider/dummy_data/lexrider/settings.json' ),
			);
			if ( isset( $item['xml'] ) ) {
				$import['import_file_url'] = $item['xml'];
			}

			$imports[] = $import;
		}

		return $imports;
	}

	private function init_data() {
		$this->config   = $this->get_remote_json( trailingslashit( LEXRIDER_CORE_PLUGIN_URL ) . 'dummy-data/config.json', true );
		$this->blogpage = lexrider_get_page_by_title( 'Blog' );
	}

	public function after_import_setup_base( $selected_import ) {
		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', ( ( $this->homepage instanceof WP_Post ) ? $this->homepage->ID : 0 ) );
		update_option( 'page_for_posts', ( ( $this->blogpage instanceof WP_Post ) ? $this->blogpage->ID : 0 ) );
		update_option( 'otf-oneclick-first-import', 'no' );

		// Setup Customizer
		$this->reset_theme_mods();
		$thememods = $this->get_remote_json( $selected_import['customizer'], true );
		foreach ( $thememods as $mod => $value ) {
			set_theme_mod( $mod, $value );
		}

		// Setup Elementor

		$elementor = $this->get_remote_json( $selected_import['elementor'], true );
		if ( osf_is_elementor_activated() ) {

			foreach ( $elementor as $key => $value ) {
				update_option( $key, $value );
			}
		}
		$this->setup_elementor_global();
		$this->settings = $this->get_remote_json( $selected_import['settings'], true );

		if(function_exists('tribe_update_option')){
			tribe_update_option('views_v2_enabled', false);
		}

		// Breadcrumb
		update_option( 'bcn_options', $this->settings['breadcrumb'] );

		// Update Logo
		set_theme_mod( 'custom_logo', 4152 );

		// Mailchimp
		$mailchimp = lexrider_get_page_by_title( 'Opal MailChimp', OBJECT, 'mc4wp-form' );
		if ( $mailchimp ) {
			update_option( 'mc4wp_default_form_id', $mailchimp->ID );
		}
	}

	private function fixelementor_home( $slug ) {
		$datas = $this->get_data_elementor();
		$post  = get_page_by_path( $slug );
		if ( $post ) {
			update_post_meta( $post->ID, '_elementor_data', $datas[ $slug ] );
		}
	}

	public function after_import_setup( $selected_import ) {
		if ( isset( $this->config[ $selected_import['slug'] ] ) ) {

			$this->homepage = lexrider_get_page_by_title( $selected_import['import_file_name'] );

			$setup = $this->config[ $selected_import['slug'] ];
			// REVSLIDER
			if ( $sliders = $setup['rev_sliders'] ) {
				if ( class_exists( 'RevSliderAdmin' ) ) {
					if ( ! file_exists( $this->path_rev ) ) {
						wp_mkdir_p( $this->path_rev );
					}
					foreach ( $sliders as $slider ) {
						$this->add_revslider( $slider );
					}
				}
			}

			$this->settings  = $this->get_remote_json( $selected_import['settings'], true );


			// Setup Home page
			update_option( 'page_on_front', ( ( $this->homepage instanceof WP_Post ) ? $this->homepage->ID : 0 ) );

			$this->fixelementor_home( 'home-' . $selected_import['slug'] );

		}
		set_theme_mod( 'osf_dev_mode', false );
	}

	private function add_revslider( $slider ) {
		$dest_rev = $this->path_rev . basename( $slider );
		if ( ! file_exists( $dest_rev ) ) {
			file_put_contents( $dest_rev, fopen( $slider, 'r' ) );
			$_FILES['import_file']['error']    = UPLOAD_ERR_OK;
			$_FILES['import_file']['tmp_name'] = $dest_rev;

			$revslider = new RevSlider();
			$revslider->importSliderFromPost( true, 'none' );
		}
	}

	/**
	 * @param $link
	 *
	 * @return object|boolean
	 */
	private function get_remote_json( $link, $assoc = false ) {
		$content = wp_remote_get( $link );
		if ( $content instanceof WP_Error ) {
			return false;
		}
		$arr = json_decode( $content['body'], $assoc );

		return $arr;
	}

	public function reset_theme_mods() {
		$mods = json_decode( file_get_contents( trailingslashit( LEXRIDER_CORE_PLUGIN_DIR ) . 'reset-theme-mods.json' ) );
		foreach ( $mods as $mod ) {
			remove_theme_mod( $mod );
		}
	}

	public function setup_elementor_global() {
		$json
			= '
				{
				    "default_generic_fonts": "Sans-serif",
				    "global_image_lightbox": "yes",
				    "container_width": {
				        "unit": "px",
				        "size": "1290"
				    },
				    "stretched_section_container": "body",
				    "space_between_widgets": {
				        "unit": "px",
				        "size": ""
				    },
				    "viewport_md": "",
				    "viewport_lg": "",
				    "system_colors": [
				        {
				            "_id": "primary",
				            "title": "Primary",
				            "color": "#E81938"
				        },
				        {
				            "_id": "secondary",
				            "title": "Secondary",
				            "color": "#131313"
				        },
				        {
				            "_id": "text",
				            "title": "Text",
				            "color": "#8E8E8E"
				        },
				        {
				            "_id": "accent",
				            "title": "Accent",
				            "color": "#8E8E8E"
				        }
				    ],
				    "custom_colors": [
				        {
				            "_id": "e9cf061",
				            "title": "Saved Color #1",
				            "color": "#6EC1E4"
				        },
				        {
				            "_id": "120abf7b",
				            "title": "Saved Color #2",
				            "color": "#54595F"
				        },
				        {
				            "_id": "494daa40",
				            "title": "Saved Color #3",
				            "color": "#777777"
				        },
				        {
				            "_id": "ad553bc",
				            "title": "Saved Color #5",
				            "color": "#4054B2"
				        },
				        {
				            "_id": "1f983409",
				            "title": "Saved Color #7",
				            "color": "#000000"
				        },
				        {
				            "_id": "3bcfb16b",
				            "title": "Saved Color #8",
				            "color": "#FFF"
				        }
				    ],
				    "system_typography": [
				        {
				            "_id": "primary",
				            "title": "Primary Headline",
				            "typography_typography": "custom",
				            "typography_font_family": "Teko",
				            "typography_font_weight": "500"
				        },
				        {
				            "_id": "secondary",
				            "title": "Secondary Headline",
				            "typography_typography": "custom",
				            "typography_font_family": "Teko",
				            "typography_font_weight": "400"
				        },
				        {
				            "_id": "text",
				            "title": "Body Text",
				            "typography_typography": "custom",
				            "typography_font_family": "Noto Sans",
				            "typography_font_weight": "400"
				        },
				        {
				            "_id": "accent",
				            "title": "Accent Text",
				            "typography_typography": "custom",
				            "typography_font_family": "Noto Sans",
				            "typography_font_weight": "400"
				        }
				    ]
				}';

		$options = json_decode( $json, true );
		$id      = Elementor\Plugin::$instance->kits_manager->get_active_id();
		update_post_meta( $id, '_elementor_page_settings', $options );
	}

	private function get_data_elementor(){
        return json_decode('{"default-kit":null,"conatct":[{"id":"313872d","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"125","right":0,"bottom":"125","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"e82f526","elType":"column","settings":{"_column_size":50,"_inline_size":40},"elements":[{"id":"10d74d5","elType":"widget","settings":{"icon":"opal-icon-location","title_text":"head office","description_text":"44 Shirley Ave. West Chicago,<br>\nNew York, USA","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#2e2e2e","_animation":"opal-move-up","animation_duration":"fast","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"},{"id":"0b26367","elType":"widget","settings":{"icon":"opal-icon-user-headset","title_text":"call support","description_text":"8(800) 123 - 45 - 99<br>\n8(800) 123 - 45 - 66","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"title_typography_typography":"custom","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"description_typography_typography":"custom","description_typography_line_height":{"unit":"px","size":"","sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#2e2e2e","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"},{"id":"9a2749e","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_color":"#2e2e2e","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"padding":{"unit":"px","top":"10","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"3469c91","elType":"column","settings":{"_column_size":50,"_inline_size":63.953000000000002955857780762016773223876953125,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"cc40373","elType":"widget","settings":{"icon":"opal-icon-email","title_text":"Email us","description_text":"contact@example.com<br>\nsupport@example.com","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"title_typography_typography":"custom","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"description_typography_typography":"custom","description_typography_line_height":{"unit":"px","size":"","sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_border_color":"#2e2e2e","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"0abf274","elType":"column","settings":{"_column_size":50,"_inline_size":36.046999999999997044142219237983226776123046875,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"88f1edc","elType":"widget","settings":{"title":"follow us","align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"header_size":"h3","align_tablet":"center","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"492136c","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"b3d40de","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"d7ab8f1","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-google-plus","_id":"905749e","link":{"url":"","is_external":"true","nofollow":""}}],"shape":"square","icon_color":"custom","icon_primary_color":"#000000","icon_secondary_color":"#ffffff","icon_size":{"unit":"px","size":18,"sizes":[]},"icon_padding":{"unit":"em","size":0.75,"sizes":[]},"icon_spacing":{"unit":"px","size":6,"sizes":[]},"hover_primary_color":"#e81938","hover_secondary_color":"#ffffff","_element_width":"auto","_element_vertical_align":"center","align":"left","align_mobile":"center","_element_width_tablet":"inherit","align_tablet":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":true}],"isInner":true},{"id":"1d63e60","elType":"widget","settings":{"address":"London Eye, London, United Kingdom","height":{"unit":"px","size":387,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"google_maps"}],"isInner":false},{"id":"9ef0e10","elType":"column","settings":{"_column_size":50,"_inline_size":60,"space_between_widgets":0,"background_background":"classic","background_color":"#131313","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"15","left":"15","isLinked":false}},"elements":[{"id":"5cb08ba","elType":"widget","settings":{"title":"Send us a message","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"0818777","elType":"widget","settings":{"editor":"<p>If you have any questions or need more information, please use the form below to send us a message.<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":15,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"text-editor"},{"id":"fb23c4e","elType":"widget","settings":{"form_name":"Contact form","cf_id":"4331","input_typography_line_height":{"unit":"px","size":"","sizes":[]},"border_input_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_input_color":"#323232","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200,"select_typography_text_transform":"none","label_typography_typography":"custom","label_typography_font_size":{"unit":"px","size":14,"sizes":[]},"label_typography_text_transform":"none","label_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"input_typography_font_size":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"opal-contactform7"}],"isInner":false}],"isInner":false}],"our-members":[{"id":"8826785","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"140","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"2f89221","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"5e5702e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-newsletter.jpg","id":500},"image_size":"full","_animation":"opal-move-up","animation_duration":"fast","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"1e31f7f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"95","isLinked":false},"_inline_size_tablet":100,"space_between_widgets":20,"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"fe84117","elType":"widget","settings":{"title":"The Hierarchy of\na Motorcycle Club","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"5d0048e","elType":"widget","settings":{"editor":"<p>A motorcycle club assumes a serious hierarchy in leadership just like any other organization. At the top is the president who is the head of the executive committee and the MC CEO.\u00a0<\/p>","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"typography_typography":"custom","typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"1b757f5","elType":"widget","settings":{"title":"The treasurer is in charge of the motorcycle club funds. He is also the custodian of the ","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"3","isLinked":false},"_border_color":"#e81938","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200,"typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"1c369b5","elType":"widget","settings":{"editor":"<p>We have sergeant-at-arms whose job is to ensure that the club\u2019s bylaws are adhered to. The road captain is the boss in the road runs and everything related to the road.<\/p>","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250,"typography_typography":"custom","typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"f445677","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"margin":{"unit":"px","top":"140","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"40","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"e525fc0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"77bd32c","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false}},"elements":[{"id":"6c3abdf","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"1885340","elType":"widget","settings":{"title":"Meet our<br>\nCrew members","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"our team","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase","show_decor":"yes","decor_spacing":{"unit":"px","size":0,"sizes":[]},"align":"left","typography_font_size_tablet":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","sub_title_spacing_mobile":{"unit":"px","size":11,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true},{"id":"f282710","elType":"section","settings":{"layout":"full_width","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"68d5870","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0},"elements":[{"id":"bfc4b04","elType":"widget","settings":{"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase","team_items":[{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"0abfeae"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"eaf77c9"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"ron carter","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team2.jpg","id":3952},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"15b570c"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"alex carter","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team3.jpg","id":3953},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"e9e809b"}],"columns":"4","gutter_tablet":{"unit":"px","size":30,"sizes":[]},"team_align_tablet":"flex-start","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"team_align":"flex-start","team_content_wrapper_align_tablet":"left","name_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"job_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]}},"elements":[],"widgetType":"opal-team-box"}],"isInner":true}],"isInner":true},{"id":"bd308cd","elType":"section","settings":{"layout":"full_width","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"cb02459","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0},"elements":[{"id":"a9fb89b","elType":"widget","settings":{"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase","team_items":[{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"will stone","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team5.jpg","id":3955},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"0abfeae"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"alan smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team6.jpg","id":3956},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"eaf77c9"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"jack brow","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"15b570c"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"view":"traditional","name":"leo m.","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team8.jpg","id":3958},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"e9e809b"}],"columns":"4","gutter_tablet":{"unit":"px","size":30,"sizes":[]},"team_align_tablet":"flex-start","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200,"name_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"job_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]}},"elements":[],"widgetType":"opal-team-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"b470b93","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"content_position":"middle","padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"e824b3f","elType":"column","settings":{"_column_size":50,"_inline_size":49.844999999999998863131622783839702606201171875,"space_between_widgets":0,"background_background":"classic","background_position":"top left","background_repeat":"no-repeat","background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(0,0,0,0.4)","_inline_size_tablet":100,"background_size":"cover","css_classes":"overflow-hidden"},"elements":[{"id":"67e9a81","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_img.jpg","id":3842},"image_size":"custom","image_custom_dimension":{"width":"645","height":"760"},"align":"left","align_tablet":"center","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"background_hover_transition":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]},"hover_animation":"grow","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"2c5557b","elType":"column","settings":{"_column_size":50,"_inline_size":50.155000000000001136868377216160297393798828125,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"1b43b05","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"px","size":-130},"osf_section_parallax_position_v":{"unit":"px","size":-110},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"8627540"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":90},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"5106c33"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":51},"osf_section_parallax_position_v":{"unit":"%","size":80},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"810a9ee"}],"padding":{"unit":"px","top":"60","right":"100","bottom":"60","left":"100","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[{"id":"a557712","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"b61f261","elType":"widget","settings":{"title":"WHAT our members SAY","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"TESTIMONIALS","typography_font_size_tablet":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]},"sub_title_color":"#000000","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","align":"left","align_tablet":"center"},"elements":[],"widgetType":"heading"},{"id":"0cb2a03","elType":"widget","settings":{"testimonials":[{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"testimonial_name":"Alex Bold","testimonial_job":"member","due_date":"","_id":"e5c390b"},{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team6.jpg","id":3956},"testimonial_name":"John Doe","testimonial_job":"member","due_date":"","_id":"3587f8f"}],"testimonial_image_size":"custom","testimonial_image_custom_dimension":{"width":"60","height":"60"},"testimonial_alignment":"left","wrapper_bgcolor":"#ffffff","wrapper_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"wrapper_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_content_color":"#000000","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":24,"sizes":[]},"content_typography_font_style":"italic","content_typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"enable_carousel":"yes","navigation":"arrows","_animation":"opal-move-up","animation_duration":"fast","content_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"content_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase","content_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"name_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"name_typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"job_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"c53ac05","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_calltoaction_about.jpg","id":5122},"background_overlay_opacity":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_position_mobile":"bottom left","background_size_mobile":"cover","background_bg_width_mobile":{"unit":"%","size":400,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_color":"#000000"},"elements":[{"id":"a80e525","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"fb16c52","elType":"widget","settings":{"title":"Come Ride with Us!","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"68d04a7","elType":"widget","settings":{"title":"Become a Part of<br>\nOur Family","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":42,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height":{"unit":"px","size":80,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"a61d726","elType":"widget","settings":{"text":"Contact us","align":"center","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"our-mission":[{"id":"f6e9667","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"125","left":0,"isLinked":false},"stretch_section":"section-stretched","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"60","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a401098","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"872fc9d","elType":"widget","settings":{"title":"we kept what we<br>\nloved about the bike","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"70","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"ad698b0","elType":"widget","settings":{"text":"explore our rides","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"c6dcfe9","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a9afae2","elType":"widget","settings":{"editor":"The Club Helping Veterans is a diverse group of individuals, with one thing in common: We all have a tremendous love and respect for our country and for those who risk their lives every day, whether on American soil or abroad, in securing our nation\'s freedoms and liberties. We encourage those who share this respect to join us in support of all those who have served and still are serving.<br><br>\nWe are a non-profit corporation. Our primary mission is to provide financial assistance to Heroes and their families in their time of need when other resources are not available in a timely manner.","_margin_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":350},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"4f7e068","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"stretch_section":"section-stretched","margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"custom_height":{"unit":"px","size":500,"sizes":[]}},"elements":[{"id":"8ccedee","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_position":"center center","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#131313","background_hover_transition":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"animation_tablet":"opal-move-up"},"elements":[{"id":"15fa47a","elType":"widget","settings":{"icon":"","title_text":"01","sub_title_text":"Purpose ","description_text":"To make motorcycling communities, as well as the public at large, aware that people are serious motorcyclist and deserve such recognition.   ","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"header_position_tablet":"flex-start","spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false},{"id":"26e5969","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_position":"bottom center","background_hover_background":"classic","background_hover_color":"#131313","animation_tablet":"opal-move-up","animation_delay":150},"elements":[{"id":"9d9bfe1","elType":"widget","settings":{"icon":"","title_text":"02","sub_title_text":"Unity","description_text":"To unite with various organizations for the purpose of supporting charitable functions, and the improved communities such deserve.   ","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false},{"id":"5ff023c","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_hover_background":"classic","background_hover_color":"#131313","animation_tablet":"opal-move-up","animation_delay":300},"elements":[{"id":"dae709c","elType":"widget","settings":{"icon":"","title_text":"03","sub_title_text":"Leadership","description_text":"To lead our youth towards a positive direction such that life may be successful without drugs and violence such recognition. ","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false}],"isInner":false},{"id":"a843359","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"30","content_delay_time":"0.50","stretch_section":"section-stretched","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"840379a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_hover_background":"classic","background_hover_color":"#131313","animation_tablet":"opal-move-up"},"elements":[{"id":"4ba864c","elType":"widget","settings":{"icon":"","title_text":"04","sub_title_text":"Education","description_text":"To make available, information on safe courses and to provide assistance to novice riders, through mentoring of good sportsmanship and motorcycle.   ","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false},{"id":"f265c27","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_hover_background":"classic","background_hover_color":"#131313","animation_tablet":"opal-move-up","animation_delay":150},"elements":[{"id":"7f0c1f8","elType":"widget","settings":{"icon":"","title_text":"05","sub_title_text":"Encouragement","description_text":"To show everyone, that they have limitless potential and can accomplish any goal or dream of good sportsmanship and motorcycle responsibility. ","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false},{"id":"e54d12d","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"background_color":"#ffffff","background_hover_background":"classic","background_hover_color":"#131313","animation_tablet":"opal-move-up","animation_delay":300},"elements":[{"id":"25171f7","elType":"widget","settings":{"icon":"","title_text":"06","sub_title_text":"Recreation","description_text":"To enhance the sheer enjoyment of motorcycling while maintaining the integrity of good sportsmanship and motorcycle responsibility.","title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_font_weight":"500","title_typography_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#e81938","subtitle_typography_typography":"custom","subtitle_typography_font_family":"Teko","subtitle_typography_font_size":{"unit":"px","size":30,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":60,"sizes":[]},"subtitle_color":"#000000","spacing_title":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"description_spacing":{"unit":"px","size":10,"sizes":[]},"spacing_title_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"spacing_subtitle_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_color_hover":"#ffffff","wrapper_padding":{"unit":"px","top":"60","right":"40","bottom":"70","left":"40","isLinked":false},"wrapper_padding_tablet":{"unit":"px","top":"30","right":"20","bottom":"30","left":"20","isLinked":false},"subtitle_color_hover":"#ffffff"},"elements":[],"widgetType":"featured-box"}],"isInner":false}],"isInner":false},{"id":"5aaeb0a","elType":"section","settings":{"content_delay_time":"0.50","margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1330,"sizes":[]},"gap":"no","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"60","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"5","bottom":"0","left":"5","isLinked":false}},"elements":[{"id":"32bac84","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e437ab4","elType":"widget","settings":{"title":"our rules","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"Requirements","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"b579a98","elType":"widget","settings":{"tabs":[{"tab_icon":"","tab_title":"General rules","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"1708631","tab_template":"3729"},{"tab_icon":"","tab_title":"Vehicles","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"b1999a2","tab_template":"5065"},{"tab_icon":"","tab_title":"Membership","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"5a8983f","tab_template":"5068"}],"tabs_heading_typography_typography":"custom","tab_header_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":18,"sizes":[]},"tab_typography_font_weight":"500","tab_typography_text_transform":"uppercase","tab_typography_line_height":{"unit":"px","size":20,"sizes":[]},"title_color":"#ffffff","title_background_color":"#000000","title_hover_color":"#ffffff","title_background_hover_color":"#e81938","title_active_color":"#ffffff","title_background_active_color":"#e81938","align_content":"","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"tab_title_margin":{"unit":"px","top":"0","right":"5","bottom":"0","left":"5","isLinked":false},"tab_title_margin_mobile":{"unit":"px","top":"0","right":"10","bottom":"10","left":"10","isLinked":false}},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"679e2af","elType":"section","settings":{"content_delay_time":"0.50","margin":{"unit":"px","top":"110","right":0,"bottom":"100","left":0,"isLinked":false},"stretch_section":"section-stretched","gap":"no","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"fd583e1","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"c3bd44b","elType":"widget","settings":{"title":"upcoming event","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"what\u2019s next","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"56e4a29","elType":"widget","settings":{"gutter":{"unit":"px","size":"","sizes":[]},"enable_carousel":"yes","pause_on_hover":"","autoplay":"","inner_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"opal-events"}],"isInner":false}],"isInner":false},{"id":"fbe194f","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_calltoaction_about.jpg","id":5122},"background_overlay_opacity":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_position_mobile":"bottom left","background_size_mobile":"cover","background_bg_width_mobile":{"unit":"%","size":400,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_color":"#000000"},"elements":[{"id":"bd91461","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f57fbb6","elType":"widget","settings":{"title":"Come Ride with Us!","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"eaf1cf4","elType":"widget","settings":{"title":"Become a Part of<br>\nOur Family","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height":{"unit":"px","size":80,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":60,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"81b6693","elType":"widget","settings":{"text":"Contact us","align":"center","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"club-history":[{"id":"80d53cc","elType":"section","settings":{"gap":"no","height":"min-height","structure":"21","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"125","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"13ed90e","elType":"column","settings":{"_column_size":33,"_inline_size":40.61999999999999744204615126363933086395263671875,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"cdf6c8d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/history-1.jpg","id":334},"image_size":"full","_animation":"opal-move-up","animation_duration":"fast","width_tablet":{"unit":"%","size":100,"sizes":[]},"space_tablet":{"unit":"%","size":100,"sizes":[]},"_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"f457320","elType":"column","settings":{"_column_size":66,"_inline_size":59.37700000000000244426701101474463939666748046875,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"140","isLinked":false},"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"74e197b","elType":"widget","settings":{"title":"HOW IT ALL STARTED","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"title_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"64b62de","elType":"widget","settings":{"editor":"<p>Originally the club was formed for the interest of both car and bike riders in Launceston and was called the Tasmanian Automobile Club. The constitution stated that membership had to be approximately 50 \/ 50 car and bike. At events cars would compete with bike riders acting as officials for half the day and the roles swapped for the second half.<\/p><p>Right from the start the club ran regular competitive events mainly on the roads in and around Launceston. Hill climbs were held at places like Henry Street, High Street, Denison Road, and Landfall Hill. Acceleration test were held at many places along the Midland Highway, The \u201cflying mile\u201d near Longford, Rochalea Road and Nile Road.<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]},"typography_line_height":{"unit":"px","size":28,"sizes":[]}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"1eb7429","elType":"section","settings":{"gap":"no","structure":"21","content_delay_time":"0.50","margin":{"unit":"px","top":"60","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"a5c5ffa","elType":"column","settings":{"_column_size":33,"_inline_size":40.61999999999999744204615126363933086395263671875,"space_between_widgets":0,"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"border_color":"#e81938","_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"f94f2ca","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"80","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"50","isLinked":false}},"elements":[{"id":"bde2db6","elType":"column","settings":{"_column_size":100,"_inline_size":null},"elements":[{"id":"35e6c20","elType":"widget","settings":{"icon":"opal-icon-quote-left","align":"left","size":{"unit":"px","size":70,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-70","left":"-64","isLinked":false}},"elements":[],"widgetType":"icon"},{"id":"869d310","elType":"widget","settings":{"editor":"Our mission is to provide a friendly club for owners and enthusiasts of Classic Motorcycles.","typography_typography":"custom","text_color":"#ffffff","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":30,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":24,"sizes":[]},"typography_line_height":{"unit":"px","size":37,"sizes":[]},"typography_line_height_mobile":{"unit":"em","size":1.3000000000000000444089209850062616169452667236328125,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0.90000000000000002220446049250313080847263336181640625,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"38","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"e97d885","elType":"widget","settings":{"editor":"<p><img class=\"alignnone size-full wp-image-415\" src=\"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/s.png\" alt=\"\" width=\"269\" height=\"72\" \/><\/p>","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"1810fdb","elType":"widget","settings":{"title":"Richard Hilton","header_size":"h3","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":"","sizes":[]},"_margin":{"unit":"px","top":"10","right":"0","bottom":"0","left":"0","isLinked":false},"title_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"dca7bdd","elType":"widget","settings":{"title":"founder","header_size":"h3","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"em","size":0.1000000000000000055511151231257827021181583404541015625,"sizes":[]},"title_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]},"typography_letter_spacing":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"aa934ff","elType":"column","settings":{"_column_size":66,"_inline_size":59.37700000000000244426701101474463939666748046875,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"140","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_inline_size_tablet":100},"elements":[{"id":"a76409d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/history-2.jpg","id":363},"image_size":"full","_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_css_classes":"img-animated","width_tablet":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"5e58760","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"130","right":0,"bottom":"130","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"368c6c0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"3c76313","elType":"widget","settings":{"title":"Club history","sub_title":"our story","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_text_transform":"uppercase","subtitle_typography_line_height":{"unit":"px","size":"","sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"title_color":"#ffffff","subtitle_typography_font_family":"Teko","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":42,"sizes":[]},"show_decor":"yes"},"elements":[],"widgetType":"heading"},{"id":"232a80e","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"f9c4787","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"0c63aba","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/img-timeline.jpg","id":5389},"image_size":"full","align":"left","_css_classes":"img-animated","align_tablet":"center","width_tablet":{"unit":"%","size":100,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"4ad50d7","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"1d8958b","elType":"widget","settings":{"tabs":[{"st_year":"1935","st_heading":"The McCook Outlaws Motorcycle Club","st_content":"The McCook Outlaws Motorcycle Club was established out of Matilda`s Bar on old Route 66 in McCook, Illinois, just outside of Chicago.<br>\nAlthough the Club stayed together their activities had been limited during World War II. In May of 1946, the first major post-war motorcycle event was held at Soldier Field in Chicago.<br>\nWith new members coming from all over the Chicago area, the Club was growing in size from its early beginnings of 1935. Moving out of McCook and re-establishing itself in Chicago, the club decided to change its name. <br>The \u201cMcCook Outlaws\u201d became The \u201cChicago Outlaws\u201d. The club logo also underwent a change; a small skull replaced the winged motorcycle .<br><br>","_id":"4756c50"},{"st_year":"1954","st_heading":"A set of Crossed Pistons","st_content":"<p>A set of Crossed Pistons were added to the small skull. This time the design was embroidered on black western style shirts with white piping.<br \/>The Skull and Crossed Pistons were redesigned, making them much larger with more detail.<br \/>The AMA (American Motorcycle Association) that supervises all official races in the USA, banned the word Outlaws from all race clothing. Club members who raced adapted and wore an \u201cOMC\u201d on their outfits till 1963.<br \/>The Outlaws became the first true 1%er Club east of the Mississippi.<br \/>On the 4th of July, the \u201cGipsy Outlaws\u201d from Milwaukee became the second chapter to join the club.\u00a0<\/p><p>\u00a0<\/p>","_id":"e695041"},{"st_year":"1965","st_heading":"The first chapter outside the USA ","st_content":"<p>In July, 1967, the \u201cOutlaws\u201d National President and a few more members went down from Chicago, and sanctioned the first chapter in Florida.<br \/>\u201cGod forgives, Outlaws don\'t\u201c became the club\'s motto.<br \/>The first chapter outside the USA was formed in Canada. The \u201cSatan\'s Choice\u201d became \u201cOutlaws\u201d.<br \/>For the first time a member not belonging to the Mother chapter became \u201cNational President\u201d.<br \/>The abbreviation \u201cMC\u201d was added to the backpatch.<br \/>France became the first European chapter.<br \/>Formerly independent, the \u201cAustralian Outlaws\u201d joined the AOA. The \u201cMC 44\u201d from France became a chapter. The bottom rocker on their backpatch read \u201cEurope\u201d.<br \/><br \/><\/p>","_id":"8c8fe92"},{"st_year":"1995","st_heading":"The Chicago chapter had grown","st_content":"The Chicago chapter had grown and is split into three groups: the Mother Chapter (Southside), Westside and Northside. Norway became the second European chapter.<br>The Belgian \u201cOutlaws MC\u201d, already existing independently for 25 years, became a member of the AOA.<br>14 chapters of the English and welsh \u201cOutlaws MC\u201c, until then an independent MC, joined the AOA. Later that year Norway was added as the first Scandinavian chapter.<br>\nWith new chapters in Ireland and Jersey, a country off the English coast, the club began to expand. In Germany the \u201cGhost Riders MC\u201d joined the AOA.<br><br><br>","_id":"20038a9"},{"st_year":"2002","st_heading":"Original Mustang Shop Tour","st_content":" The first Asian chapter was established in Thailand and Sweden became the second Scandinavian chapter. <br>\nGermany started the first official Support MC of the AOA Nation. The new \u201cBlack Pistons MC\u201d soon appeared in other countries: the USA, Canada, Great Britain, Poland and Norway for starters. The AOA expanded again, this time with new chapters in Italy and Poland.<br>\nThe \u201cOutlaws MC\u201d had grown to hold a presence in 19 states of the USA. The French \u201cMC Drome\u201d came over and joined the AOA.<br>\nAt the end of 2004, the AOA started its first prospective chapter in Russia.<br><br><br>\n\n","_id":"3bec932"},{"st_year":"2005","st_heading":"The Outlaws MC World","st_content":"The Outlaws MC World celebrated its 70th Anniversary as a Motorcycle Club and the 40th Anniversary as the AOA. In June Charlie landed in Russia, as the chapter received full membership Status.<br>\nThe end of 2006 marked the AOA starting its first chapter in Japan.<br>\nAsia grew again, with the first chapter in Philippines starting in March.<br>The A.O.A. starts a chapter in Spain, in January.<br>The A.O.A. starts a chapter in Serbia and Austria.<br>\nThe A.O.A. starts a chapter in Switzerland and Czechia.<br>\nBiking & Brotherhood since 1935. The Outlaws MC World celebrate 2015 the 80th Anniversary as a Motorcycle Club and 50th Anniversary as the AOA (Outlaws Nation)\n<br><br>\n<br>","_id":"256ca79"}],"height_wrapper":{"unit":"px","size":580,"sizes":[]},"content_padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-scroll-timeline"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"c6eed40","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"140","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"521844f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"dca4d82","elType":"widget","settings":{"title":"More than 25 years\nof age","sub_title":"We Are Experienced","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"70","left":"0","isLinked":false},"_padding":{"unit":"%","top":"0","right":"27","bottom":"0","left":"27","isLinked":false},"title_color":"#ffffff","subtitle_typography_font_family":"Teko","_animation":"opal-move-up","animation_duration":"fast","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":42,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"show_decor":"yes"},"elements":[],"widgetType":"heading"},{"id":"e8b1c2c","elType":"section","settings":{"gap":"no","height_inner":"min-height","custom_height_inner":{"unit":"px","size":420,"sizes":[]},"structure":"20","content_delay_time":"0.50"},"elements":[{"id":"5a8a9f4","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"125","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"8f2b30a","elType":"widget","settings":{"editor":"<p>Looking for some adventure? We are working on several short tours on Vancouver Island, On-Road, Off-Road there is so much to see here. Keep and eye on the website and our News Letter as we release information about these tours and how you can get off the beaten track and experience the incredible parts of this Island with our expert guides.<\/p>","_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"5bf0082","elType":"widget","settings":{"title":"riding skill","percent":{"unit":"%","size":79,"sizes":[]},"progress_height":{"unit":"px","size":3,"sizes":[]},"progress_border_radius":{"unit":"px","size":0,"sizes":[]},"display_percentage":"hide","inner_text":"","bar_bg_color":"rgba(0,0,0,0)","title_color":"#ffffff","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"progress"},{"id":"4514c25","elType":"widget","settings":{"title":"SURVIVAL skill","percent":{"unit":"%","size":96,"sizes":[]},"progress_height":{"unit":"px","size":3,"sizes":[]},"progress_border_radius":{"unit":"px","size":0,"sizes":[]},"display_percentage":"hide","inner_text":"","bar_bg_color":"rgba(0,0,0,0)","title_color":"#ffffff","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"progress"},{"id":"2d9d375","elType":"widget","settings":{"title":"PERFORMANCE","percent":{"unit":"%","size":85,"sizes":[]},"progress_height":{"unit":"px","size":3,"sizes":[]},"progress_border_radius":{"unit":"px","size":0,"sizes":[]},"display_percentage":"hide","inner_text":"","bar_bg_color":"rgba(0,0,0,0)","title_color":"#ffffff","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"progress"}],"isInner":true},{"id":"b878401","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"5cf747d","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=1Q3LojC1wf8","border_video_color":"#ffffff","_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/video.jpg","id":3714},"_background_position":"center center","_background_repeat":"no-repeat","_background_size":"cover","_padding":{"unit":"px","top":"188","right":"0","bottom":"188","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-video-popup"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"01cbe99","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_calltoaction_about.jpg","id":5122},"background_overlay_opacity":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_position_mobile":"bottom left","background_size_mobile":"cover","background_bg_width_mobile":{"unit":"%","size":400,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_color":"#000000"},"elements":[{"id":"cfb64ef","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"383a37e","elType":"widget","settings":{"title":"Come Ride with Us!","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"f7ce6a0","elType":"widget","settings":{"title":"Become a Part of<br>\nOur Family","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height":{"unit":"px","size":80,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"a81a62c","elType":"widget","settings":{"text":"Contact us","align":"center","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"club-info":[{"id":"7096fff","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"130","right":0,"bottom":"130","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"5303ac7","elType":"column","settings":{"_column_size":50,"_inline_size":48.91499999999999914734871708787977695465087890625,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"be0101e","elType":"widget","settings":{"title":"Vintage Motorcycle Club<br>of <span class=\"c-primary\">Western Australia<\/span>","align_tablet":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"cf5c73c","elType":"widget","settings":{"editor":"If you are looking to find a group of well-established and safe to ride with, you\'ve found us. We were founded as a formal motorcycle club in Boston in 1985, and are still going strong. We focus on safe riding and we also ride for charities that are near and dear to our hearts.<br>\nWe are a national club with chapters and members across the country. Our passion for motorcycling provides a unique bond within the legal community. We ride virtually every make and model of bike, although a majority rides Harleys.","_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","align_tablet":"center"},"elements":[],"widgetType":"text-editor"},{"id":"6abc967","elType":"widget","settings":{"text":"explore our rides","_margin":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""},"align_tablet":"center"},"elements":[],"widgetType":"button"},{"id":"2148f5c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/image1_about.jpg","id":336},"image_size":"full","_css_classes":"img-animated","align":"left","align_tablet":"center"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"82a9ab1","elType":"column","settings":{"_column_size":50,"_inline_size":51.08500000000000085265128291212022304534912109375,"space_between_widgets":0,"_inline_size_tablet":100,"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"140","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"css_classes":"c-primary"},"elements":[{"id":"bc9dd8a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/image2_about.jpg","id":344},"image_size":"full","_margin":{"unit":"px","top":"0","right":"0","bottom":"135","left":"0","isLinked":false},"_css_classes":"img-animated","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"60","right":"0","bottom":"30","left":"0","isLinked":false},"align":"right","align_tablet":"center","width_tablet":{"unit":"%","size":60,"sizes":[]},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"image"},{"id":"bb0237d","elType":"widget","settings":{"title":"we kept what we<br>loved about the bike","align_tablet":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"98695be","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"content_width":{"unit":"px","size":1320,"sizes":[]},"stretch_section":"section-stretched","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"938b9aa","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"eca4497","elType":"widget","settings":{"title":"what we do","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"Club activities","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"d8222be","elType":"section","settings":{"gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"layout":"full_width"},"elements":[{"id":"bd083f8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"animation":"opal-move-up","animation_duration":"fast","background_color":"#ffffff","background_position":"top left","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#131313"},"elements":[{"id":"d3df816","elType":"widget","settings":{"icon":"opal-icon-motocross","view":"default","title_text":"We ride bikes","description_text":"Lex Rider regularly organises ride-outs suitable for all types of bikes and speeds. Our ride-outs range from short, local routes, to continental travel.","alignment":"center","wrapper_padding":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_font_weight":"500","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"spacing_title":{"unit":"px","top":"40","right":"0","bottom":"20","left":"0","isLinked":false},"title_color":"#000000","description_spacing":{"unit":"px","size":0,"sizes":[]},"primary_color":"#e81938","icon_size":{"unit":"px","size":64,"sizes":[]},"view_style":"default","wrapper_padding_tablet":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]},"subtitle_color_hover":"#ffffff","_background_background":"classic"},"elements":[],"widgetType":"featured-box"}],"isInner":true},{"id":"e2ad7b1","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"background_color":"#ffffff","background_position":"top left","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#131313"},"elements":[{"id":"e847a5b","elType":"widget","settings":{"icon":"opal-icon-support-heart","view":"default","title_text":"We support charities","description_text":"We support both local and national charities such as air ambulance, blood bikes, and the teenage cancer trust through the annual Stephen Sutton Ride","alignment":"center","wrapper_padding":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_font_weight":"500","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"spacing_title":{"unit":"px","top":"40","right":"0","bottom":"20","left":"0","isLinked":false},"title_color":"#000000","description_spacing":{"unit":"px","size":0,"sizes":[]},"primary_color":"#e81938","icon_size":{"unit":"px","size":64,"sizes":[]},"view_style":"default","wrapper_padding_tablet":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]},"subtitle_color_hover":"#ffffff","_background_background":"classic"},"elements":[],"widgetType":"featured-box"}],"isInner":true},{"id":"e98963c","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_mis_bg1.png","id":5461},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300,"background_color":"#ffffff","background_position":"top left","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#131313"},"elements":[{"id":"ee2fbfd","elType":"widget","settings":{"icon":"opal-icon-motorcycle","view":"default","title_text":" motorcycle shows","description_text":"We have such a diverse collection of bikes through the club. We attend and exhibit at most of the major motorcycle shows.","alignment":"center","wrapper_padding":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_font_weight":"500","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"spacing_title":{"unit":"px","top":"40","right":"0","bottom":"20","left":"0","isLinked":false},"title_color":"#000000","description_spacing":{"unit":"px","size":0,"sizes":[]},"primary_color":"#e81938","icon_size":{"unit":"px","size":60,"sizes":[]},"view_style":"default","wrapper_padding_tablet":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":22,"sizes":[]},"subtitle_color_hover":"#ffffff","_background_background":"classic"},"elements":[],"widgetType":"featured-box"}],"isInner":true}],"isInner":true},{"id":"862b267","elType":"widget","settings":{"text":"see our activities","align":"center","_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"14925b9","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"40","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_counter_about.jpg","id":392},"background_repeat":"no-repeat","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"padding":{"unit":"px","top":"120","right":"0","bottom":"100","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true},"animation_duration":"fast","background_size":"cover","padding_tablet":{"unit":"px","top":"40","right":"30","bottom":"40","left":"30","isLinked":false},"content_width":{"unit":"px","size":1070,"sizes":[]},"background_position":"center center","section_parallax_on":"yes"},"elements":[{"id":"859d804","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"6ac875f","elType":"widget","settings":{"ending_number":185,"title":"members","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"divider_width":{"unit":"%","size":100,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","typography_title_line_height":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"wrapper_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"wrapper_padding_tablet":{"unit":"px","top":"20","right":"15","bottom":"20","left":"0","isLinked":false},"wrapper_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"84b8c7f","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"e3c6c20","elType":"widget","settings":{"ending_number":486,"title":"Club rides","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"divider_width":{"unit":"%","size":100,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","typography_title_line_height":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"wrapper_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"wrapper_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"b10dd02","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"1bb632a","elType":"widget","settings":{"ending_number":1561,"title":"Repairs in workshop ","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"divider_width":{"unit":"%","size":100,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","typography_title_line_height":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"wrapper_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"wrapper_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"80b1636","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"f216e91","elType":"widget","settings":{"ending_number":219561,"title":"Total KMS by the club","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"divider_width":{"unit":"%","size":100,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","typography_title_line_height":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"wrapper_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"wrapper_padding_tablet":{"unit":"px","top":"20","right":"0","bottom":"20","left":"20","isLinked":false},"wrapper_padding_mobile":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":true},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":false}],"isInner":false},{"id":"852f1b1","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"028a154","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"87fe7d1","elType":"widget","settings":{"title":"why choose us","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"our benefits","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"35b258a","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","overflow":"hidden","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":50},"osf_section_parallax_position_v":{"unit":"%","size":-23},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"1a4b32b"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":50},"osf_section_parallax_position_v":{"unit":"%","size":90},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"08c6b16"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":73},"osf_section_parallax_position_v":{"unit":"%","size":74},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"140d73c"}],"content_position":"middle"},"elements":[{"id":"4becfba","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100,"animation_duration":"fast"},"elements":[{"id":"75e4de7","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/image3_about.jpg","id":429},"image_size":"full","width_tablet":{"unit":"%","size":70,"sizes":[]},"_css_classes":"img-animated","align":"left","align_tablet":"center","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"4f564c6","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"70","right":"70","bottom":"70","left":"70","isLinked":true},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3c15fe9","elType":"widget","settings":{"tabs":[{"tab_title":"Meet new and like-minded folks","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"3a9c881"},{"tab_title":"Happiness multiplies when shared","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"2fa7a03"},{"tab_title":"Rides are safer","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"dfde816"},{"tab_title":"Get More Attention ","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"ca28627"},{"tab_title":"Get to know more machines ","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"7b230cd"},{"tab_title":"Be part of a Legacy","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"3e6e851"}],"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_color":"#000000","title_color_active":"#e81938","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"icon_background_color_normal":"rgba(0,0,0,0)","icon_active_color":"#e81938","icon_active_bg_color":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":30,"sizes":[]},"padding_vertical":{"unit":"px","size":8,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"20","right":"50","bottom":"40","left":"50","isLinked":false},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"content_typography_line_height":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","title_typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"icon_space_add_mobile":{"unit":"px","size":5,"sizes":[]},"content_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"35","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"5dd0c36","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"110","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"f79ec77","elType":"column","settings":{"_column_size":50,"_inline_size":25,"space_between_widgets":0,"_inline_size_tablet":30,"content_position":"space-between"},"elements":[{"id":"cb19f11","elType":"widget","settings":{"title":"recent<br>\nposts","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"Latest news","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"90","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align":"left","subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"1b4a66d","elType":"widget","settings":{"text":"see all news","_animation":"opal-move-up","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/news\/","is_external":"on","nofollow":""},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"50d6554","elType":"column","settings":{"_column_size":50,"_inline_size":75,"space_between_widgets":0,"_inline_size_tablet":70},"elements":[{"id":"862f10f","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast","column_tablet":"1","column_mobile":"1"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"b08bb38","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_calltoaction_about.jpg","id":5122},"background_overlay_opacity":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375,"sizes":[]},"padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_position_mobile":"bottom left","background_size_mobile":"cover","background_bg_width_mobile":{"unit":"%","size":400,"sizes":[]},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"background_repeat":"no-repeat","background_overlay_background":"classic","background_overlay_color":"#000","background_position":"center center","background_size":"cover","padding_tablet":{"unit":"px","top":"100","right":"15","bottom":"100","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"c26de39","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"6e4b2e3","elType":"widget","settings":{"title":"Come Ride with Us!","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","typography_font_weight":"500"},"elements":[],"widgetType":"heading"},{"id":"746773b","elType":"widget","settings":{"title":"Become a Part of<br>\nOur Family","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_line_height":{"unit":"em","size":1,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":"","sizes":[]},"typography_font_weight":"500"},"elements":[],"widgetType":"heading"},{"id":"8537b13","elType":"widget","settings":{"text":"Contact us","align":"center","_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/contact\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"footer-1":[{"id":"7900c43","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#1a1a1a","padding":{"unit":"px","top":"125","right":"30","bottom":"110","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"70","right":"30","bottom":"70","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"15","bottom":"70","left":"15","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#313131"},"elements":[{"id":"9069814","elType":"column","settings":{"_column_size":33,"_inline_size":58.6820000000000021600499167107045650482177734375,"space_between_widgets":0,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"66e78e4","elType":"widget","settings":{"title":"do you have questions? <br>do not wait, <span class=\"c-primary\">let\u2019s talk<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"51","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"219b70e","elType":"widget","settings":{"view":"inline","icon_list":[{"text":"+(84) 22 4130 0555","icon":"opal-icon-phone-square","_id":"2f1b5eb","link":{"url":"","is_external":"","nofollow":""}},{"text":"contact@example.com","icon":"opal-icon-envelope-open-text","_id":"525f58b","link":{"url":"#","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":24,"sizes":[]},"text_indent":{"unit":"px","size":14,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Teko","icon_typography_font_size":{"unit":"px","size":40,"sizes":[]},"icon_typography_font_weight":"500","text_color":"#ffffff","list_item_margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"list_item_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_align_mobile":"center","icon_typography_font_size_tablet":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"icon-list"}],"isInner":false},{"id":"8bb6996","elType":"column","settings":{"_column_size":33,"_inline_size":22.318000000000001392663762089796364307403564453125,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"f50798e","elType":"widget","settings":{"title":"head office","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"346c3d7","elType":"widget","settings":{"editor":"<p>Box 565, <br \/>Charlestown, Nevis, <br \/>West Indies, <br \/>Caribbean<\/p>","align_mobile":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"d65c0a2","elType":"widget","settings":{"editor":"<p><a href=\"https:\/\/www.google.com\/maps?ll=51.523767,-0.158556&amp;z=16&amp;t=m&amp;hl=en&amp;gl=US&amp;mapclient=embed&amp;q=221B+Baker+St+Marylebone,+London+NW1+6XE+UK\" target=\"_blank\" rel=\"noopener\">view map<\/a><\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12,"sizes":[]},"typography_text_transform":"uppercase","border_link_border":"solid","border_link_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_link_color":"rgba(0,0,0,0)","link_color":"#e81938","link_hover_color":"#e81938","link_hover_border_color":"#e81938"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"ed03c9e","elType":"column","settings":{"_column_size":33,"_inline_size":18.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"d58e376","elType":"widget","settings":{"title":"quick links","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"1bc0001","elType":"widget","settings":{"menu":"quick-links","layout":"vertical","pointer":"dot","indicator":"none","enable_mobile_dropdown":"","menu-toggle-title":"Menu","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_family":"Noto Sans","menu_typography_font_size":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"capitalize","padding_horizontal_menu_item":{"unit":"px","size":0,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":4,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"menu_typography_font_weight":"400","align_items_mobile":"center"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false},{"id":"b0a6c8c","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#131313","padding":{"unit":"px","top":"65","right":"30","bottom":"65","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"2ef0b9e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"82b9721","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019. All Rights Reserved.<\/p>","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"ebd5286","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f706d1b","elType":"widget","settings":{"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"3e7683f","elType":"column","settings":{"_column_size":33,"_inline_size":null,"content_position":"center","align":"flex-end","space_between_widgets":0},"elements":[{"id":"b2969f2","elType":"widget","settings":{"title":"social media","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"18","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_element_vertical_align":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","align_mobile":"center","_element_width_mobile":"inherit","typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"ea8b55f","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"b3d40de","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"d7ab8f1","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-google-plus","_id":"905749e","link":{"url":"","is_external":"true","nofollow":""}}],"shape":"square","icon_color":"custom","icon_primary_color":"#000000","icon_secondary_color":"#ffffff","icon_size":{"unit":"px","size":18,"sizes":[]},"icon_padding":{"unit":"em","size":0.75,"sizes":[]},"icon_spacing":{"unit":"px","size":6,"sizes":[]},"hover_primary_color":"#e81938","hover_secondary_color":"#ffffff","_element_width":"auto","_element_vertical_align":"center","align":"right","align_mobile":"center","_element_width_tablet":"inherit"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"pricing-page":[{"id":"29b249c","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"140","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"8c3bd1d","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"2f25b5e","elType":"widget","settings":{"icon":"opal-icon-helmet","heading":"basic","sub_heading":"Starting From","price":"39.0","period":"monthly","features_list":[{"item_text":"Monthly magazine","item_icon":"fa fa-check-circle","_id":"331a51e","item_check":"yes"},{"item_text":"Private sections","item_icon":"fa fa-check-circle","_id":"1e12800","item_check":"yes"},{"item_text":"Insurance services","item_icon":"fa fa-check-circle","_id":"b82c952","item_check":"yes"},{"item_text":"Marque specialists","item_check":"","_id":"e33849b"},{"item_text":" Club library","item_check":"","_id":"5f4b8fa"},{"item_text":"Events","item_check":"","_id":"8136907"},{"item_text":"Member discount","item_check":"","_id":"f5987a5"}],"button_text":"join now","ribbon_title":"Popular","heading_typography_typography":"custom","heading_typography_text_transform":"uppercase","sub_heading_typography_typography":"custom","sub_heading_typography_text_transform":"uppercase","wrapper_features_border_border":"solid","wrapper_features_border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"wrapper_features_border_color":"rgba(237,237,237,0.2)","button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":18,"sizes":[]},"button_margin":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":true},"price_typography_typography":"custom","features_list_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","button_margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"button_margin_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"section_wrapper_bkg_hover":"#ffffff","animation_moveup":"yes","border_color_hover":"#ededed"},"elements":[],"widgetType":"opal-price-table"}],"isInner":false},{"id":"1794f7a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","margin":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"7a7a748","elType":"widget","settings":{"icon":"opal-icon-speedometer","heading":"advandce","sub_heading":"Starting From","price":"49.0","period":"monthly","features_list":[{"item_text":"Monthly magazine","item_icon":"fa fa-check-circle","_id":"331a51e","item_check":"yes"},{"item_text":"Private sections","item_icon":"fa fa-check-circle","_id":"1e12800","item_check":"yes"},{"item_text":"Insurance services","item_icon":"fa fa-check-circle","_id":"b82c952","item_check":"yes"},{"item_text":"Marque specialists","item_check":"yes","_id":"e33849b"},{"item_text":" Club library","item_check":"yes","_id":"5f4b8fa"},{"item_text":"Events","item_check":"","_id":"8136907"},{"item_text":"Member discount","item_check":"","_id":"f5987a5"}],"button_text":"Join now","ribbon_title":"Popular","heading_typography_typography":"custom","heading_typography_text_transform":"uppercase","sub_heading_typography_typography":"custom","sub_heading_typography_text_transform":"uppercase","wrapper_features_border_border":"solid","wrapper_features_border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"wrapper_features_border_color":"#ededed","section_wrapper_bkg":"#ffffff","heading_color":"#000000","features_list_color_check":"#000000","features_list_color_uncheck":"#777777","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"features_list_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"button_margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"button_margin_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation_moveup":"yes"},"elements":[],"widgetType":"opal-price-table"}],"isInner":false},{"id":"d8f2ce8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"39fde58","elType":"widget","settings":{"icon":"opal-icon-pistons","heading":"premier","sub_heading":"Starting From","price":"59.0","period":"monthly","features_list":[{"item_text":"Monthly magazine","item_icon":"fa fa-check-circle","_id":"331a51e","item_check":"yes"},{"item_text":"Private sections","item_icon":"fa fa-check-circle","_id":"1e12800","item_check":"yes"},{"item_text":"Insurance services","item_icon":"fa fa-check-circle","_id":"b82c952","item_check":"yes"},{"item_text":"Marque specialists","item_check":"yes","_id":"e33849b"},{"item_text":" Club library","item_check":"yes","_id":"5f4b8fa"},{"item_text":"Events","item_check":"yes","_id":"8136907"},{"item_text":"Member discount","item_check":"yes","_id":"f5987a5"}],"button_text":"join now","ribbon_title":"Popular","heading_typography_typography":"custom","heading_typography_text_transform":"uppercase","sub_heading_typography_typography":"custom","sub_heading_typography_text_transform":"uppercase","wrapper_features_border_border":"solid","wrapper_features_border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"wrapper_features_border_color":"rgba(237,237,237,0.2)","button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":18,"sizes":[]},"button_margin":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":true},"price_typography_typography":"custom","features_list_padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","button_margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"button_margin_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation_delay":250,"animation_moveup":"yes","section_wrapper_bkg_hover":"#ffffff","border_color_hover":"#ededed"},"elements":[],"widgetType":"opal-price-table"}],"isInner":false}],"isInner":false},{"id":"5e66d88","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"140","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"249c180","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"36ae9ef","elType":"widget","settings":{"title":"Questions or concerns","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":42,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"b5d3a08","elType":"section","settings":{"content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"e8da36d","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"d50e95f","elType":"widget","settings":{"tabs":[{"tab_title":"Are you a Harley club?","tab_content":"<p>No, we are not focused on any single brand of motorcycle. In fact, our club\u2019s founding members included at least three members who each owned a different motorcycle dealership.<\/p>","_id":"a85ffb3"},{"tab_title":"Are you an \"OUTLAW\" motorcycle club?","tab_content":"<p>After successfully infiltrating one of the most infamous outlaw biker gangs, Charles Falco dons the wire and heads back undercover in the new series of Gangland Undercover, Tuesdays at 10pm exclusively on HISTORY.<\/p>","_id":"b93fdd8"},{"tab_title":"I ride a motorcycle, can I join?","tab_content":"<p>The terminology is left over from the days before motorized conveyances, where to \"drive\" horses or cattle was to induce them to move in a desired direction. People \"rode\" horses by sitting on them.<\/p>","_id":"209b4b1"},{"tab_title":"If I see you guys around, can I say hello?","tab_content":"<p>Not in the Southern United States! There, \u201cguy\/guys\u201d is still considered a male usage, reserved for addressing a strictly male audience in an informal setting. Using it towards or in reference to a mixed or all-female group will get the speaker some strange looks in return.<\/p>","_id":"4c251b8"}],"background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_background":"#131313","title_color":"#ffffff","title_background_active":"#131313","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_padding":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"icon_align":"right","icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":0,"sizes":[]},"padding_vertical":{"unit":"px","size":15,"sizes":[]},"icon_space_add":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_padding":{"unit":"px","top":"0","right":"40","bottom":"50","left":"40","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"title_padding_tablet":{"unit":"px","top":"15","right":"30","bottom":"15","left":"30","isLinked":false},"content_typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"30","left":"30","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true},{"id":"6efc886","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"4495972","elType":"widget","settings":{"tabs":[{"tab_title":"I used to know a guy in the club, can you say hi for me.","tab_content":"<p>Your older sister recalls, \u201cWe were lab partners in chemistry. Somewhere between the first assignment and lighting the Bunsen burner, he asked me out. We\u2019ve been together ever since.\u201d<\/p>","_id":"a85ffb3"},{"tab_title":"Do I have to join STAR to ride with a Chapter? ","tab_content":"<p>Yes you can! STAR Touring and Riding is a family organization and our family and friends don\'t always own the same brand of bike. Although our main focus is the Star Motorcycle Line manufactured by Yamaha, we welcome all motorcyclists.<\/p>","_id":"b93fdd8"},{"tab_title":"What is in a membership packet?","tab_content":"<p>New membership packets contain the following; STAR membership ID card, Arm patch for type of membership required, ie; STAR, LOS, Kids, Teen, Brass new member pin, (adult members only), welcome letter, current discount card(s), and a card of decals.<br \/>Renewal packets contain the following; Adult members only, New STAR membership card, small year rocker for the year you renewed, welcome letter, and current discount card(s).<\/p>","_id":"209b4b1"},{"tab_title":"Where do I buy a back patch? ","tab_content":"<p>You can order them by going to the STAR Mall or by calling the International Office. Remember, you must be a current member of STAR Touring and Riding. Refer to the placement guidelines at the bottom of this page.<\/p>","_id":"4c251b8"}],"background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_background":"#131313","title_color":"#ffffff","title_background_active":"#131313","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_padding":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"icon_align":"right","icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":0,"sizes":[]},"padding_vertical":{"unit":"px","size":15,"sizes":[]},"icon_space_add":{"unit":"px","size":15,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_padding":{"unit":"px","top":"0","right":"40","bottom":"50","left":"40","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":20,"sizes":[]},"title_padding_tablet":{"unit":"px","top":"15","right":"30","bottom":"15","left":"30","isLinked":false},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"content_typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"30","left":"30","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"9fca122","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"be6b9ec","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"c0fad3c","elType":"widget","settings":{"title":"why choose us","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"our benefits","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"90","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"a8ead3a","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","overflow":"hidden","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":50},"osf_section_parallax_position_v":{"unit":"%","size":-23},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"1a4b32b"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":50},"osf_section_parallax_position_v":{"unit":"%","size":90},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"08c6b16"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":73},"osf_section_parallax_position_v":{"unit":"%","size":74},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"140d73c"}],"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg_box.jpg","id":4728},"background_position":"bottom right","background_repeat":"no-repeat"},"elements":[{"id":"fb6e532","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"53aeb80","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/image3_about.jpg","id":429},"image_size":"full","width_tablet":{"unit":"%","size":100,"sizes":[]},"_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"cc704ac","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"70","right":"70","bottom":"70","left":"70","isLinked":true},"_inline_size_tablet":100,"background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"background_repeat":"no-repeat","padding_tablet":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":true},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[{"id":"d47b2b8","elType":"widget","settings":{"tabs":[{"tab_title":"Meet new and like-minded folks","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"3a9c881"},{"tab_title":"Happiness multiplies when shared","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"2fa7a03"},{"tab_title":"Rides are safer","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"dfde816"},{"tab_title":"Get More Attention ","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"ca28627"},{"tab_title":"Get to know more machines ","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"7b230cd"},{"tab_title":"Be part of a Legacy","tab_content":"<p>Being part of a ride group is a great way to get that missing hint of novelty in your life. Each ride takes you to new places, makes you see new faces, and while each face comes with its own eccentricities, the one thing that remains a common thread among all is their love for rubber on tarmac and freedom.<\/p>","_id":"3e6e851"}],"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_color":"#000000","title_color_active":"#e81938","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"icon_background_color_normal":"rgba(0,0,0,0)","icon_active_color":"#e81938","icon_active_bg_color":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":30,"sizes":[]},"padding_vertical":{"unit":"px","size":8,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"20","right":"50","bottom":"40","left":"50","isLinked":false},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"content_typography_line_height":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","title_typography_font_size_mobile":{"unit":"px","size":20,"sizes":[]},"icon_space_add_mobile":{"unit":"px","size":5,"sizes":[]},"content_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"35","isLinked":false},"title_typography_font_size_tablet":{"unit":"px","size":24,"sizes":[]},"content_typography_font_size_tablet":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"accordion"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"faq-2":[{"id":"29f821b","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#313131","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"140","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false}},"elements":[{"id":"fda0086","elType":"column","settings":{"_column_size":100},"elements":[{"id":"7523374","elType":"widget","settings":{"title":"Find answers to all of your<br>questions here","align":"center","typography_typography":"custom","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"e9cf79c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","layout":"full_width","margin":{"unit":"px","top":"40","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"ace463b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a273472","elType":"widget","settings":{"tabs":[{"tab_title":"Are you a Harley club?","tab_content":"<p>No, we are not focused on any single brand of motorcycle. In fact, our club\u2019s founding members included at least three members who each owned a different motorcycle dealership.<\/p>","_id":"f5ed659"},{"tab_title":"Are you an \"OUTLAW\" motorcycle club?","tab_content":"<p>After successfully infiltrating one of the most infamous outlaw biker gangs, Charles Falco dons the wire and heads back undercover in the new series of Gangland Undercover, Tuesdays at 10pm exclusively on HISTORY.<\/p>","_id":"63b67d4"},{"tab_title":"I ride a motorcycle, can I join?","tab_content":"<p>The terminology is left over from the days before motorized conveyances, where to \"drive\" horses or cattle was to induce them to move in a desired direction. People \"rode\" horses by sitting on them.<\/p>","_id":"169988e"},{"tab_title":"If I see you guys around, can I say hello?","tab_content":"<p>Not in the Southern United States! There, \u201cguy\/guys\u201d is still considered a male usage, reserved for addressing a strictly male audience in an informal setting. Using it towards or in reference to a mixed or all-female group will get the speaker some strange looks in return.<\/p>","_id":"2311c72"},{"tab_title":"Do you only ride Harley Davidson Motorcycles?","tab_content":"<p>Originally, the term referred to motorcycle clubs not sanctioned by and, therefore, not obeying the laws of the AMA, American Motorcycling Association. After members of some of those clubs made the news due to their criminal exploits, the term got a more broad association with disobeying the law.<\/p>","_id":"dfd771d"}],"icon_align":"right","background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_color":"#ffffff","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_padding":{"unit":"px","top":"35","right":"38","bottom":"35","left":"38","isLinked":false},"icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":10,"sizes":[]},"padding_vertical":{"unit":"px","size":58,"sizes":[]},"icon_space_add":{"unit":"px","size":"","sizes":[]},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"0","right":"38","bottom":"60","left":"38","isLinked":false},"title_padding_tablet":{"unit":"px","top":"38","right":"30","bottom":"35","left":"15","isLinked":false},"icon_width_tablet":{"unit":"px","size":0,"sizes":[]},"icon_size":{"unit":"px","size":20,"sizes":[]},"icon_size_tablet":{"unit":"px","size":20,"sizes":[]},"icon_size_mobile":{"unit":"px","size":20,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true},{"id":"9c1b73b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ffbc2b5","elType":"widget","settings":{"tabs":[{"tab_title":"I used to know a guy in the club, can you say hi for me.","tab_content":"Your older sister recalls, \u201cWe were lab partners in chemistry. Somewhere between the first assignment and lighting the Bunsen burner, he asked me out. We\u2019ve been together ever since.\u201d","_id":"f5ed659"},{"tab_title":"Do I have to join STAR to ride with a Chapter? ","tab_content":"Yes you can! STAR Touring and Riding is a family organization and our family and friends don\'t always own the same brand of bike. Although our main focus is the Star Motorcycle Line manufactured by Yamaha, we welcome all motorcyclists.","_id":"63b67d4"},{"tab_title":"What is in a membership packet?","tab_content":"New membership packets contain the following; STAR membership ID card, Arm patch for type of membership required, ie; STAR, LOS, Kids, Teen, Brass new member pin, (adult members only), welcome letter, current discount card(s), and a card of decals.\nRenewal packets contain the following; Adult members only, New STAR membership card, small year rocker for the year you renewed, welcome letter, and current discount card(s). ","_id":"169988e"},{"tab_title":"Where do I buy a back patch? ","tab_content":"You can order them by going to the STAR Mall or by calling the International Office. Remember, you must be a current member of STAR Touring and Riding. Refer to the placement guidelines at the bottom of this page. ","_id":"2311c72"}],"icon_align":"right","background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_color":"#ffffff","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_padding":{"unit":"px","top":"35","right":"38","bottom":"35","left":"38","isLinked":false},"icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":10,"sizes":[]},"padding_vertical":{"unit":"px","size":0,"sizes":[]},"icon_space_add":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"0","right":"38","bottom":"60","left":"38","isLinked":false},"title_padding_tablet":{"unit":"px","top":"38","right":"30","bottom":"38","left":"15","isLinked":false},"icon_width_tablet":{"unit":"px","size":0,"sizes":[]},"icon_size":{"unit":"px","size":20,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"faq":[{"id":"29f821b","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#313131","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"140","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false}},"elements":[{"id":"fda0086","elType":"column","settings":{"_column_size":100},"elements":[{"id":"7523374","elType":"widget","settings":{"title":"Find answers to all of your<br>questions here","align":"center","typography_typography":"custom","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"e9cf79c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","layout":"full_width","margin":{"unit":"px","top":"40","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"ace463b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a273472","elType":"widget","settings":{"tabs":[{"tab_title":"Are you a Harley club?","tab_content":"<p>No, we are not focused on any single brand of motorcycle. In fact, our club\u2019s founding members included at least three members who each owned a different motorcycle dealership.<\/p>","_id":"f5ed659"},{"tab_title":"Are you an \"OUTLAW\" motorcycle club?","tab_content":"<p>After successfully infiltrating one of the most infamous outlaw biker gangs, Charles Falco dons the wire and heads back undercover in the new series of Gangland Undercover, Tuesdays at 10pm exclusively on HISTORY.<\/p>","_id":"63b67d4"},{"tab_title":"I ride a motorcycle, can I join?","tab_content":"<p>The terminology is left over from the days before motorized conveyances, where to \"drive\" horses or cattle was to induce them to move in a desired direction. People \"rode\" horses by sitting on them.<\/p>","_id":"169988e"},{"tab_title":"If I see you guys around, can I say hello?","tab_content":"<p>Not in the Southern United States! There, \u201cguy\/guys\u201d is still considered a male usage, reserved for addressing a strictly male audience in an informal setting. Using it towards or in reference to a mixed or all-female group will get the speaker some strange looks in return.<\/p>","_id":"2311c72"},{"tab_title":"Do you only ride Harley Davidson Motorcycles?","tab_content":"<p>Originally, the term referred to motorcycle clubs not sanctioned by and, therefore, not obeying the laws of the AMA, American Motorcycling Association. After members of some of those clubs made the news due to their criminal exploits, the term got a more broad association with disobeying the law.<\/p>","_id":"dfd771d"}],"icon_align":"right","background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_color":"#ffffff","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_padding":{"unit":"px","top":"35","right":"38","bottom":"35","left":"38","isLinked":false},"icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":10,"sizes":[]},"padding_vertical":{"unit":"px","size":58,"sizes":[]},"icon_space_add":{"unit":"px","size":"","sizes":[]},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"0","right":"38","bottom":"60","left":"38","isLinked":false},"title_padding_tablet":{"unit":"px","top":"38","right":"30","bottom":"35","left":"15","isLinked":false},"icon_width_tablet":{"unit":"px","size":0,"sizes":[]},"icon_size":{"unit":"px","size":20,"sizes":[]},"icon_size_tablet":{"unit":"px","size":20,"sizes":[]},"icon_size_mobile":{"unit":"px","size":20,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true},{"id":"9c1b73b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ffbc2b5","elType":"widget","settings":{"tabs":[{"tab_title":"I used to know a guy in the club, can you say hi for me.","tab_content":"Your older sister recalls, \u201cWe were lab partners in chemistry. Somewhere between the first assignment and lighting the Bunsen burner, he asked me out. We\u2019ve been together ever since.\u201d","_id":"f5ed659"},{"tab_title":"Do I have to join STAR to ride with a Chapter? ","tab_content":"Yes you can! STAR Touring and Riding is a family organization and our family and friends don\'t always own the same brand of bike. Although our main focus is the Star Motorcycle Line manufactured by Yamaha, we welcome all motorcyclists.","_id":"63b67d4"},{"tab_title":"What is in a membership packet?","tab_content":"New membership packets contain the following; STAR membership ID card, Arm patch for type of membership required, ie; STAR, LOS, Kids, Teen, Brass new member pin, (adult members only), welcome letter, current discount card(s), and a card of decals.\nRenewal packets contain the following; Adult members only, New STAR membership card, small year rocker for the year you renewed, welcome letter, and current discount card(s). ","_id":"169988e"},{"tab_title":"Where do I buy a back patch? ","tab_content":"You can order them by going to the STAR Mall or by calling the International Office. Remember, you must be a current member of STAR Touring and Riding. Refer to the placement guidelines at the bottom of this page. ","_id":"2311c72"}],"icon_align":"right","background_accordion_item":"#131313","accordion_item_spacing":{"unit":"px","size":30,"sizes":[]},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_color":"#ffffff","title_color_active":"#e81938","border_accordion_title_border":"solid","border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_padding":{"unit":"px","top":"35","right":"38","bottom":"35","left":"38","isLinked":false},"icon_color_normal":"#e81938","icon_background_color_normal":"rgba(0,0,0,0)","icon_width":{"unit":"px","size":10,"sizes":[]},"padding_vertical":{"unit":"px","size":0,"sizes":[]},"icon_space_add":{"unit":"px","size":0,"sizes":[]},"content_typography_typography":"custom","content_typography_font_family":"Noto Sans","content_typography_font_size":{"unit":"px","size":16,"sizes":[]},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding":{"unit":"px","top":"0","right":"38","bottom":"60","left":"38","isLinked":false},"title_padding_tablet":{"unit":"px","top":"38","right":"30","bottom":"38","left":"15","isLinked":false},"icon_width_tablet":{"unit":"px","size":0,"sizes":[]},"icon_size":{"unit":"px","size":20,"sizes":[]},"content_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"home-1-2":[{"id":"5486e45","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50"},"elements":[{"id":"99d9266","elType":"column","settings":{"_column_size":100},"elements":[{"id":"14b655b","elType":"widget","settings":{"rev_alias":"slide-home1"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"47f0e4e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","background_background":"gradient","background_color":"#1d1d1d","background_color_stop":{"unit":"%","size":60,"sizes":[]},"background_color_b":"#ffffff","background_color_b_stop":{"unit":"%","size":40,"sizes":[]},"background_gradient_angle":{"unit":"deg","size":90,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"overflow":"hidden","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/upcoming-ride.png","id":4656},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":50},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_mouse":"yes","osf_section_parallax_rate":20,"_id":"ff489c0"}]},"elements":[{"id":"b216348","elType":"column","settings":{"_column_size":50,"_inline_size":57.98400000000000176214598468504846096038818359375,"space_between_widgets":0,"background_background":"classic","background_color":"#1d1d1d","padding":{"unit":"px","top":"45","right":"110","bottom":"45","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":50,"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"40","left":"15","isLinked":false},"z_index":10},"elements":[{"id":"4e46041","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","z_index":10},"elements":[{"id":"bc181b6","elType":"column","settings":{"_column_size":50,"_inline_size":45.51400000000000289901436190120875835418701171875,"_inline_size_tablet":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"51a3494","elType":"widget","settings":{"title":"upcoming event","header_size":"h3","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"5e02918","elType":"widget","settings":{"title":"<span class=\"c-primary\">himalayas, dec 17-18, 2019<\/span>","header_size":"h4","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","animation_duration":"fast"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"b741908","elType":"column","settings":{"_column_size":50,"_inline_size":54.48599999999999710098563809879124164581298828125,"_inline_size_tablet":100,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"424304e","elType":"widget","settings":{"due_date":"2020-01-24 01:33","label_days":"Days","label_hours":"Hours","label_minutes":"Minutes","label_seconds":"Seconds","box_background_color":"#2a2a2a","box_padding":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"digits_color":"#ffffff","digits_typography_typography":"custom","digits_typography_font_size":{"unit":"px","size":40,"sizes":[]},"digits_typography_line_height":{"unit":"px","size":40,"sizes":[]},"label_typography_typography":"custom","label_typography_font_size":{"unit":"px","size":18,"sizes":[]},"label_typography_text_transform":"uppercase","label_typography_line_height":{"unit":"px","size":18,"sizes":[]},"box_spacing_mobile":{"unit":"px","size":5,"sizes":[]},"box_padding_mobile":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"digits_typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"animation_duration":"fast","_animation_delay":100},"elements":[],"widgetType":"opal-countdown"}],"isInner":true}],"isInner":true},{"id":"658f9ed","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"text","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Upcoming","text_typo_typography":"custom","text_typo_font_family":"Teko","text_typo_font_size":{"unit":"px","size":240,"sizes":[]},"text_typo_font_size_tablet":{"unit":"px","size":"","sizes":[]},"text_typo_font_size_mobile":{"unit":"px","size":"","sizes":[]},"text_typo_font_weight":"500","text_typo_text_transform":"uppercase","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"px","size":60,"sizes":[]},"text_typo_line_height_tablet":{"unit":"em","size":"","sizes":[]},"text_typo_line_height_mobile":{"unit":"em","size":"","sizes":[]},"text_typo_letter_spacing":{"unit":"px","size":"","sizes":[]},"text_typo_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"text_typo_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"text_color":"rgba(255,255,255,0.03)","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":-50,"sizes":[]},"img_layers_hor_position_tablet":{"unit":"px","size":"","sizes":[]},"img_layers_hor_position_mobile":{"unit":"px","size":"","sizes":[]},"img_layers_ver_position":{"unit":"%","size":100,"sizes":[]},"img_layers_ver_position_tablet":{"unit":"px","size":"","sizes":[]},"img_layers_ver_position_mobile":{"unit":"px","size":"","sizes":[]},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-20,"img_layers_align":"left","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":"","img_layers_class":"","_id":"6f2ac83"}],"_element_width":"initial","_position":"absolute","_offset_x":{"unit":"%","size":-55,"sizes":[]},"_offset_y":{"unit":"%","size":110,"sizes":[]}},"elements":[],"widgetType":"opal-images-layers"}],"isInner":false},{"id":"daeb231","elType":"column","settings":{"_column_size":50,"_inline_size":42.01599999999999823785401531495153903961181640625,"content_position":"center","space_between_widgets":0,"padding":{"unit":"px","top":"45","right":"30","bottom":"45","left":"50","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":50,"background_background":"classic","background_color":"#ffffff","padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"40","left":"15","isLinked":false},"z_index":1},"elements":[{"id":"73a10a1","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":-30},"osf_section_parallax_position_v":{"unit":"%","size":-110},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":-10,"_id":"11c5925"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":95},"osf_section_parallax_position_v":{"unit":"%","size":-60},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":-10,"_id":"ca8740c"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":99},"osf_section_parallax_position_v":{"unit":"%","size":10},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":-10,"_id":"f5edda2"}]},"elements":[{"id":"a4ec13a","elType":"column","settings":{"_column_size":50,"_inline_size":58.59700000000000130739863379858434200286865234375,"_inline_size_tablet":100,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ddd67cd","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=1Q3LojC1wf8","border_video_color":"#ffffff","_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg_video.jpg","id":402},"_background_position":"center center","_background_repeat":"no-repeat","_background_size":"cover","_padding":{"unit":"px","top":"50","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-video-popup"}],"isInner":true},{"id":"124ba32","elType":"column","settings":{"_column_size":50,"_inline_size":41.40299999999999869260136620141565799713134765625,"_inline_size_tablet":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"3171a59","elType":"widget","settings":{"title":"Watch Us In<br>\nAction","header_size":"h3","title_color":"#131313","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500"},"elements":[],"widgetType":"heading"},{"id":"952a60e","elType":"widget","settings":{"title":"<span class=\"c-primary\">more photos & videos<\/span>","header_size":"h4","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/photos-album\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"e715d28","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"120","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false}},"elements":[{"id":"b5e2945","elType":"column","settings":{"_column_size":50,"_inline_size":56.58899999999999863575794734060764312744140625,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"a943d77","elType":"widget","settings":{"title":"Welcome to the home of,<br>Boston\'s <span class=\"c-primary\">Motorcycle Club<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"df57943","elType":"widget","settings":{"editor":"If you are looking to find a group of well-established and safe to ride with, you\'ve found us. We were founded as a formal motorcycle club in Boston in 1985, and are still going strong. We focus on safe riding and we also ride for charities that are near and dear to our hearts. Come to a meeting and check us out. Feel free to email us with any questions you may have.","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"7ab67ec","elType":"section","settings":{"gap":"no","structure":"30","content_delay_time":"0.50","layout":"full_width"},"elements":[{"id":"bc01d26","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"b0fac13","elType":"widget","settings":{"ending_number":185,"title":"members","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true},{"id":"40af54e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"30cdeb2","elType":"widget","settings":{"ending_number":48137,"title":"Total KMS by the club","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true},{"id":"60205b8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"63e6bf2","elType":"widget","settings":{"ending_number":219561,"title":"KMs of riding experience","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"9eb1b0f","elType":"column","settings":{"_column_size":50,"_inline_size":43.41100000000000136424205265939235687255859375,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"3fdb971","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/original.png","id":486},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":"","sizes":[]},"text_typo_font_size_tablet":{"unit":"px","size":"","sizes":[]},"text_typo_font_size_mobile":{"unit":"px","size":"","sizes":[]},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":"","sizes":[]},"text_typo_line_height_tablet":{"unit":"em","size":"","sizes":[]},"text_typo_line_height_mobile":{"unit":"em","size":"","sizes":[]},"text_typo_letter_spacing":{"unit":"px","size":"","sizes":[]},"text_typo_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"text_typo_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50,"sizes":[]},"img_layers_hor_position_tablet":{"unit":"px","size":"","sizes":[]},"img_layers_hor_position_mobile":{"unit":"px","size":"","sizes":[]},"img_layers_ver_position":{"unit":"%","size":50,"sizes":[]},"img_layers_ver_position_tablet":{"unit":"px","size":"","sizes":[]},"img_layers_ver_position_mobile":{"unit":"px","size":"","sizes":[]},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"yes","img_layers_animation":"opal-move-up","img_layers_animation_duration":"fast","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":20,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"4182648"}]},"elements":[],"widgetType":"opal-images-layers"}],"isInner":false}],"isInner":false},{"id":"86d9130","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","content_position":"middle","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"overflow":"hidden","background_background":"classic"},"elements":[{"id":"965ab5e","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_position":"center","align":"center"},"elements":[{"id":"281e685","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":-60},"osf_section_parallax_position_v":{"unit":"%","size":-90},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":-10,"_id":"bd21ea8"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-30},"osf_section_parallax_position_v":{"unit":"%","size":105},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":20,"_id":"e17ceda"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":45},"osf_section_parallax_position_v":{"unit":"%","size":60},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":"","osf_section_parallax_rate":20,"_id":"61d5bbc"}],"content_width":{"unit":"px","size":440,"sizes":[]}},"elements":[{"id":"6b25297","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"6025470","elType":"widget","settings":{"title":"become one of us<br><span class=\"c-primary\">join the club<\/span>","title_color":"#131313","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"header_size":"span","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"642a601","elType":"widget","settings":{"spacing_icon":{"unit":"px","size":0,"sizes":[]},"hide_icon":"none","width_input":{"unit":"%","size":100,"sizes":[]},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"setting_block":"yes","width_button":{"unit":"%","size":50,"sizes":[]},"width_input_tablet":{"unit":"%","size":100,"sizes":[]},"width_button_tablet":{"unit":"%","size":40,"sizes":[]},"input_bacground":"#f0f0f0","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_input_mobile":{"unit":"%","size":100,"sizes":[]},"width_button_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"2dc079b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_position":"center center","background_repeat":"no-repeat","background_size":"cover","background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(0,0,0,0.25)","_inline_size_tablet":100,"css_classes":"overflow-hidden"},"elements":[{"id":"51db9d0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-newsletter.jpg","id":500},"image_size":"full","align":"center","align_tablet":"center","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"background_hover_transition":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]},"hover_animation":"grow","animation_duration":"fast","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"8305f7f","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"5219873","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"aa53eef","elType":"widget","settings":{"title":"our missions","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"sub_title":"what we do","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7a6e693","elType":"section","settings":{"gap":"no","structure":"30","content_delay_time":"0.50"},"elements":[{"id":"a38e525","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"0b1dd1d","elType":"widget","settings":{"title_text":"Ride outs","description_text":"Lex Rider regularly organises ride-outs suitable for all types of bikes and speeds. Our ride-outs range from short, local routes, to continental travel.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-helmet","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-helmet","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"713a308","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"ca57a57","elType":"widget","settings":{"title_text":"support","description_text":"Establish a brotherhood of other like minded bikers who take an oath to stand with us, to support and defend the Constitution against all enemies, foreign and domestic.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-pistons","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-pistons","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"a60a39e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"33feefa","elType":"widget","settings":{"title_text":"communities","description_text":"Provide an opportunity to give back to communities as well as provide assistance to veterans related injuries via charities, benefits, and donations.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-tyre","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-tyre","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"c2c0e07","elType":"section","settings":{"stretch_section":"section-stretched","height":"min-height","custom_height":{"unit":"px","size":600,"sizes":[]},"content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"background_position":"center center","background_repeat":"no-repeat","background_size":"cover","section_parallax_on":"yes","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"custom_height_tablet":{"unit":"px","size":500,"sizes":[]},"custom_height_mobile":{"unit":"px","size":400,"sizes":[]}},"elements":[{"id":"d5e2efc","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b543239","elType":"widget","settings":{"layout":"above","bg_image":{"url":"","id":""},"title":"Come Ride with Us!","description":"HIMALAYAS CALLING","button":"join this ride","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"title_typography_font_weight":"500","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"title_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"title_spacing":{"unit":"px","size":75,"sizes":[]},"description_typography_typography":"custom","description_typography_font_family":"Teko","description_typography_font_size":{"unit":"px","size":120,"sizes":[]},"description_typography_font_weight":"500","description_typography_line_height":{"unit":"em","size":0.5,"sizes":[]},"description_spacing":{"unit":"px","size":60,"sizes":[]},"content_bg_color":"rgba(0,0,0,0)","title_color":"#ffffff","description_color":"#ffffff","button_size":"md","button_type":"primary","title_spacing_mobile":{"unit":"px","size":30,"sizes":[]},"description_typography_font_size_tablet":{"unit":"px","size":100,"sizes":[]},"description_typography_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"description_typography_line_height_mobile":{"unit":"px","size":50,"sizes":[]},"description_spacing_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false},{"id":"57bf01c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"110","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"content_position":"middle"},"elements":[{"id":"bd1d56c","elType":"column","settings":{"_column_size":50,"_inline_size":33.3299999999999982946974341757595539093017578125,"space_between_widgets":0},"elements":[{"id":"d4cd19c","elType":"widget","settings":{"title":"Meet our<br>Crew<br>members","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","sub_title":"our team","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast","align":"left","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"cea0b43","elType":"column","settings":{"_column_size":50,"_inline_size":66.6700000000000017053025658242404460906982421875,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"b561561","elType":"widget","settings":{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","facebook":"www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","name_space":{"unit":"px","size":5,"sizes":[]},"name_text_color":"#ffffff","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":30,"sizes":[]},"name_typography_font_weight":"500","name_typography_text_transform":"uppercase","job_space":{"unit":"px","size":30,"sizes":[]},"job_text_color":"#ffffff","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":18,"sizes":[]},"job_typography_font_weight":"500","job_typography_text_transform":"uppercase","instagram":"#","team_items":[{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"view":"traditional","name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"136196d"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"view":"traditional","name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"3fb6efa"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"view":"traditional","name":"ron cater","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team5.jpg","id":3955},"job":"member","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"306d176"}],"columns":"2","columns_tablet":"1","gutter":{"unit":"px","size":30,"sizes":[]},"team_align":"flex-end","team_align_mobile":"flex-start","enable_carousel":"yes","navigation":"none","pause_on_hover":"","infinite":"","autoplay":"","_animation":"opal-move-up","animation_duration":"fast","gutter_mobile":{"unit":"px","size":15,"sizes":[]},"team_align_tablet":"center","_margin":{"unit":"px","top":"0","right":"-15","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-team-box"}],"isInner":false}],"isInner":false},{"id":"b4b3210","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"content_position":"middle","overflow":"hidden"},"elements":[{"id":"0fd7c74","elType":"column","settings":{"_column_size":50,"_inline_size":49.844999999999998863131622783839702606201171875,"space_between_widgets":0,"background_background":"classic","background_position":"top left","background_repeat":"no-repeat","background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(0,0,0,0.4)","_inline_size_tablet":100,"background_size":"cover","css_classes":"overflow-hidden"},"elements":[{"id":"b1b5732","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_img.jpg","id":3842},"image_size":"custom","image_custom_dimension":{"width":"645","height":"760"},"align":"left","align_tablet":"center","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"background_hover_transition":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]},"hover_animation":"grow","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"084dc9d","elType":"column","settings":{"_column_size":50,"_inline_size":50.155000000000001136868377216160297393798828125,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ddacf27","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"px","size":-130},"osf_section_parallax_position_v":{"unit":"px","size":-110},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"8627540"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":90},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"5106c33"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":51},"osf_section_parallax_position_v":{"unit":"%","size":80},"osf_section_parallax_background_size":"auto","osf_section_parallax_z_index":1,"osf_section_parallax_rate":-10,"_id":"810a9ee"}],"padding":{"unit":"px","top":"60","right":"100","bottom":"60","left":"100","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[{"id":"436ba12","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"ef6e1c6","elType":"widget","settings":{"title":"WHAT our members SAY","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"TESTIMONIALS","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#000000","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","align":"left","align_tablet":"center"},"elements":[],"widgetType":"heading"},{"id":"f031870","elType":"widget","settings":{"testimonials":[{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata1.jpg","id":3627},"testimonial_name":"Alex Bold","testimonial_job":"member","due_date":"","_id":"e5c390b"},{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata3.jpg","id":3635},"testimonial_name":"John Doe","testimonial_job":"member","due_date":"","_id":"3587f8f"}],"testimonial_image_size":"custom","testimonial_image_custom_dimension":{"width":"60","height":"60"},"testimonial_alignment":"left","wrapper_bgcolor":"#ffffff","wrapper_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"wrapper_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_content_color":"#000000","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":24,"sizes":[]},"content_typography_font_style":"italic","content_typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"enable_carousel":"yes","navigation":"arrows","_animation":"opal-move-up","animation_duration":"fast","content_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"content_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"6cfa577","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false}},"elements":[{"id":"b80f0fa","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"37f67c5","elType":"widget","settings":{"title":"our rides","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"sub_title":"riding report","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"b58f16a","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-1","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast","button_ajax_background_background":"classic","button_ajax_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-blog.svg","id":5342},"button_ajax_background_position":"bottom left","button_ajax_background_repeat":"no-repeat","post_type":"osf_report"},"elements":[],"widgetType":"opal-post-grid"},{"id":"7218c33","elType":"widget","settings":{"text":"explore more","align":"center","_margin":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"3f2c86a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-instagram.jpg","id":3872},"background_position":"top center","background_repeat":"no-repeat","section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"140","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"140","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"1b87068","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"align":"center"},"elements":[{"id":"d8bf89f","elType":"widget","settings":{"title":" ","header_size":"h3","align":"center","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"_element_vertical_align":"center","sub_title":"follow us on instagram","typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"ccb7899","elType":"widget","settings":{"username":"lex.riderr","per_row":"6","size":"large","image_spacing":{"unit":"px","size":0,"sizes":[]},"per_row_tablet":"3","per_row_mobile":"2","_animation":"opal-move-up","animation_duration":"fast","_background_background":"classic"},"elements":[],"widgetType":"opal-instagram"}],"isInner":false}],"isInner":false}],"home-1":[{"id":"5486e45","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"99d9266","elType":"column","settings":{"_column_size":100},"elements":[{"id":"14b655b","elType":"widget","settings":{"rev_alias":"slide-home1"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"47f0e4e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","background_background":"gradient","background_color":"#1d1d1d","background_color_stop":{"unit":"%","size":60,"sizes":[]},"background_color_b":"#ffffff","background_color_b_stop":{"unit":"%","size":40,"sizes":[]},"background_gradient_angle":{"unit":"deg","size":90,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"overflow":"hidden","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/upcoming-ride.png","id":4656},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":50},"osf_section_parallax_z_index":"","osf_section_parallax_mouse":"yes","osf_section_parallax_rate":20,"_id":"ff489c0"}]},"elements":[{"id":"b216348","elType":"column","settings":{"_column_size":50,"_inline_size":57.98400000000000176214598468504846096038818359375,"space_between_widgets":0,"background_background":"classic","background_color":"#1d1d1d","padding":{"unit":"px","top":"45","right":"110","bottom":"45","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":50,"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"40","left":"15","isLinked":false},"z_index":10},"elements":[{"id":"4e46041","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","z_index":10,"osf_section_parallax_layer":[]},"elements":[{"id":"bc181b6","elType":"column","settings":{"_column_size":50,"_inline_size":45.51400000000000289901436190120875835418701171875,"_inline_size_tablet":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"51a3494","elType":"widget","settings":{"title":"upcoming event","header_size":"h3","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"5e02918","elType":"widget","settings":{"title":"<span class=\"c-primary\">himalayas, dec 17-18, 2019<\/span>","header_size":"h4","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","animation_duration":"fast"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"b741908","elType":"column","settings":{"_column_size":50,"_inline_size":54.48599999999999710098563809879124164581298828125,"_inline_size_tablet":100,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"424304e","elType":"widget","settings":{"due_date":"2022-04-30 01:33","label_days":"Days","label_hours":"Hours","label_minutes":"Minutes","label_seconds":"Seconds","box_background_color":"#2a2a2a","box_padding":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"digits_color":"#ffffff","digits_typography_typography":"custom","digits_typography_font_size":{"unit":"px","size":40,"sizes":[]},"digits_typography_line_height":{"unit":"px","size":40,"sizes":[]},"label_typography_typography":"custom","label_typography_font_size":{"unit":"px","size":18,"sizes":[]},"label_typography_text_transform":"uppercase","label_typography_line_height":{"unit":"px","size":18,"sizes":[]},"box_spacing_mobile":{"unit":"px","size":5,"sizes":[]},"box_padding_mobile":{"unit":"px","top":"10","right":"10","bottom":"10","left":"10","isLinked":true},"digits_typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"animation_duration":"fast","_animation_delay":100},"elements":[],"widgetType":"opal-countdown"}],"isInner":true}],"isInner":true},{"id":"658f9ed","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"text","text_layers":"Upcoming","text_typo_typography":"custom","text_typo_font_family":"Teko","text_typo_font_size":{"unit":"px","size":240,"sizes":[]},"text_typo_font_weight":"500","text_typo_text_transform":"uppercase","text_typo_line_height":{"unit":"px","size":60,"sizes":[]},"text_color":"rgba(255,255,255,0.03)","img_layers_hor_position":{"unit":"%","size":-50,"sizes":[]},"img_layers_ver_position":{"unit":"%","size":100,"sizes":[]},"img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_mouse":"yes","img_layers_rate":-20,"img_layers_zindex":"","_id":"6f2ac83"}],"_element_width":"initial","_position":"absolute","_offset_x":{"unit":"%","size":-55,"sizes":[]},"_offset_y":{"unit":"%","size":110,"sizes":[]}},"elements":[],"widgetType":"opal-images-layers"}],"isInner":false},{"id":"daeb231","elType":"column","settings":{"_column_size":50,"_inline_size":42.01599999999999823785401531495153903961181640625,"content_position":"center","space_between_widgets":0,"padding":{"unit":"px","top":"45","right":"30","bottom":"45","left":"50","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":50,"background_background":"classic","background_color":"#ffffff","padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"40","left":"15","isLinked":false},"z_index":1},"elements":[{"id":"73a10a1","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":-30},"osf_section_parallax_position_v":{"unit":"%","size":-110},"osf_section_parallax_z_index":"","_id":"11c5925"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":95},"osf_section_parallax_position_v":{"unit":"%","size":-60},"osf_section_parallax_z_index":"","_id":"ca8740c"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":99},"osf_section_parallax_position_v":{"unit":"%","size":10},"osf_section_parallax_z_index":"","_id":"f5edda2"}]},"elements":[{"id":"a4ec13a","elType":"column","settings":{"_column_size":50,"_inline_size":58.59700000000000130739863379858434200286865234375,"_inline_size_tablet":100,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ddd67cd","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=1Q3LojC1wf8","border_video_color":"#ffffff","_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg_video.jpg","id":402},"_background_position":"center center","_background_repeat":"no-repeat","_background_size":"cover","_padding":{"unit":"px","top":"50","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-video-popup"}],"isInner":true},{"id":"124ba32","elType":"column","settings":{"_column_size":50,"_inline_size":41.40299999999999869260136620141565799713134765625,"_inline_size_tablet":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"3171a59","elType":"widget","settings":{"title":"Watch Us In<br>\nAction","header_size":"h3","title_color":"#131313","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500"},"elements":[],"widgetType":"heading"},{"id":"952a60e","elType":"widget","settings":{"title":"<span class=\"c-primary\">more photos & videos<\/span>","header_size":"h4","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/photos-album\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"e715d28","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"120","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"b5e2945","elType":"column","settings":{"_column_size":50,"_inline_size":56.58899999999999863575794734060764312744140625,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"a943d77","elType":"widget","settings":{"title":"Welcome to the home of,<br>Boston\'s <span class=\"c-primary\">Motorcycle Club<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"df57943","elType":"widget","settings":{"editor":"If you are looking to find a group of well-established and safe to ride with, you\'ve found us. We were founded as a formal motorcycle club in Boston in 1985, and are still going strong. We focus on safe riding and we also ride for charities that are near and dear to our hearts. Come to a meeting and check us out. Feel free to email us with any questions you may have.","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"7ab67ec","elType":"section","settings":{"gap":"no","structure":"30","content_delay_time":"0.50","layout":"full_width","osf_section_parallax_layer":[]},"elements":[{"id":"bc01d26","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"b0fac13","elType":"widget","settings":{"ending_number":185,"title":"members","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true},{"id":"40af54e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"30cdeb2","elType":"widget","settings":{"ending_number":48137,"title":"Total KMS by the club","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true},{"id":"60205b8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"63e6bf2","elType":"widget","settings":{"ending_number":219561,"title":"KMs of riding experience","position":"flex-start","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_number_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"typography_number_font_weight":"500","title_color":"#ffffff","typography_title_typography":"custom","typography_title_font_size":{"unit":"px","size":18,"sizes":[]},"typography_title_font_weight":"500","typography_title_text_transform":"uppercase","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"divider_width":{"unit":"%","size":100,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"divider_height":{"unit":"px","size":3,"sizes":[]}},"elements":[],"widgetType":"counter"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"9eb1b0f","elType":"column","settings":{"_column_size":50,"_inline_size":43.41100000000000136424205265939235687255859375,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"3fdb971","elType":"widget","settings":{"img_layers_images_repeater":[{"img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/original.png","id":486},"text_layers":"Lorem ipsum dolor sit amet","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_animation_switcher":"yes","img_layers_animation":"opal-move-up","img_layers_animation_duration":"fast","img_layers_mouse":"yes","img_layers_rate":20,"img_layers_align":"center","_id":"4182648"}]},"elements":[],"widgetType":"opal-images-layers"}],"isInner":false}],"isInner":false},{"id":"86d9130","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","content_position":"middle","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"overflow":"hidden","background_background":"classic","osf_section_parallax_layer":[]},"elements":[{"id":"965ab5e","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_position":"center","align":"center"},"elements":[{"id":"281e685","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":-60},"osf_section_parallax_position_v":{"unit":"%","size":-90},"osf_section_parallax_z_index":"","_id":"bd21ea8"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-30},"osf_section_parallax_position_v":{"unit":"%","size":105},"osf_section_parallax_z_index":"","osf_section_parallax_rate":20,"_id":"e17ceda"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":45},"osf_section_parallax_position_v":{"unit":"%","size":60},"osf_section_parallax_z_index":"","osf_section_parallax_rate":20,"_id":"61d5bbc"}],"content_width":{"unit":"px","size":440,"sizes":[]}},"elements":[{"id":"6b25297","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"6025470","elType":"widget","settings":{"title":"become one of us<br><span class=\"c-primary\">join the club<\/span>","title_color":"#131313","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"header_size":"span","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"642a601","elType":"widget","settings":{"spacing_icon":{"unit":"px","size":0,"sizes":[]},"hide_icon":"none","width_input":{"unit":"%","size":100,"sizes":[]},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"setting_block":"yes","width_button":{"unit":"%","size":50,"sizes":[]},"width_input_tablet":{"unit":"%","size":100,"sizes":[]},"width_button_tablet":{"unit":"%","size":40,"sizes":[]},"input_bacground":"#f0f0f0","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_input_mobile":{"unit":"%","size":100,"sizes":[]},"width_button_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"2dc079b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_position":"center center","background_repeat":"no-repeat","background_size":"cover","background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(0,0,0,0.25)","_inline_size_tablet":100,"css_classes":"overflow-hidden"},"elements":[{"id":"51db9d0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-newsletter.jpg","id":500},"image_size":"full","align":"center","align_tablet":"center","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"background_hover_transition":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]},"hover_animation":"grow","animation_duration":"fast","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"8305f7f","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"osf_section_parallax_layer":[]},"elements":[{"id":"5219873","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"aa53eef","elType":"widget","settings":{"title":"our missions","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"sub_title":"what we do","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7a6e693","elType":"section","settings":{"gap":"no","structure":"30","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"a38e525","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"0b1dd1d","elType":"widget","settings":{"title_text":"Ride outs","description_text":"Lex Rider regularly organises ride-outs suitable for all types of bikes and speeds. Our ride-outs range from short, local routes, to continental travel.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-helmet","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-helmet","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"713a308","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"ca57a57","elType":"widget","settings":{"title_text":"support","description_text":"Establish a brotherhood of other like minded bikers who take an oath to stand with us, to support and defend the Constitution against all enemies, foreign and domestic.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-pistons","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-pistons","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"a60a39e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"33feefa","elType":"widget","settings":{"title_text":"communities","description_text":"Provide an opportunity to give back to communities as well as provide assistance to veterans related injuries via charities, benefits, and donations.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"icon":"opal-icon-tyre","icon_size":{"unit":"px","size":64,"sizes":[]},"_padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313","selected_icon":{"value":"fas opal-icon-tyre","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"c2c0e07","elType":"section","settings":{"stretch_section":"section-stretched","height":"min-height","custom_height":{"unit":"px","size":600,"sizes":[]},"content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"background_position":"center center","background_repeat":"no-repeat","background_size":"cover","section_parallax_on":"yes","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"custom_height_tablet":{"unit":"px","size":500,"sizes":[]},"custom_height_mobile":{"unit":"px","size":400,"sizes":[]},"osf_section_parallax_layer":[]},"elements":[{"id":"d5e2efc","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b543239","elType":"widget","settings":{"layout":"above","bg_image":{"url":"","id":""},"title":"Come Ride with Us!","description":"HIMALAYAS CALLING","button":"join this ride","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"title_typography_font_weight":"500","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"title_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"title_spacing":{"unit":"px","size":75,"sizes":[]},"description_typography_typography":"custom","description_typography_font_family":"Teko","description_typography_font_size":{"unit":"px","size":120,"sizes":[]},"description_typography_font_weight":"500","description_typography_line_height":{"unit":"em","size":0.5,"sizes":[]},"description_spacing":{"unit":"px","size":60,"sizes":[]},"content_bg_color":"rgba(0,0,0,0)","title_color":"#ffffff","description_color":"#ffffff","button_size":"md","button_type":"primary","title_spacing_mobile":{"unit":"px","size":30,"sizes":[]},"description_typography_font_size_tablet":{"unit":"px","size":100,"sizes":[]},"description_typography_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"description_typography_line_height_mobile":{"unit":"px","size":50,"sizes":[]},"description_spacing_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false},{"id":"57bf01c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"110","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"content_position":"middle","osf_section_parallax_layer":[]},"elements":[{"id":"bd1d56c","elType":"column","settings":{"_column_size":50,"_inline_size":33.3299999999999982946974341757595539093017578125,"space_between_widgets":0},"elements":[{"id":"d4cd19c","elType":"widget","settings":{"title":"Meet our<br>Crew<br>members","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","sub_title":"our team","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast","align":"left","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"cea0b43","elType":"column","settings":{"_column_size":50,"_inline_size":66.6700000000000017053025658242404460906982421875,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"b561561","elType":"widget","settings":{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","facebook":"www.facebook.com\/opalwordpress","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","google":"https:\/\/plus.google.com\/u\/0\/+WPOpal","name_space":{"unit":"px","size":5,"sizes":[]},"name_text_color":"#ffffff","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":30,"sizes":[]},"name_typography_font_weight":"500","name_typography_text_transform":"uppercase","job_space":{"unit":"px","size":30,"sizes":[]},"job_text_color":"#ffffff","job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":18,"sizes":[]},"job_typography_font_weight":"500","job_typography_text_transform":"uppercase","instagram":"#","team_items":[{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"136196d"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"3fb6efa"},{"thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"411","height":"500"},"name":"ron cater","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team5.jpg","id":3955},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"306d176"}],"columns":"2","columns_tablet":"1","gutter":{"unit":"px","size":30,"sizes":[]},"team_align":"flex-end","team_align_mobile":"flex-start","enable_carousel":"yes","navigation":"none","pause_on_hover":"","infinite":"","autoplay":"","_animation":"opal-move-up","animation_duration":"fast","gutter_mobile":{"unit":"px","size":15,"sizes":[]},"team_align_tablet":"center","_margin":{"unit":"px","top":"0","right":"-15","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-team-box"}],"isInner":false}],"isInner":false},{"id":"b4b3210","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"content_position":"middle","overflow":"hidden","osf_section_parallax_layer":[]},"elements":[{"id":"0fd7c74","elType":"column","settings":{"_column_size":50,"_inline_size":49.844999999999998863131622783839702606201171875,"space_between_widgets":0,"background_background":"classic","background_position":"top left","background_repeat":"no-repeat","background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(0,0,0,0.4)","_inline_size_tablet":100,"background_size":"cover","css_classes":"overflow-hidden"},"elements":[{"id":"b1b5732","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_img.jpg","id":3842},"image_size":"custom","image_custom_dimension":{"width":"645","height":"760"},"align":"left","align_tablet":"center","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875,"sizes":[]},"background_hover_transition":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875,"sizes":[]},"hover_animation":"grow","_css_classes":"img-animated"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"084dc9d","elType":"column","settings":{"_column_size":50,"_inline_size":50.155000000000001136868377216160297393798828125,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ddacf27","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"px","size":-130},"osf_section_parallax_position_v":{"unit":"px","size":-110},"_id":"8627540"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":90},"_id":"5106c33"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":51},"osf_section_parallax_position_v":{"unit":"%","size":80},"_id":"810a9ee"}],"padding":{"unit":"px","top":"60","right":"100","bottom":"60","left":"100","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"30","bottom":"60","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[{"id":"436ba12","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"ef6e1c6","elType":"widget","settings":{"title":"WHAT our members SAY","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"TESTIMONIALS","typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#000000","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","align":"left","align_tablet":"center"},"elements":[],"widgetType":"heading"},{"id":"f031870","elType":"widget","settings":{"testimonials":[{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata1.jpg","id":3627},"testimonial_name":"Alex Bold","testimonial_job":"member","due_date":"","_id":"e5c390b"},{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata3.jpg","id":3635},"testimonial_name":"John Doe","testimonial_job":"member","due_date":"","_id":"3587f8f"}],"testimonial_image_size":"custom","testimonial_image_custom_dimension":{"width":"60","height":"60"},"testimonial_alignment":"left","wrapper_bgcolor":"#ffffff","wrapper_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"wrapper_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_content_color":"#000000","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":24,"sizes":[]},"content_typography_font_style":"italic","content_typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"enable_carousel":"yes","navigation":"arrows","_animation":"opal-move-up","animation_duration":"fast","content_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"content_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"6cfa577","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"b80f0fa","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"37f67c5","elType":"widget","settings":{"title":"our rides","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":60,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":40,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"sub_title":"riding report","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":20,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"b58f16a","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-1","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast","button_ajax_background_background":"classic","button_ajax_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-blog.svg","id":5342},"button_ajax_background_position":"bottom left","button_ajax_background_repeat":"no-repeat","post_type":"osf_report"},"elements":[],"widgetType":"opal-post-grid"},{"id":"7218c33","elType":"widget","settings":{"text":"explore more","align":"center","_margin":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"3f2c86a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-instagram.jpg","id":3872},"background_position":"top center","background_repeat":"no-repeat","section_parallax_on":"yes","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"140","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"140","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"1b87068","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"align":"center"},"elements":[{"id":"d8bf89f","elType":"widget","settings":{"title":" ","header_size":"h3","align":"center","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"_element_vertical_align":"center","sub_title":"Our gallery","typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":18,"sizes":[]},"subtitle_typography_font_weight":"500","subtitle_typography_text_transform":"uppercase","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d4beb2b","elType":"widget","settings":{"carousel":[{"id":6548,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-2.jpg"},{"id":6549,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-3.jpg"},{"id":6555,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-9.jpg"},{"id":6554,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-8.jpg"},{"id":6547,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-1.jpg"}],"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"215","height":"215"},"slides_to_show":"5","slides_to_show_tablet":"4","slides_to_show_mobile":"2","image_stretch":"yes","navigation":"none","image_spacing":"custom","image_spacing_custom":{"unit":"px","size":0,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-50","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"-9","left":"0","isLinked":false}},"elements":[],"widgetType":"image-carousel"}],"isInner":false}],"isInner":false}],"header-1":[{"id":"7fea3eb","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"7","right":"30","bottom":"7","left":"30","isLinked":false},"background_background":"classic","background_color":"#1d1d1d","hide_mobile":"hidden-phone"},"elements":[{"id":"aa73e72","elType":"column","settings":{"_column_size":50,"_inline_size":85.2450000000000045474735088646411895751953125,"space_between_widgets":0},"elements":[{"id":"14dc29c","elType":"widget","settings":{"editor":"<p>Welcome to our club!<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"77d641a","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"7464cb0","elType":"widget","settings":{"editor":"<p><a href=\"mailto:info@example.com\">info@example.com<\/a><\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"333aab8","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"0681bb3","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"53695d6","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-linkedin","_id":"0f53b59","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"1152568","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-youtube","_id":"e128dab","link":{"url":"#","is_external":"true","nofollow":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"rgba(0,0,0,0)","icon_secondary_color":"#777777","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":0,"sizes":[]},"icon_spacing":{"unit":"px","size":20,"sizes":[]},"hover_primary_color":"rgba(0,0,0,0)","_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"8833d21","elType":"column","settings":{"_column_size":50,"_inline_size":14.7550000000000007815970093361102044582366943359375},"elements":[{"id":"90c8d01","elType":"widget","settings":{"title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"Search...","button_text":"Search","text_account":"","title_cart":"","title_cart_hover":"","show_count":"yes","show_account":"yes","show_icon_account":"yes","show_search":"yes","show_cart":"yes","toggle_size":{"unit":"px","size":18,"sizes":[]},"config_account_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"overlay_background_color":"rgba(0,0,0,0.7)","input_text_color":"#ffffff","input_border_color":"#ffffff","input_text_color_focus":"#ffffff","input_border_color_focus":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0,"sizes":[]},"toggle_color":"#ffffff","toggle_color_hover":"#e81938","toggle_icon_size":{"unit":"px","size":100,"sizes":[]},"icon_color":"#ffffff","icon_hover_color":"#e81938","icon_account_size":{"unit":"px","size":18,"sizes":[]}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"62ee0a8","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"34","right":"30","bottom":"34","left":"30","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"rgba(255,255,255,0.2)","background_background":"classic","border_width_tablet":{"unit":"px","top":"1","right":"0","bottom":"1","left":"0","isLinked":false},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"25","right":"30","bottom":"25","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false}},"elements":[{"id":"4d631f7","elType":"column","settings":{"_column_size":50,"_inline_size":14.6910000000000007247535904753021895885467529296875,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"83fad5e","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width_mobile":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"14b706d","elType":"column","settings":{"_column_size":50,"_inline_size":85.308999999999997498889570124447345733642578125,"space_between_widgets":0,"content_position":"center","align":"flex-end","_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"7ed7317","elType":"widget","settings":{"menu":"mainmenu","align_items":"center","align_items_tablet":"center","indicator":"angle","subMenusMinWidth":{"unit":"px","size":250,"sizes":[]},"dropdown":"mobile","toggle_align":"right","menu-toggle-title":"","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":18,"sizes":[]},"menu_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"uppercase","color_menu_item":"#ffffff","show_dot_item":"yes","padding_horizontal_menu_item":{"unit":"px","size":25,"sizes":[]},"padding_horizontal_menu_item_tablet":{"unit":"px","size":20,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":10,"sizes":[]},"padding_vertical_menu_item_tablet":{"unit":"px","size":5,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"background_color_dropdown_item":"#ffffff","background_color_dropdown_item_hover":"rgba(0,0,0,0.065)","dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":16,"sizes":[]},"dropdown_typography_font_weight":"500","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item":{"unit":"px","size":25,"sizes":[]},"padding_vertical_dropdown_item":{"unit":"px","size":10,"sizes":[]},"spacing_vertical_dropdown_item":{"unit":"px","size":0,"sizes":[]},"dropdown_top_distance":{"unit":"px","size":0,"sizes":[]},"dropdown_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"toggle_icon_color":"#ffffff","toggle_icon_color_hover":"#e81938","toggle_background_color_hover":"rgba(0,0,0,0)","toggle_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_element_width":"auto","_element_width_tablet":"inherit","_element_vertical_align":"center","full_width":"stretch","dropdown_layout":"canvas","size_icon_togle_mobile":{"unit":"px","size":25,"sizes":[]}},"elements":[],"widgetType":"opal-nav-menu"},{"id":"3b2c2bb","elType":"widget","settings":{"text":"join the club","_element_width":"auto","_element_vertical_align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"40","isLinked":false},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","contact_slug":"contact-form"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"footer-02":[{"id":"8a90f9b","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#1a1a1a","padding":{"unit":"px","top":"125","right":"30","bottom":"110","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"70","right":"30","bottom":"70","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"15","bottom":"70","left":"15","isLinked":false},"border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#313131"},"elements":[{"id":"dc2ffb7","elType":"column","settings":{"_column_size":33,"_inline_size":58.6820000000000021600499167107045650482177734375,"space_between_widgets":0,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"230be0e","elType":"widget","settings":{"title":"do you have questions? <br>do not wait, <span class=\"c-primary\">let\u2019s talk<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"51","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"746ff71","elType":"widget","settings":{"view":"inline","icon_list":[{"text":"+(84) 22 4130 0555","icon":"opal-icon-phone-square","_id":"2f1b5eb","link":{"url":"","is_external":"","nofollow":""}},{"text":"contact@example.com","icon":"opal-icon-envelope-open-text","_id":"525f58b","link":{"url":"#","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":24,"sizes":[]},"text_indent":{"unit":"px","size":14,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Teko","icon_typography_font_size":{"unit":"px","size":40,"sizes":[]},"icon_typography_font_weight":"500","text_color":"#ffffff","list_item_margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"list_item_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_align_mobile":"center","icon_typography_font_size_tablet":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"icon-list"}],"isInner":false},{"id":"78330c5","elType":"column","settings":{"_column_size":33,"_inline_size":22.318000000000001392663762089796364307403564453125,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"f5d761f","elType":"widget","settings":{"title":"head office","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"3b1b736","elType":"widget","settings":{"editor":"<p>Box 565, <br \/>Charlestown, Nevis, <br \/>West Indies, <br \/>Caribbean<\/p>","align_mobile":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"8391629","elType":"widget","settings":{"editor":"<p><a href=\"https:\/\/www.google.com\/maps?ll=51.523767,-0.158556&amp;z=16&amp;t=m&amp;hl=en&amp;gl=US&amp;mapclient=embed&amp;q=221B+Baker+St+Marylebone,+London+NW1+6XE+UK\" target=\"_blank\" rel=\"noopener\">view map<\/a><\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12,"sizes":[]},"typography_text_transform":"uppercase","border_link_border":"solid","border_link_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_link_color":"rgba(0,0,0,0)","link_color":"#e81938","link_hover_color":"#e81938","link_hover_border_color":"#e81938"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"b9670a0","elType":"column","settings":{"_column_size":33,"_inline_size":18.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"8243377","elType":"widget","settings":{"title":"quick links","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"bc24f30","elType":"widget","settings":{"menu":"quick-links","layout":"vertical","pointer":"dot","indicator":"none","enable_mobile_dropdown":"","menu-toggle-title":"Menu","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_family":"Noto Sans","menu_typography_font_size":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"capitalize","padding_horizontal_menu_item":{"unit":"px","size":0,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":4,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"menu_typography_font_weight":"400","align_items_mobile":"center"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false},{"id":"e0a6205","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#131313","padding":{"unit":"px","top":"65","right":"30","bottom":"65","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"9925061","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"4d954a6","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019. All Rights Reserved.<\/p>","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"5d87b11","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"cc961bb","elType":"widget","settings":{"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"cc3f1ab","elType":"column","settings":{"_column_size":33,"_inline_size":null,"content_position":"center","align":"flex-end","space_between_widgets":0},"elements":[{"id":"b9d52b7","elType":"widget","settings":{"title":"social media","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"18","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_element_vertical_align":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","align_mobile":"center","_element_width_mobile":"inherit","typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"6fe5b83","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"b3d40de","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"d7ab8f1","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-google-plus","_id":"905749e","link":{"url":"","is_external":"true","nofollow":""}}],"shape":"square","icon_color":"custom","icon_primary_color":"#000000","icon_secondary_color":"#ffffff","icon_size":{"unit":"px","size":18,"sizes":[]},"icon_padding":{"unit":"em","size":0.75,"sizes":[]},"icon_spacing":{"unit":"px","size":6,"sizes":[]},"hover_primary_color":"#e81938","hover_secondary_color":"#ffffff","_element_width":"auto","_element_vertical_align":"center","align":"right","align_mobile":"center","_element_width_tablet":"inherit"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"header-2":[{"id":"9b1f7cb","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"7","right":"30","bottom":"7","left":"30","isLinked":false},"background_background":"classic","background_color":"#1d1d1d","hide_mobile":"hidden-phone"},"elements":[{"id":"f31c54e","elType":"column","settings":{"_column_size":50,"_inline_size":85.2450000000000045474735088646411895751953125,"space_between_widgets":0},"elements":[{"id":"e49dc71","elType":"widget","settings":{"editor":"<p>Welcome to our club!<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"b628514","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"6b70ec7","elType":"widget","settings":{"editor":"<p><a href=\"mailto:info@example.com\">info@example.com<\/a><\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"1f10358","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"7788600","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"53695d6","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-linkedin","_id":"0f53b59","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"1152568","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-youtube","_id":"e128dab","link":{"url":"#","is_external":"true","nofollow":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"rgba(0,0,0,0)","icon_secondary_color":"#777777","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":0,"sizes":[]},"icon_spacing":{"unit":"px","size":20,"sizes":[]},"hover_primary_color":"rgba(0,0,0,0)","_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"312a7cb","elType":"column","settings":{"_column_size":50,"_inline_size":14.7550000000000007815970093361102044582366943359375},"elements":[{"id":"162a54a","elType":"widget","settings":{"title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"Search...","button_text":"Search","text_account":"","title_cart":"","title_cart_hover":"","show_count":"yes","show_account":"yes","show_icon_account":"yes","show_search":"yes","show_cart":"yes","toggle_size":{"unit":"px","size":18,"sizes":[]},"config_account_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"overlay_background_color":"rgba(0,0,0,0.7)","input_text_color":"#ffffff","input_border_color":"#ffffff","input_text_color_focus":"#ffffff","input_border_color_focus":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0,"sizes":[]},"toggle_color":"#ffffff","toggle_color_hover":"#e81938","toggle_icon_size":{"unit":"px","size":100,"sizes":[]},"icon_color":"#ffffff","icon_hover_color":"#e81938","icon_account_size":{"unit":"px","size":18,"sizes":[]}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"a25c8bf","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"34","right":"30","bottom":"34","left":"30","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"rgba(255,255,255,0.2)","background_background":"classic","border_width_tablet":{"unit":"px","top":"1","right":"0","bottom":"1","left":"0","isLinked":false},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"25","right":"30","bottom":"25","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false},"background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/bg_header_02.jpg","id":6297},"background_position":"center center","background_repeat":"no-repeat","section_parallax_on":"yes"},"elements":[{"id":"ffe58c2","elType":"column","settings":{"_column_size":50,"_inline_size":14.6910000000000007247535904753021895885467529296875,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"5ae6960","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width_mobile":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"5c11d9f","elType":"column","settings":{"_column_size":50,"_inline_size":85.308999999999997498889570124447345733642578125,"space_between_widgets":0,"content_position":"center","align":"flex-end","_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"ef8cfdd","elType":"widget","settings":{"menu":"mainmenu","align_items":"center","align_items_tablet":"center","indicator":"angle","subMenusMinWidth":{"unit":"px","size":250,"sizes":[]},"dropdown":"mobile","toggle_align":"right","menu-toggle-title":"","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":18,"sizes":[]},"menu_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"uppercase","color_menu_item":"#ffffff","show_dot_item":"yes","padding_horizontal_menu_item":{"unit":"px","size":25,"sizes":[]},"padding_horizontal_menu_item_tablet":{"unit":"px","size":15,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":10,"sizes":[]},"padding_vertical_menu_item_tablet":{"unit":"px","size":5,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"background_color_dropdown_item":"#ffffff","background_color_dropdown_item_hover":"rgba(0,0,0,0.065)","dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":16,"sizes":[]},"dropdown_typography_font_weight":"500","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item":{"unit":"px","size":25,"sizes":[]},"padding_vertical_dropdown_item":{"unit":"px","size":10,"sizes":[]},"spacing_vertical_dropdown_item":{"unit":"px","size":0,"sizes":[]},"dropdown_top_distance":{"unit":"px","size":0,"sizes":[]},"dropdown_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"toggle_icon_color":"#ffffff","toggle_icon_color_hover":"#e81938","toggle_background_color_hover":"rgba(0,0,0,0)","toggle_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_element_width":"auto","_element_width_tablet":"inherit","_element_vertical_align":"center","full_width":"stretch","dropdown_layout":"canvas","size_icon_togle_mobile":{"unit":"px","size":25,"sizes":[]}},"elements":[],"widgetType":"opal-nav-menu"},{"id":"328fb70","elType":"widget","settings":{"text":"join the club","_element_width":"auto","_element_vertical_align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"40","isLinked":false},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","contact_slug":"contact-form"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-2":[{"id":"f0ea95e","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"5c93255","elType":"column","settings":{"_column_size":100},"elements":[{"id":"a70dee1","elType":"widget","settings":{"rev_alias":"slide-home2"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"a084063","elType":"section","settings":{"content_delay_time":"0.50","margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"bb951bc","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d70bdd9","elType":"widget","settings":{"title":"Vintage Motorcycle Club<br>of <span class=\"c-primary\">Western Australia<\/span>","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"bc7fbe6","elType":"widget","settings":{"editor":"<p>Dedicated to the Ownership, Use and Preservation of Motorcycles more than 25 years of age<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_padding":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"e1b778f","elType":"section","settings":{"structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"85","right":0,"bottom":"0","left":0,"isLinked":false},"gap":"no","margin_tablet":{"unit":"px","top":"40","right":0,"bottom":"0","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"b2ef91d","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"2e5be9a","elType":"widget","settings":{"skin":"cover","layout":"left","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_banner2_1a.jpg","id":6154},"bg_image_size":"full","title":"Ride outs","description":"","button":"","min-height":{"unit":"px","size":400,"sizes":[]},"alignment":"left","vertical_position":"bottom","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_text_transform":"uppercase","title_typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"title_typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"50","isLinked":false}},"elements":[],"widgetType":"call-to-action"}],"isInner":true},{"id":"76b60e4","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"2b89230","elType":"widget","settings":{"skin":"cover","layout":"left","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_banner2_2a.jpg","id":6160},"bg_image_size":"full","title":"communities","description":"","button":"","min-height":{"unit":"px","size":400,"sizes":[]},"alignment":"left","vertical_position":"bottom","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":40,"sizes":[]},"title_typography_text_transform":"uppercase","title_typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"title_typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200,"padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"50","isLinked":false}},"elements":[],"widgetType":"call-to-action"}],"isInner":true}],"isInner":true},{"id":"c6ba94c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"aa09d5b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"border_width":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"border_color":"#e81938","padding":{"unit":"px","top":"30","right":"50","bottom":"0","left":"50","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"15","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"395757b","elType":"widget","settings":{"editor":"<p>Lex Rider regularly organises ride-outs suitable for all types of bikes and speeds. Our ride-outs range from short, local routes, to continental travel.<\/p>","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"c404267","elType":"widget","settings":{"icon_list":[{"text":"Only men can join","icon":"fa fa-check-circle-o","_id":"4f0f16d","link":{"url":"","is_external":"","nofollow":""}},{"text":"Meetings have strict protocols","icon":"fa fa-check-circle-o","_id":"8192ddc","link":{"url":"","is_external":"","nofollow":""}},{"text":"Prospective members endure brutal hazing","icon":"fa fa-check-circle-o","_id":"e6eb267","link":{"url":"","is_external":"","nofollow":""}}],"space_between":{"unit":"px","size":10,"sizes":[]},"text_color":"#c6c6c6","_padding":{"unit":"px","top":"10","right":"0","bottom":"40","left":"0","isLinked":false},"list_item_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"list_item_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","icon_position":"flex-start","icon_margin":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"2652d9b","elType":"widget","settings":{"weight":{"unit":"px","size":3,"sizes":[]},"color":"#e81938","_animation":"opal-move-up","animation_duration":"fast","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":true},{"id":"f9023ac","elType":"column","settings":{"_column_size":50,"_inline_size":null,"border_width":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"border_color":"#e81938","padding":{"unit":"px","top":"30","right":"50","bottom":"0","left":"50","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"0635ba4","elType":"widget","settings":{"editor":"<p>Provide an opportunity to give back to communities as well as provide assistance to veterans related injuries via charities, benefits, and donations.<\/p>","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"044abdf","elType":"widget","settings":{"icon_list":[{"text":"Members may have to commit acts of violence","icon":"fa fa-check-circle-o","_id":"4f0f16d","link":{"url":"","is_external":"","nofollow":""}},{"text":"Members must be loyal to the club","icon":"fa fa-check-circle-o","_id":"8192ddc","link":{"url":"","is_external":"","nofollow":""}},{"text":"Only one motorcycle club can control an area","icon":"fa fa-check-circle-o","_id":"e6eb267","link":{"url":"","is_external":"","nofollow":""}}],"space_between":{"unit":"px","size":10,"sizes":[]},"text_color":"#c6c6c6","_padding":{"unit":"px","top":"10","right":"0","bottom":"40","left":"0","isLinked":false},"list_item_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","icon_position":"flex-start","icon_margin":{"unit":"px","top":"8","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"359efa6","elType":"widget","settings":{"weight":{"unit":"px","size":3,"sizes":[]},"color":"#e81938","_animation":"opal-move-up","animation_duration":"fast","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"ba0d147","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"110","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"49c8f3e","elType":"column","settings":{"_column_size":100},"elements":[{"id":"997e66d","elType":"widget","settings":{"title":"our rides","decor":"before","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","title_color":"#ffffff","sub_title":"riding report","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"sub_title_color":"#ffffff","sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"326b3ea","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-1","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast","button_ajax_background_background":"classic","button_ajax_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-blog.svg","id":5342},"button_ajax_background_position":"bottom left","button_ajax_background_repeat":"no-repeat","post_type":"osf_report"},"elements":[],"widgetType":"opal-post-grid"},{"id":"c4533ab","elType":"widget","settings":{"text":"explore more","align":"center","_margin":{"unit":"px","top":"10","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"on","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"622da9e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_banner2_3.jpg","id":5661},"margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"160","right":"30","bottom":"240","left":"30","isLinked":false},"section_parallax_on":"yes","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"background_repeat":"no-repeat","padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"a6cca54","elType":"column","settings":{"_column_size":100,"space_between_widgets":5},"elements":[{"id":"50293c3","elType":"widget","settings":{"title":"Become a member and<br>\nget more benefits","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"d6572ed","elType":"widget","settings":{"editor":"<p>187 members and the family keeps growing!<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_line_height":{"unit":"px","size":30,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"4ece07b","elType":"widget","settings":{"text":"join the club","_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"56b3ba8","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"%","size":25},"osf_section_parallax_position_v":{"unit":"%","size":-28},"osf_section_parallax_rate":20,"_id":"f0a0151"}],"margin":{"unit":"px","top":"-180","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"97e0780","elType":"column","settings":{"_column_size":50,"_inline_size":25,"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"isInner":false},{"id":"983bb2b","elType":"column","settings":{"_column_size":50,"_inline_size":75,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"85","right":"100","bottom":"70","left":"100","isLinked":false},"_inline_size_tablet":100,"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"60","left":"30","isLinked":false}},"elements":[{"id":"bdec202","elType":"widget","settings":{"testimonials":[{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata1.jpg","id":3627},"testimonial_name":"Alex Bold","testimonial_job":"member","_id":"eda79e7"},{"testimonial_content":"Such a great community to be part of. The commitment and service you all provide to the community is just outstanding.It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata3.jpg","id":3635},"testimonial_name":"Clara Saura","testimonial_job":"Manager","_id":"fb7fc2b"},{"testimonial_content":"Thank You! I just can\'t get enough of Nouv.\nI want to get a T-Shirt with Nouv on it so I can show it off to everyone.It gave me a really great insight into the diverse ways Americans think.\u201d                                ","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_avata2.jpg","id":3634},"testimonial_name":"John Does","testimonial_job":"Customer","_id":"87f6f69"}],"testimonial_image_size":"custom","testimonial_image_custom_dimension":{"width":"60","height":"60"},"columns":"1","enable_carousel":"yes","navigation":"arrows","pause_on_hover":"","autoplay":"","content_typography_typography":"custom","content_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"content_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"name_typography_typography":"custom","name_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_font_size_mobile":{"unit":"px","size":14,"sizes":[]},"job_typography_text_transform":"uppercase","content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false},{"id":"c32c11e","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"2fc056f","elType":"column","settings":{"_column_size":100},"elements":[{"id":"a74fc85","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"layout":"full_width","padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"aa9ad19","elType":"column","settings":{"_column_size":100,"_inline_size":null},"elements":[{"id":"c70d460","elType":"widget","settings":{"title":"Meet our<br>\nCrew members","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"our team","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase","show_decor":"yes","decor_spacing":{"unit":"px","size":0,"sizes":[]},"align":"left","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true},{"id":"5615470","elType":"section","settings":{"layout":"full_width","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"4ae0fcc","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"727b3fe","elType":"widget","settings":{"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase","team_items":[{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"0abfeae"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"tom riddle","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team4.jpg","id":3954},"job":"founder","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"eaf77c9"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"ron carter","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team2.jpg","id":3952},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"15b570c"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"alex carter","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team3.jpg","id":3953},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"e9e809b"}],"columns":"4","gutter_tablet":{"unit":"px","size":30,"sizes":[]},"team_align_tablet":"flex-start","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-team-box"}],"isInner":true}],"isInner":true},{"id":"4790d74","elType":"section","settings":{"layout":"full_width","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"osf_section_parallax_layer":[]},"elements":[{"id":"a911d67","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"b2a5ceb","elType":"widget","settings":{"name":"john smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team1.jpg","id":3678},"job":"founder","facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","thumbnail_size":"custom","thumbnail_custom_dimension":{"width":"300","height":"365"},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase","team_items":[{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"will stone","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team5.jpg","id":3955},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"0abfeae"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"alan smith","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team6.jpg","id":3956},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"eaf77c9"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"jack brow","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"15b570c"},{"thumbnail_custom_dimension":{"width":"300","height":"365"},"name":"leo m.","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team8.jpg","id":3958},"job":"member","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"e9e809b"}],"columns":"4","gutter_tablet":{"unit":"px","size":30,"sizes":[]},"team_align_tablet":"flex-start","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-team-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"21b255c","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"0f3035a","elType":"column","settings":{"_column_size":100},"elements":[{"id":"fb3e3fa","elType":"widget","settings":{"title":"upcoming event","sub_title":"what\u2019s next","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_text_transform":"uppercase","show_decor":"yes","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"sub_title_color":"#ffffff","sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size":{"unit":"px","size":80,"sizes":[]},"subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"0458b17","elType":"widget","settings":{"gutter":{"unit":"px","size":"","sizes":[]},"enable_carousel":"yes","pause_on_hover":"","autoplay":"","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-events"}],"isInner":false}],"isInner":false},{"id":"3e83e41","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1020,"sizes":[]},"custom_height":{"unit":"px","size":900,"sizes":[]},"structure":"40","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexider_bg2_1.png","id":4132},"background_position":"bottom center","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"450","left":"0","isLinked":false},"background_repeat":"no-repeat","margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"250","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"7de0bbd","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"57f368b","elType":"widget","settings":{"icon":"opal-icon-helmet","primary_color":"#ffffff","size":{"unit":"px","size":60,"sizes":[]}},"elements":[],"widgetType":"icon"},{"id":"b0eca9e","elType":"widget","settings":{"ending_number":185,"title":"members","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_text_transform":"uppercase","divider_width":{"unit":"px","size":220,"sizes":[]},"divider_height":{"unit":"px","size":3,"sizes":[]},"_margin":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"divider_color":"#e81938"},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"09c0c88","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"28ad1a7","elType":"widget","settings":{"icon":"opal-icon-tyre","primary_color":"#ffffff","size":{"unit":"px","size":60,"sizes":[]}},"elements":[],"widgetType":"icon"},{"id":"e6f3f98","elType":"widget","settings":{"ending_number":468,"title":"Club rides","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_text_transform":"uppercase","divider_width":{"unit":"px","size":220,"sizes":[]},"divider_height":{"unit":"px","size":3,"sizes":[]},"_margin":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"divider_color":"#e81938"},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"66be1d3","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"a22b501","elType":"widget","settings":{"icon":"opal-icon-pistons","primary_color":"#ffffff","size":{"unit":"px","size":60,"sizes":[]}},"elements":[],"widgetType":"icon"},{"id":"caaba01","elType":"widget","settings":{"ending_number":1561,"title":"Repairs in workshop ","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_text_transform":"uppercase","divider_width":{"unit":"px","size":220,"sizes":[]},"divider_height":{"unit":"px","size":3,"sizes":[]},"_margin":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"divider_color":"#e81938"},"elements":[],"widgetType":"counter"}],"isInner":false},{"id":"35acb03","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":450},"elements":[{"id":"82e7fd7","elType":"widget","settings":{"icon":"opal-icon-speedometer","primary_color":"#ffffff","size":{"unit":"px","size":60,"sizes":[]}},"elements":[],"widgetType":"icon"},{"id":"bf59721","elType":"widget","settings":{"ending_number":219561,"title":"Total KMS by the club","number_color":"#e81938","typography_number_typography":"custom","typography_number_font_size":{"unit":"px","size":80,"sizes":[]},"typography_number_line_height":{"unit":"px","size":60,"sizes":[]},"title_color":"#ffffff","typography_title_typography":"custom","typography_title_text_transform":"uppercase","divider_width":{"unit":"px","size":220,"sizes":[]},"divider_height":{"unit":"px","size":3,"sizes":[]},"_margin":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"divider_color":"#e81938"},"elements":[],"widgetType":"counter"}],"isInner":false}],"isInner":false},{"id":"4903eca","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","animation":"opal-move-up","animation_duration":"fast","osf_section_parallax_layer":[]},"elements":[{"id":"6949259","elType":"column","settings":{"_column_size":100},"elements":[{"id":"63b7ae8","elType":"widget","settings":{"thumbnail_size":"full","carousel":[{"id":6555,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-9.jpg"},{"id":6554,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-8.jpg"},{"id":6551,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-5.jpg"},{"id":6549,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-3.jpg"},{"id":6548,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-2.jpg"},{"id":6550,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-4.jpg"},{"id":6552,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-6.jpg"},{"id":6553,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-7.jpg"},{"id":6547,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-1.jpg"}],"slides_to_show":"6","navigation":"none","_margin":{"unit":"px","top":"0","right":"0","bottom":"-9","left":"0","isLinked":false},"slides_to_show_tablet":"4","slides_to_show_mobile":"2"},"elements":[],"widgetType":"image-carousel"}],"isInner":false}],"isInner":false}],"header-02":[{"id":"9b1f7cb","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"7","right":"30","bottom":"7","left":"30","isLinked":false},"background_background":"classic","background_color":"#1d1d1d","hide_mobile":"hidden-phone"},"elements":[{"id":"f31c54e","elType":"column","settings":{"_column_size":50,"_inline_size":85.2450000000000045474735088646411895751953125,"space_between_widgets":0},"elements":[{"id":"e49dc71","elType":"widget","settings":{"editor":"<p>Welcome to our club!<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"b628514","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"6b70ec7","elType":"widget","settings":{"editor":"<p><a href=\"mailto:info@example.com\">info@example.com<\/a><\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"1f10358","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"7788600","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"53695d6","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-linkedin","_id":"0f53b59","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"1152568","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-youtube","_id":"e128dab","link":{"url":"#","is_external":"true","nofollow":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"rgba(0,0,0,0)","icon_secondary_color":"#777777","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":0,"sizes":[]},"icon_spacing":{"unit":"px","size":20,"sizes":[]},"hover_primary_color":"rgba(0,0,0,0)","_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"312a7cb","elType":"column","settings":{"_column_size":50,"_inline_size":14.7550000000000007815970093361102044582366943359375},"elements":[{"id":"162a54a","elType":"widget","settings":{"title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"Search...","button_text":"Search","text_account":"","title_cart":"","title_cart_hover":"","show_count":"yes","show_account":"yes","show_icon_account":"yes","show_search":"yes","show_cart":"yes","toggle_size":{"unit":"px","size":18,"sizes":[]},"config_account_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"overlay_background_color":"rgba(0,0,0,0.7)","input_text_color":"#ffffff","input_border_color":"#ffffff","input_text_color_focus":"#ffffff","input_border_color_focus":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0,"sizes":[]},"toggle_color":"#ffffff","toggle_color_hover":"#e81938","toggle_icon_size":{"unit":"px","size":100,"sizes":[]},"icon_color":"#ffffff","icon_hover_color":"#e81938","icon_account_size":{"unit":"px","size":18,"sizes":[]}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"a25c8bf","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"34","right":"30","bottom":"34","left":"30","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"rgba(255,255,255,0.2)","background_background":"classic","border_width_tablet":{"unit":"px","top":"1","right":"0","bottom":"1","left":"0","isLinked":false},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"25","right":"30","bottom":"25","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false},"background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/bg_header_02.jpg","id":6297},"background_position":"center center","background_repeat":"no-repeat","section_parallax_on":"yes"},"elements":[{"id":"ffe58c2","elType":"column","settings":{"_column_size":50,"_inline_size":14.6910000000000007247535904753021895885467529296875,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"5ae6960","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width_mobile":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"5c11d9f","elType":"column","settings":{"_column_size":50,"_inline_size":85.308999999999997498889570124447345733642578125,"space_between_widgets":0,"content_position":"center","align":"flex-end","_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"ef8cfdd","elType":"widget","settings":{"menu":"mainmenu","align_items":"center","align_items_tablet":"center","indicator":"angle","subMenusMinWidth":{"unit":"px","size":250,"sizes":[]},"dropdown":"mobile","toggle_align":"right","menu-toggle-title":"","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":18,"sizes":[]},"menu_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"uppercase","color_menu_item":"#ffffff","show_dot_item":"yes","padding_horizontal_menu_item":{"unit":"px","size":25,"sizes":[]},"padding_horizontal_menu_item_tablet":{"unit":"px","size":15,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":10,"sizes":[]},"padding_vertical_menu_item_tablet":{"unit":"px","size":5,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"background_color_dropdown_item":"#ffffff","background_color_dropdown_item_hover":"rgba(0,0,0,0.065)","dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":16,"sizes":[]},"dropdown_typography_font_weight":"500","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item":{"unit":"px","size":25,"sizes":[]},"padding_vertical_dropdown_item":{"unit":"px","size":10,"sizes":[]},"spacing_vertical_dropdown_item":{"unit":"px","size":0,"sizes":[]},"dropdown_top_distance":{"unit":"px","size":0,"sizes":[]},"dropdown_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"toggle_icon_color":"#ffffff","toggle_icon_color_hover":"#e81938","toggle_background_color_hover":"rgba(0,0,0,0)","toggle_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_element_width":"auto","_element_width_tablet":"inherit","_element_vertical_align":"center","full_width":"stretch","dropdown_layout":"canvas","size_icon_togle_mobile":{"unit":"px","size":25,"sizes":[]}},"elements":[],"widgetType":"opal-nav-menu"},{"id":"328fb70","elType":"widget","settings":{"text":"join the club","_element_width":"auto","_element_vertical_align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"40","isLinked":false},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","contact_slug":"contact-form"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-4":[{"id":"908ae42","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"60","right":0,"bottom":"30","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"15","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"4fdb728","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"20eff61","elType":"widget","settings":{"rev_alias":"slide-home4"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"910cd32","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"7f541d6","elType":"column","settings":{"_column_size":50,"_inline_size":67.054000000000002046363078989088535308837890625,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[{"id":"6fd4cc5","elType":"widget","settings":{"skin":"cover","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_banner1.jpg","id":6308},"bg_image_size":"custom","bg_image_custom_dimension":{"width":"867","height":"539"},"title":"member discount","description":"PROTECTIVE PARTS &<br> ACCESSORIES","button":"","min-height":{"unit":"px","size":420,"sizes":[]},"min-height_tablet":{"unit":"px","size":300,"sizes":[]},"alignment":"right","alignment_tablet":"center","vertical_position":"middle","padding":{"unit":"px","top":"0","right":"65","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"title_typography_text_transform":"uppercase","title_typography_letter_spacing":{"unit":"px","size":2,"sizes":[]},"title_spacing":{"unit":"px","size":40,"sizes":[]},"title_spacing_tablet":{"unit":"px","size":30,"sizes":[]},"title_spacing_mobile":{"unit":"px","size":20,"sizes":[]},"description_typography_typography":"custom","description_typography_font_family":"Teko","description_typography_font_size":{"unit":"px","size":60,"sizes":[]},"description_typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"description_typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":60,"sizes":[]},"description_typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"description_typography_line_height_mobile":{"unit":"px","size":35,"sizes":[]}},"elements":[],"widgetType":"call-to-action"}],"isInner":false},{"id":"2efce67","elType":"column","settings":{"_column_size":50,"_inline_size":32.945999999999997953636921010911464691162109375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"e33e003","elType":"widget","settings":{"skin":"cover","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_banner2.jpg","id":6310},"bg_image_size":"custom","bg_image_custom_dimension":{"width":"410","height":"420"},"title":"New custom build","description":"the FUEL Royal<br> Rally 400","button":"","min-height":{"unit":"px","size":420,"sizes":[]},"min-height_tablet":{"unit":"px","size":300,"sizes":[]},"alignment":"right","alignment_tablet":"center","vertical_position":"middle","padding":{"unit":"px","top":"60","right":"60","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18,"sizes":[]},"title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"title_typography_letter_spacing":{"unit":"px","size":2,"sizes":[]},"title_spacing":{"unit":"px","size":15,"sizes":[]},"title_spacing_tablet":{"unit":"px","size":30,"sizes":[]},"title_spacing_mobile":{"unit":"px","size":20,"sizes":[]},"description_typography_typography":"custom","description_typography_font_family":"Teko","description_typography_font_size":{"unit":"px","size":40,"sizes":[]},"description_typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":40,"sizes":[]},"description_typography_line_height_mobile":{"unit":"px","size":35,"sizes":[]}},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false},{"id":"5a0c46e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"c0d2eba","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"35500ce","elType":"widget","settings":{"title":"Best Selling","sub_title":"Our products","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase","sub_title_spacing":{"unit":"px","size":5,"sizes":[]},"show_decor":"yes","_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":50,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"998d330","elType":"widget","settings":{"limit":4,"column":"4","product_type":"best_selling"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false},{"id":"ee0cebd","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"content_position":"middle","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"d42a62c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"e71757b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_img1.jpg","id":6332},"image_size":"custom","image_custom_dimension":{"width":"645","height":"760"},"_z_index":5,"_css_classes":"img-animated","width_tablet":{"unit":"%","size":70,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"6ca35ab","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"align":"flex-start"},"elements":[{"id":"4d88d55","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"px","size":-130},"osf_section_parallax_position_v":{"unit":"px","size":-125},"_id":"8627540"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":90},"_id":"5106c33"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":51},"osf_section_parallax_position_v":{"unit":"%","size":80},"_id":"810a9ee"}],"padding":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"27605df","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"50","right":"30","bottom":"50","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[{"id":"880e906","elType":"widget","settings":{"product_id":"5984","title_color":"#000000"},"elements":[],"widgetType":"opal-single-product"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"9431d3c","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"160","right":"30","bottom":"160","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_bg1.jpg","id":6346},"background_position":"center center","background_repeat":"no-repeat","section_parallax_on":"yes","background_overlay_background":"classic","background_overlay_color":"#000000","padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"d222b4d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"683e173","elType":"widget","settings":{"title":"save up to 75%","sub_title":"member discount","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":120,"sizes":[]},"typography_text_transform":"uppercase","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase","sub_title_spacing":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":80,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":50,"sizes":[]},"sub_title_spacing_tablet":{"unit":"px","size":30,"sizes":[]},"sub_title_spacing_mobile":{"unit":"px","size":5,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"0fb3d9e","elType":"widget","settings":{"text":"view detail","align":"center"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"788be81","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"89dfd79","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"6c428be","elType":"widget","settings":{"title":"","sub_title":"Shop our collections","align":"center","title_color":"#ffffff","sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_text_transform":"uppercase","show_decor":"yes","sub_title_spacing_mobile":{"unit":"px","size":0,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"a75adfd","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"9b19674","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"913eea0","elType":"widget","settings":{"categories":"pants","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_ct1.jpg","id":6364},"image_size":"custom","image_custom_dimension":{"width":"645","height":"520"},"text_align_h":"left","text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","item_typography_typography":"custom"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true},{"id":"1f2db30","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"38b5127","elType":"widget","settings":{"categories":"jackets","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_ct2.jpg","id":6365},"image_size":"custom","image_custom_dimension":{"width":"645","height":"520"},"text_align_h":"left","text_align_v":"flex-end","button_text":"View Collection"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true},{"id":"e9e4539","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"c37771b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":33.3299999999999982946974341757595539093017578125},"elements":[{"id":"2cd2600","elType":"widget","settings":{"categories":"gears","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_ct3.jpg","id":6355},"image_size":"custom","image_custom_dimension":{"width":"430","height":"320"},"text_align_h":"left","text_align_v":"flex-end","button_text":"View Collection"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true},{"id":"d143e47","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":33.3299999999999982946974341757595539093017578125},"elements":[{"id":"e3ef703","elType":"widget","settings":{"categories":"helmets","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_ct4.jpg","id":6356},"image_size":"custom","image_custom_dimension":{"width":"430","height":"320"},"text_align_h":"left","text_align_v":"flex-end","button_text":"View Collection"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true},{"id":"0165e9c","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":33.3299999999999982946974341757595539093017578125},"elements":[{"id":"f2b505e","elType":"widget","settings":{"categories":"accessories","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_ct5.jpg","id":6357},"image_size":"custom","image_custom_dimension":{"width":"430","height":"320"},"text_align_h":"left","text_align_v":"flex-end","button_text":"View Collection"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"e12e4ae","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg3.jpg","id":3996},"section_parallax_on":"yes","background_overlay_background":"gradient","background_overlay_color":"#1a1a1a","background_overlay_color_stop":{"unit":"%","size":6,"sizes":[]},"background_overlay_color_b":"rgba(26,26,26,0.52)","background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"padding":{"unit":"px","top":"100","right":"30","bottom":"150","left":"30","isLinked":false},"background_position_tablet":"center right","background_size_tablet":"initial","background_size_mobile":"cover","background_bg_width_tablet":{"unit":"%","size":150,"sizes":[]},"padding_tablet":{"unit":"px","top":"50","right":"30","bottom":"110","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"110","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"4e204a7","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"_inline_size":null,"_inline_size_tablet":100},"elements":[{"id":"8e00645","elType":"widget","settings":{"brands":[{"brand_title":"Brand Name","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_brand1.png","id":6372},"_id":"baaf931"},{"brand_title":"Brand Name","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_brand2.png","id":6373},"_id":"388ef1d"},{"brand_title":"Brand Name","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_brand3.png","id":6374},"_id":"288dd95"},{"brand_title":"Brand Name","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/h4_brand4.png","id":6375},"_id":"440592a"}],"brand_image_size":"custom","brand_image_custom_dimension":{"width":"185","height":"178"},"column":"4","_margin":{"unit":"px","top":"0","right":"0","bottom":"150","left":"0","isLinked":false},"column_tablet":"4","column_mobile":"2","brand_align_mobile":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"brand_align":"center"},"elements":[],"widgetType":"opal-brand"},{"id":"5af1ad4","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"20","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"38e0e6b","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"_inline_size":null,"_inline_size_tablet":100},"elements":[{"id":"eb30e5c","elType":"widget","settings":{"title":"join the club","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":50,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"e057286","elType":"widget","settings":{"editor":"<p>187 members and the family keeps growing!<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"0e962a0","elType":"widget","settings":{"width_input":{"unit":"%","size":70,"sizes":[]},"width_input_mobile":{"unit":"%","size":100,"sizes":[]},"width_button":{"unit":"%","size":30,"sizes":[]},"width_button_mobile":{"unit":"%","size":100,"sizes":[]},"input_bacground":"#f0f0f0","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":true},{"id":"528966e","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"660353a","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","animation":"opal-move-up","animation_duration":"fast","osf_section_parallax_layer":[]},"elements":[{"id":"0f3aee6","elType":"column","settings":{"_column_size":100},"elements":[{"id":"9265d5f","elType":"widget","settings":{"thumbnail_size":"full","carousel":[{"id":6555,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-9.jpg"},{"id":6554,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-8.jpg"},{"id":6551,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-5.jpg"},{"id":6549,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-3.jpg"},{"id":6548,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-2.jpg"},{"id":6550,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-4.jpg"},{"id":6552,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-6.jpg"},{"id":6553,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-7.jpg"},{"id":6547,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-1.jpg"}],"slides_to_show":"6","navigation":"none","_margin":{"unit":"px","top":"0","right":"0","bottom":"-9","left":"0","isLinked":false},"slides_to_show_tablet":"4","slides_to_show_mobile":"2"},"elements":[],"widgetType":"image-carousel"}],"isInner":false}],"isInner":false}],"tab3-ourmission":[{"id":"9e0be6f","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"79ffc41","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"32911da","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_mis_banner3.jpg","id":6129},"image_size":"full","image_custom_dimension":{"width":"650","height":"400"},"align_tablet":"left","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"f66b2f7","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"65","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"9d430eb","elType":"widget","settings":{"editor":"<p>If you are looking to find a group of well-established and safe to ride with, you\'ve found us. We were founded as a formal motorcycle club in Boston in 1985, and are still going strong. We focus on safe riding and we also ride for charities that are near and dear to our hearts.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"5488a67","elType":"widget","settings":{"icon_list":[{"text":"Only men can join","icon":"fa fa-check-circle-o","_id":"e219ba9","link":{"url":"","is_external":"","nofollow":""}},{"text":"Meetings have strict protocols","icon":"fa fa-check-circle-o","_id":"ee7e8a7","link":{"url":"","is_external":"","nofollow":""}},{"text":"Prospective members endure brutal hazing ","icon":"fa fa-check-circle-o","_id":"7b48ed6","link":{"url":"","is_external":"","nofollow":""}},{"text":"Some new members have to deal with human waste","icon":"fa fa-check-circle-o","_id":"2b7fbc5","link":{"url":"","is_external":"","nofollow":""}},{"text":"Attendance at all meetings is mandatory","icon":"fa fa-check-circle-o","_id":"336e72e","link":{"url":"","is_external":"","nofollow":""}},{"text":" Race may play a part in the induction process","icon":"fa fa-check-circle-o","_id":"0257b0b","link":{"url":"","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":16,"sizes":[]},"list_item_margin":{"unit":"px","top":"10","right":"0","bottom":"10","left":"0","isLinked":false},"text_indent":{"unit":"px","size":15,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Noto Sans","icon_typography_line_height":{"unit":"px","size":30,"sizes":[]},"text_color":"#c6c6c6","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"icon-list"}],"isInner":false}],"isInner":false}],"tab2-ourmission":[{"id":"14f96fa","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"34fefd7","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"3d36183","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_mis_banner2.jpg","id":6127},"image_size":"full","image_custom_dimension":{"width":"650","height":"400"},"align_tablet":"left","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"6b1a26c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"65","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"61c6706","elType":"widget","settings":{"editor":"<p>Some of the regulations are simple mandates all motorcycle club members must follow. Other rules are unique to particular clubs such as the Hells Angels, the Bandidos, or the Outlaws. Members must follow each set of regulations or else face strict punishment.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"185cc82","elType":"widget","settings":{"icon_list":[{"text":"Members may have to commit acts of violence","icon":"fa fa-check-circle-o","_id":"e219ba9","link":{"url":"","is_external":"","nofollow":""}},{"text":"Only one motorcycle club can control an area","icon":"fa fa-check-circle-o","_id":"ee7e8a7","link":{"url":"","is_external":"","nofollow":""}},{"text":"Members must be completely loyal to the club","icon":"fa fa-check-circle-o","_id":"7b48ed6","link":{"url":"","is_external":"","nofollow":""}},{"text":"Nonmembers are not allowed to know club business","icon":"fa fa-check-circle-o","_id":"336e72e","link":{"url":"","is_external":"","nofollow":""}},{"text":"Leaving a motorcycle club isn\'t easy","icon":"fa fa-check-circle-o","_id":"0257b0b","link":{"url":"","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":16,"sizes":[]},"list_item_margin":{"unit":"px","top":"10","right":"0","bottom":"10","left":"0","isLinked":false},"text_indent":{"unit":"px","size":15,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Noto Sans","icon_typography_line_height":{"unit":"px","size":30,"sizes":[]},"text_color":"#c6c6c6","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"icon-list"}],"isInner":false}],"isInner":false}],"header-empty":null,"landing-page":[{"id":"725ed6c","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false}},"elements":[{"id":"87ca682","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"0f0a6ae","elType":"widget","settings":{"rev_alias":"landingpage-slide"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"3ee44f8","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","background_background":"classic","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"ee5f86b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"abbf876","elType":"widget","settings":{"title":"<span class=\"c-primary\">04+<\/span> Predefined Homepage Layouts","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","typography_text_transform":"uppercase","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"9d1d5c8","elType":"widget","settings":{"editor":"The eye-catchy demos come with powerful framework and page builder that promises to\nhelp you show products and club info effectively.","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"85","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_padding":{"unit":"%","top":"0","right":"17","bottom":"0","left":"17","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"c6b559e","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"40","content_delay_time":"0.50","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"3b8c08c","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"5018ce3","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_home_1.jpg","id":4726},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/home-1","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-flip-box"},{"id":"f48a545","elType":"widget","settings":{"title":"Home 1","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"2324a4d","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"7a87e5d","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_home_2.jpg","id":4745},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/home-2","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"opal-flip-box"},{"id":"69689b1","elType":"widget","settings":{"title":"Home 2","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"e1479da","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"fc8f130","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_home_3.jpg","id":4746},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/home-3","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-flip-box"},{"id":"757179b","elType":"widget","settings":{"title":"Home 3","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"f6de50f","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"57fcf09","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/05\/landing_home_4.jpg","id":6338},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/home-4","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300,"background_a_size":"cover"},"elements":[],"widgetType":"opal-flip-box"},{"id":"d04586e","elType":"widget","settings":{"title":"Home 4 (Shop)","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"5a8de2d","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","content_width":{"unit":"px","size":1320,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"background_background":"classic","background_color":"#141414","padding":{"unit":"px","top":"130","right":"30","bottom":"130","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"21a9414","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"759b9cb","elType":"widget","settings":{"title":"riding report & upcoming events style","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1529fdc","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"fd974d0","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f671f03","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_riding-report-grid-style.jpg","id":4826},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-grid-style\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-flip-box"},{"id":"bdaa876","elType":"widget","settings":{"title":"riding report grid style","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"883b6d8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"99fe1d5","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_riding-report-timeline-style.jpg","id":4827},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/report-timeline-style\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"opal-flip-box"},{"id":"94992f0","elType":"widget","settings":{"title":"riding report timeline style","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"20c05a5","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"c60640e","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_upcoming-event-month-view.jpg","id":4828},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/events\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-flip-box"},{"id":"31bedba","elType":"widget","settings":{"title":"upcoming event calendar view","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"ad2192b","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a53757b","elType":"column","settings":{"_column_size":50,"_inline_size":50,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"150","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"76e25a8","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_woo.png","id":5293},"image_size":"full","align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","align_mobile":"center"},"elements":[],"widgetType":"image"},{"id":"1e08507","elType":"widget","settings":{"title":"Great for eCommerce too. Start build your shop online today","typography_typography":"custom","typography_text_transform":"uppercase","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","align_mobile":"center"},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"77e83ec","elType":"column","settings":{"_column_size":50,"_inline_size":50,"space_between_widgets":0},"elements":[{"id":"cd45090","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_page_shop.jpg","id":5298},"image_size":"custom","image_custom_dimension":{"width":"660","height":"520"},"align":"left","align_mobile":"center","image_border_border":"solid","image_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"image_border_color":"#343434","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"c7d089a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","content_width":{"unit":"px","size":1320,"sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"background_background":"classic","background_color":"#141414","padding":{"unit":"px","top":"130","right":"30","bottom":"130","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"403ef45","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"1f73ab3","elType":"widget","settings":{"title":"Ready Pages to use","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"630d387","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false}},"elements":[{"id":"46d24c7","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"308a7a2","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_about_club_info.jpg","id":5315},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/club-info\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-flip-box"},{"id":"70e3a00","elType":"widget","settings":{"title":"club info","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"71c97c6","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"deb821b","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_about_history.jpg","id":5326},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/club-history\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"opal-flip-box"},{"id":"6ef5618","elType":"widget","settings":{"title":"club history","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"cf5962f","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ce6e08d","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_about_our_mission.jpg","id":5322},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/our-mission\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-flip-box"},{"id":"2469284","elType":"widget","settings":{"title":"our mission","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true},{"id":"4d2c1af","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"de50167","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f44cf6c","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_about_members.jpg","id":5339},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/our-members\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-flip-box"},{"id":"6d388c8","elType":"widget","settings":{"title":"our members","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"6efe55e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"21beee4","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_media_photo_albums.jpg","id":5340},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/photos-album\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"opal-flip-box"},{"id":"3bc4d4e","elType":"widget","settings":{"title":"media","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"427a74b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"40a57c7","elType":"widget","settings":{"graphic_element":"none","icon":"","title_text_a":"","description_text_a":"","background_a_background":"classic","background_a_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_news.jpg","id":5341},"background_a_position":"top center","background_a_repeat":"no-repeat","title_text_b":"","description_text_b":"","button_text":"","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/news\/","is_external":"","nofollow":""},"background_b_background":"classic","background_b_color":"rgba(232,25,56,0.8)","height":{"unit":"px","size":520,"sizes":[]},"flip_effect":"fade","border_a_border":"solid","border_a_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_a_color":"#353535","link_click":"box","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-flip-box"},{"id":"4d172a9","elType":"widget","settings":{"title":"news","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"e1ca2cd","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","sticky_background_color_stop":{"unit":"%","size":0,"sizes":[]},"sticky_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"sticky_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"sticky_background_xpos":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_bg_width":{"unit":"%","size":100,"sizes":[]},"sticky_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"sticky_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"stretch_section":"section-stretched","background_background":"classic","osf_section_vertical_line_switcher":"active","osf_section_vertical_line_color":"rgba(255,255,255,0.1)","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"sticky_background_background":"","sticky_background_color":"","sticky_background_color_b":"#f2295b","sticky_background_gradient_type":"linear","sticky_background_gradient_position":"center center","sticky_background_image":{"url":"","id":""},"sticky_background_image_tablet":{"url":"","id":""},"sticky_background_image_mobile":{"url":"","id":""},"sticky_background_position":"","sticky_background_position_tablet":"","sticky_background_position_mobile":"","sticky_background_attachment":"","sticky_background_repeat":"","sticky_background_repeat_tablet":"","sticky_background_repeat_mobile":"","sticky_background_size":"","sticky_background_size_tablet":"","sticky_background_size_mobile":"","sticky_background_video_link":"","sticky_background_video_start":"","sticky_background_video_end":"","sticky_background_video_fallback":{"url":"","id":""},"margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false}},"elements":[{"id":"4e0e76e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"69c3458","elType":"widget","settings":{"title":"Theme features","align":"center","typography_typography":"custom","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"decor_spacing":{"unit":"px","size":"","sizes":[]},"decor_spacing_tablet":{"unit":"px","size":"","sizes":[]},"decor_spacing_mobile":{"unit":"px","size":"","sizes":[]},"title_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"72afcaa","elType":"widget","settings":{"editor":"<p>See all of the outstanding features in Lex Rider<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"16c9770","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"sticky_background_color_stop":{"unit":"%","size":0,"sizes":[]},"sticky_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"sticky_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"sticky_background_xpos":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_bg_width":{"unit":"%","size":100,"sizes":[]},"sticky_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"sticky_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"background_background":"classic","osf_section_vertical_line_switcher":"active","osf_section_vertical_line_color":"rgba(255,255,255,0.1)","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"sticky_background_background":"","sticky_background_color":"","sticky_background_color_b":"#f2295b","sticky_background_gradient_type":"linear","sticky_background_gradient_position":"center center","sticky_background_image":{"url":"","id":""},"sticky_background_image_tablet":{"url":"","id":""},"sticky_background_image_mobile":{"url":"","id":""},"sticky_background_position":"","sticky_background_position_tablet":"","sticky_background_position_mobile":"","sticky_background_attachment":"","sticky_background_repeat":"","sticky_background_repeat_tablet":"","sticky_background_repeat_mobile":"","sticky_background_size":"","sticky_background_size_tablet":"","sticky_background_size_mobile":"","sticky_background_video_link":"","sticky_background_video_start":"","sticky_background_video_end":"","sticky_background_video_fallback":{"url":"","id":""},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"20","left":0,"isLinked":false}},"elements":[{"id":"652e2dc","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"91d83bc","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","sticky_background_color_stop":{"unit":"%","size":0,"sizes":[]},"sticky_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"sticky_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"sticky_background_xpos":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_bg_width":{"unit":"%","size":100,"sizes":[]},"sticky_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"sticky_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"margin":{"unit":"px","top":"0","right":0,"bottom":"10","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"osf_section_vertical_line_switcher":"","osf_section_vertical_line_color":"","sticky_background_background":"","sticky_background_color":"","sticky_background_color_b":"#f2295b","sticky_background_gradient_type":"linear","sticky_background_gradient_position":"center center","sticky_background_image":{"url":"","id":""},"sticky_background_image_tablet":{"url":"","id":""},"sticky_background_image_mobile":{"url":"","id":""},"sticky_background_position":"","sticky_background_position_tablet":"","sticky_background_position_mobile":"","sticky_background_attachment":"","sticky_background_repeat":"","sticky_background_repeat_tablet":"","sticky_background_repeat_mobile":"","sticky_background_size":"","sticky_background_size_tablet":"","sticky_background_size_mobile":"","sticky_background_video_link":"","sticky_background_video_start":"","sticky_background_video_end":"","sticky_background_video_fallback":{"url":"","id":""}},"elements":[{"id":"7e773b1","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"a8a63bb","elType":"widget","settings":{"icon":"opal-icon-mouse-pointer","title_text":"One click install","description_text":"Import all data on the demos with less time -consuming and effort.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"ae7feff","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"f078c45","elType":"widget","settings":{"icon":"opal-icon-cogs","title_text":"Page builder","description_text":"Elementor approved to help you build a perfect riding club site.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"f78c554","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"e289177","elType":"widget","settings":{"icon":"opal-icon-search","title_text":"Seo ready","description_text":"Make your site on the top positions to get more clicks and result in significant traffic increases.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true},{"id":"95e109b","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","sticky_background_color_stop":{"unit":"%","size":0,"sizes":[]},"sticky_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"sticky_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"sticky_background_xpos":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_bg_width":{"unit":"%","size":100,"sizes":[]},"sticky_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"sticky_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"osf_section_vertical_line_switcher":"","osf_section_vertical_line_color":"","sticky_background_background":"","sticky_background_color":"","sticky_background_color_b":"#f2295b","sticky_background_gradient_type":"linear","sticky_background_gradient_position":"center center","sticky_background_image":{"url":"","id":""},"sticky_background_image_tablet":{"url":"","id":""},"sticky_background_image_mobile":{"url":"","id":""},"sticky_background_position":"","sticky_background_position_tablet":"","sticky_background_position_mobile":"","sticky_background_attachment":"","sticky_background_repeat":"","sticky_background_repeat_tablet":"","sticky_background_repeat_mobile":"","sticky_background_size":"","sticky_background_size_tablet":"","sticky_background_size_mobile":"","sticky_background_video_link":"","sticky_background_video_start":"","sticky_background_video_end":"","sticky_background_video_fallback":{"url":"","id":""}},"elements":[{"id":"c0d2e9d","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"9f6acaf","elType":"widget","settings":{"icon":"opal-icon-sliders-v","title_text":"Slider builder","description_text":"You can easily create powerful sliders with very nice transition effects.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"c7487d2","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"b2a2879","elType":"widget","settings":{"icon":"opal-icon-speedometer","title_text":"Speed optimization","description_text":"Everything is loaded in seconds without interruption to satisfy consumers\u2019 demands.<span style=\"font-size: 1rem;\"><\/span>","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"0cf11c3","elType":"column","settings":{"_column_size":33,"space_between_widgets":0,"_inline_size":null,"animation":"opal-move-up","animation_duration":"fast","padding_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"142cb19","elType":"widget","settings":{"icon":"opal-icon-user-headset","title_text":"Full support","description_text":"Contact us at GMT +7, we are there and willing to assist your issues related to the theme.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"_padding":{"unit":"px","top":"35","right":"15","bottom":"55","left":"15","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#141414"},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"ce18dce","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false}},"elements":[{"id":"282cf27","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"bef968b","elType":"widget","settings":{"color":"#343434"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"339d7ce","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"120","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"osf_section_vertical_line_switcher":"","osf_section_vertical_line_color":"","sticky_background_background":"","sticky_background_color":"","sticky_background_color_stop":{"unit":"%","size":0,"sizes":[]},"sticky_background_color_b":"#f2295b","sticky_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"sticky_background_gradient_type":"linear","sticky_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"sticky_background_gradient_position":"center center","sticky_background_image":{"url":"","id":""},"sticky_background_image_tablet":{"url":"","id":""},"sticky_background_image_mobile":{"url":"","id":""},"sticky_background_position":"","sticky_background_position_tablet":"","sticky_background_position_mobile":"","sticky_background_xpos":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"sticky_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"sticky_background_attachment":"","sticky_background_repeat":"","sticky_background_repeat_tablet":"","sticky_background_repeat_mobile":"","sticky_background_size":"","sticky_background_size_tablet":"","sticky_background_size_mobile":"","sticky_background_bg_width":{"unit":"%","size":100,"sizes":[]},"sticky_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"sticky_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"sticky_background_video_link":"","sticky_background_video_start":"","sticky_background_video_end":"","sticky_background_video_fallback":{"url":"","id":""}},"elements":[{"id":"77f5e60","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"7ef1427","elType":"widget","settings":{"brands":[{"brand_title":"Elementor","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_brand1.png","id":5369},"_id":"af0e99f"},{"brand_title":"Slider Revolution","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_brand2.png","id":5370},"_id":"4af617f"},{"brand_title":"Contact Form","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_brand3.png","id":5371},"_id":"419a058"},{"brand_title":"Mailchimp","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_brand4.png","id":5372},"_id":"74c83d0"},{"brand_title":"WPML","brand_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/landing_brand5.png","id":5373},"_id":"1699b94"}],"column":"5","column_tablet":"3","column_mobile":"1","brand_align":"center","enable_carousel":"yes","navigation":"none","image_box_shadow_box_shadow_type":"","image_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"image_box_shadow_box_shadow_position":" ","image_box_shadow_hover_box_shadow_type":"","image_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"image_box_shadow_hover_box_shadow_position":" ","border_image_border":"","border_image_width":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"border_image_width_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"border_image_width_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"border_image_color":"","image_border_radius":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_padding_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_padding_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_margin":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_margin_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"image_margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"autoplay_speed":4000},"elements":[],"widgetType":"opal-brand"}],"isInner":false}],"isInner":false},{"id":"f2a795a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_color":"#141414","padding":{"unit":"px","top":"130","right":"30","bottom":"130","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"30","bottom":"80","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false}},"elements":[{"id":"9172873","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"648d720","elType":"widget","settings":{"title":"Get The Fully Functional<br> motorcycle club WordPress Theme","align":"center","typography_typography":"custom","typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"5a794f1","elType":"widget","settings":{"text":"$59 purchase","link":{"url":"https:\/\/themeforest.net\/item\/lexrider-motorcycle-club-woocommerce-wordpress-theme\/23700786","is_external":"","nofollow":""},"align":"center","size":"lg","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"riding-report-timeline":null,"events":null,"contact":[{"id":"313872d","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"125","right":0,"bottom":"125","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"e82f526","elType":"column","settings":{"_column_size":50,"_inline_size":40},"elements":[{"id":"10d74d5","elType":"widget","settings":{"icon":"opal-icon-location","title_text":"head office","description_text":"44 Shirley Ave. West Chicago,<br>\nNew York, USA","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#2e2e2e","_animation":"opal-move-up","animation_duration":"fast","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":16,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"},{"id":"0b26367","elType":"widget","settings":{"icon":"opal-icon-user-headset","title_text":"call support","description_text":"8(800) 123 - 45 - 99<br>\n8(800) 123 - 45 - 66","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"title_typography_typography":"custom","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"description_typography_typography":"custom","description_typography_line_height":{"unit":"px","size":"","sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#2e2e2e","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150,"title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"},{"id":"9a2749e","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_color":"#2e2e2e","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true},"padding":{"unit":"px","top":"10","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"3469c91","elType":"column","settings":{"_column_size":50,"_inline_size":63.953000000000002955857780762016773223876953125,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"cc40373","elType":"widget","settings":{"icon":"opal-icon-email","title_text":"Email us","description_text":"contact@example.com<br>\nsupport@example.com","position":"left","icon_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":1,"sizes":[]},"title_typography_typography":"custom","title_typography_line_height":{"unit":"px","size":"","sizes":[]},"description_typography_typography":"custom","description_typography_line_height":{"unit":"px","size":"","sizes":[]},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_border_color":"#2e2e2e","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"title_typography_font_size":{"unit":"px","size":24,"sizes":[]},"title_typography_text_transform":"uppercase"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"0abf274","elType":"column","settings":{"_column_size":50,"_inline_size":36.046999999999997044142219237983226776123046875,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"88f1edc","elType":"widget","settings":{"title":"follow us","align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"header_size":"h3","align_tablet":"center","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"492136c","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"b3d40de","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"d7ab8f1","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-google-plus","_id":"905749e","link":{"url":"","is_external":"true","nofollow":""}}],"shape":"square","icon_color":"custom","icon_primary_color":"#000000","icon_secondary_color":"#ffffff","icon_size":{"unit":"px","size":18,"sizes":[]},"icon_padding":{"unit":"em","size":0.75,"sizes":[]},"icon_spacing":{"unit":"px","size":6,"sizes":[]},"hover_primary_color":"#e81938","hover_secondary_color":"#ffffff","_element_width":"auto","_element_vertical_align":"center","align":"left","align_mobile":"center","_element_width_tablet":"inherit","align_tablet":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":true}],"isInner":true},{"id":"1d63e60","elType":"widget","settings":{"address":"London Eye, London, United Kingdom","height":{"unit":"px","size":387,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"google_maps"}],"isInner":false},{"id":"9ef0e10","elType":"column","settings":{"_column_size":50,"_inline_size":60,"space_between_widgets":0,"background_background":"classic","background_color":"#131313","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"15","left":"15","isLinked":false}},"elements":[{"id":"5cb08ba","elType":"widget","settings":{"title":"Send us a message","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"0818777","elType":"widget","settings":{"editor":"<p>If you have any questions or need more information, please use the form below to send us a message.<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":15,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"text-editor"},{"id":"fb23c4e","elType":"widget","settings":{"form_name":"Contact form","cf_id":"4331","input_typography_line_height":{"unit":"px","size":"","sizes":[]},"border_input_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_input_color":"#323232","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200,"select_typography_text_transform":"none","label_typography_typography":"custom","label_typography_font_size":{"unit":"px","size":14,"sizes":[]},"label_typography_text_transform":"none","label_typography_letter_spacing":{"unit":"px","size":0,"sizes":[]},"input_typography_font_size":{"unit":"px","size":14,"sizes":[]}},"elements":[],"widgetType":"opal-contactform7"}],"isInner":false}],"isInner":false}],"footer-01":[{"id":"7900c43","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#1a1a1a","padding":{"unit":"px","top":"125","right":"30","bottom":"110","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"70","right":"30","bottom":"70","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"70","right":"15","bottom":"70","left":"15","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#313131"},"elements":[{"id":"9069814","elType":"column","settings":{"_column_size":33,"_inline_size":58.6820000000000021600499167107045650482177734375,"space_between_widgets":0,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"66e78e4","elType":"widget","settings":{"title":"do you have questions? <br>do not wait, <span class=\"c-primary\">let\u2019s talk<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_line_height":{"unit":"px","size":60,"sizes":[]},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":30,"sizes":[]},"typography_line_height_tablet":{"unit":"px","size":40,"sizes":[]},"typography_line_height_mobile":{"unit":"px","size":40,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"51","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"219b70e","elType":"widget","settings":{"view":"inline","icon_list":[{"text":"+(84) 22 4130 0555","icon":"opal-icon-phone-square","_id":"2f1b5eb","link":{"url":"","is_external":"","nofollow":""}},{"text":"contact@example.com","icon":"opal-icon-envelope-open-text","_id":"525f58b","link":{"url":"#","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":24,"sizes":[]},"text_indent":{"unit":"px","size":14,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Teko","icon_typography_font_size":{"unit":"px","size":40,"sizes":[]},"icon_typography_font_weight":"500","text_color":"#ffffff","list_item_margin":{"unit":"px","top":"0","right":"50","bottom":"0","left":"0","isLinked":false},"list_item_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_align_mobile":"center","icon_typography_font_size_tablet":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"icon-list"}],"isInner":false},{"id":"8bb6996","elType":"column","settings":{"_column_size":33,"_inline_size":22.318000000000001392663762089796364307403564453125,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"f50798e","elType":"widget","settings":{"title":"head office","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"346c3d7","elType":"widget","settings":{"editor":"<p>Box 565, <br \/>Charlestown, Nevis, <br \/>West Indies, <br \/>Caribbean<\/p>","align_mobile":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_line_height":{"unit":"px","size":30,"sizes":[]}},"elements":[],"widgetType":"text-editor"},{"id":"d65c0a2","elType":"widget","settings":{"editor":"<p><a href=\"https:\/\/www.google.com\/maps?ll=51.523767,-0.158556&amp;z=16&amp;t=m&amp;hl=en&amp;gl=US&amp;mapclient=embed&amp;q=221B+Baker+St+Marylebone,+London+NW1+6XE+UK\" target=\"_blank\" rel=\"noopener\">view map<\/a><\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12,"sizes":[]},"typography_text_transform":"uppercase","border_link_border":"solid","border_link_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_link_color":"rgba(0,0,0,0)","link_color":"#e81938","link_hover_color":"#e81938","link_hover_border_color":"#e81938"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"ed03c9e","elType":"column","settings":{"_column_size":33,"_inline_size":18.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"d58e376","elType":"widget","settings":{"title":"quick links","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"16","right":"0","bottom":"37","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"1bc0001","elType":"widget","settings":{"menu":"quick-links","layout":"vertical","pointer":"dot","indicator":"none","enable_mobile_dropdown":"","menu-toggle-title":"Menu","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_family":"Noto Sans","menu_typography_font_size":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"capitalize","padding_horizontal_menu_item":{"unit":"px","size":0,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":4,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"menu_typography_font_weight":"400","align_items_mobile":"center"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false},{"id":"b0a6c8c","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"30","content_delay_time":"0.50","background_background":"classic","background_color":"#131313","padding":{"unit":"px","top":"65","right":"30","bottom":"65","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"padding_mobile":{"unit":"px","top":"30","right":"15","bottom":"30","left":"15","isLinked":false}},"elements":[{"id":"2ef0b9e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"82b9721","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019. All Rights Reserved.<\/p>","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"ebd5286","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f706d1b","elType":"widget","settings":{"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"3e7683f","elType":"column","settings":{"_column_size":33,"_inline_size":null,"content_position":"center","align":"flex-end","space_between_widgets":0},"elements":[{"id":"b2969f2","elType":"widget","settings":{"title":"social media","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_line_height":{"unit":"px","size":"","sizes":[]},"typography_letter_spacing":{"unit":"px","size":3.5,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"18","bottom":"0","left":"0","isLinked":false},"_element_width":"auto","_element_vertical_align":"center","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","align_mobile":"center","_element_width_mobile":"inherit","typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"ea8b55f","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"b3d40de","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"d7ab8f1","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-google-plus","_id":"905749e","link":{"url":"","is_external":"true","nofollow":""}}],"shape":"square","icon_color":"custom","icon_primary_color":"#000000","icon_secondary_color":"#ffffff","icon_size":{"unit":"px","size":18,"sizes":[]},"icon_padding":{"unit":"em","size":0.75,"sizes":[]},"icon_spacing":{"unit":"px","size":6,"sizes":[]},"hover_primary_color":"#e81938","hover_secondary_color":"#ffffff","_element_width":"auto","_element_vertical_align":"center","align":"right","align_mobile":"center","_element_width_tablet":"inherit"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"demo2":[{"id":"ce432f6","elType":"section","settings":{"content_delay_time":"0.50","content_width":{"unit":"px","size":1320,"sizes":[]},"gap":"no"},"elements":[{"id":"bec7273","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"185402d","elType":"widget","settings":{"team_items":[{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"79a9df3"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"2af5e67"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"a93b39d"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"3d44417"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"9d3bd61"}],"columns":"4","team_align":""},"elements":[],"widgetType":"opal-team-box"}],"isInner":false}],"isInner":false}],"spring-wildflowers":[{"id":"d3db741","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"8cb6687","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"edac3d6","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"3ab4bab","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"92e93e8","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"616a779","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"5cf23b5","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"6db63ca","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"37876c0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"a8c323e","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"03c84b7","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"0930123","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"afb9b54","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"098c086","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"63d539f","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"f66ed73","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"304df54","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"9bed66b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"f80e1c4","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"d3d0b2d","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"067bda5","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"7634214","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"3528cc8","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"a452c17","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"f08fdef","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"1f82229","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"first-ride-out-to-offa":[{"id":"1b5d05f","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"edfcb3b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"bee0f89","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"62e3466","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"27cfd3f","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"7a02287","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"630d107","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"fcfcebc","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"064eef3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"d59d085","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"7df0659","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"cc38a5a","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"fe628c9","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"0b6f106","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"5de8792","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"371946c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"c642d55","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"69212b3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"b787513","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"1cd737d","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"2e92770","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"777c908","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"13558e9","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"cdc617f","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"ede4600","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d9f65ff","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"triumph-america":[{"id":"a36adae","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"b57ed2c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f53c89c","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"e72f994","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"097e6c3","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"bc680ca","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"0da64d7","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"082d257","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"1193b42","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"d722a99","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"120f8d0","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"f5c72d4","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"4b9c375","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"4107a23","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"61f9de6","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"98be377","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"bb55aa8","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"44dd56c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"612d2ec","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"0ca8825","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"7781183","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"4f5de86","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"772cd49","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"fd01628","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"0122ca6","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"635aeb3","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"death-valley-on-a-motorcycle":[{"id":"7b5c6a2","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"e4ccf01","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"cb75e3d","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"5e64a9a","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"264f193","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"de91e73","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"dcfeb66","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"5d05394","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"7775e7e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"aa59908","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"116baf4","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"5748ae2","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"00ddf3e","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"8b6ae93","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"ddb340b","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"f609294","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","width_mobile":{"unit":"%","size":100,"sizes":[]},"space_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"3dc22c2","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"6e357f4","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"space_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"7ee28dd","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"ef24d0d","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"c6ea5ea","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"d502d5f","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"ce4239b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"6db1d1a","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"642a3cf","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"5823daa","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"west-africa-tour":[{"id":"2ea38f6","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"be60bf4","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"b50fbc4","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"64f93ad","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"a9ad2cf","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"ca6b000","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"0cd784d","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"46c99d0","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"48dddc0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"4bd0a08","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"6455059","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"edf968d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"2926b34","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"3369cf8","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"bda468a","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"5bf0a3a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"185c3df","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"99035fb","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"212fe69","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"c208942","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"56bd036","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"3ee7bb5","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"6d6dda0","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"80459cd","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"d455e7a","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f9dd355","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"ikogosi-tour":[{"id":"a7d37da","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"0f8a5b2","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"9118f47","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"80327e3","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b1546b4","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"f69b8f8","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"7655586","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"8250040","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"651bbb2","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"162053e","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"6ddab90","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"a6cb6a6","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"33082ff","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"fd96e35","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"2708f97","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"d67e821","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"4dffd17","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"42b42fb","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"cea6239","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"2233095","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"3bd97da","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"437c18b","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"aba7cda","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"1193310","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"9aba4d6","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"5b8959a","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"from-lagos-to-europe":[{"id":"619e1d1","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"8cbe967","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"55fc6b7","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"36544dd","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"a7b7098","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"ca40ccb","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"fc00c92","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"e31d1fa","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"6f8d0ee","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"9b66e62","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"b8c9646","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"e92e8e8","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"a76e21e","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"d57eab5","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"100be83","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"cb04581","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"75da895","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"dc2d3ec","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"a509c63","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"bb409af","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"8f09a92","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"e9211bb","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375},"elements":[{"id":"8aff07d","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"61695df","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"53e3864","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"76823e8","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"first-ride-out-to-offa-2":[{"id":"eb1571c","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"ae20b5d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"7a92627","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"bd46a4d","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"fa13367","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"287a52d","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"231851e","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"3512527","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"f2a5efc","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"9e3ac4b","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"d07b1ce","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"1ec0dbe","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"0c26958","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"540cc75","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"e28c1e8","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625},"elements":[{"id":"25ee4f2","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"8f4fd09","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"f2a72eb","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"bd67898","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"1f08e05","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"318cf72","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"5d62f4e","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375},"elements":[{"id":"7775383","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"012db68","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"84271b6","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f543c4e","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"off-road-adventure-in-casca":[{"id":"4e8e94c","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"bb1f62c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"41d37f6","elType":"widget","settings":{"editor":"<p>We woke up to prepare for the trip back to Lagos. Breakfast was yam and sauce; Yam and egg and tea, coffee and chocolate drink.<\/p><p>\u00a0Once we had eaten, and everyone was set, we were road bound and set off at about 9 am. Our route was to ride from Offa, Osogbo, Ede, Gbongan, Ikire, Ibadan, Sagamu, Lagos.<\/p><p>\u00a0Heading out we stopped to fill up at the NNPC station in Offa and then set off.<\/p><p>\u00a0Heading from Offa to Osogbo was quite tricky as we were more often than not rolling on roads which were under construction, \u201cit seems Osogbo is one big construction yard lot of roads being constructed or revamped\u201d. We hit Osogbo in an hour and went on a merry go round cos road works meant roads were closed and we had to find alternative routes.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"6f4b212","elType":"widget","settings":{"title":"Journey took us through to the Iife","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":30,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"016e5a5","elType":"section","settings":{"gap":"no","custom_height_inner":{"unit":"px","size":300,"sizes":[]},"structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"61130c1","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"e53b8d0","elType":"widget","settings":{"editor":"<p>In looking for alternative routes, as a sharp guy, i left my visor open lo and behold my first fly in the helmet experience when on the highway. Its a not a funny something o, I was perturbed and almost overwhelmed with the buzzing in the helmet and had to make an emergency stop to save myself.<\/p><p>&nbsp;Of course my guardians were there to sort me out FD and Maestro. Once i sorted out the helmet we rolled off and caught up with the others \u201cthey had waited further on\u201d and we continued out of Osogbo through to Ede (nice breezy and fun ride).<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":16,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"7b6697f","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375,"space_between_widgets":0},"elements":[{"id":"5a96898","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/bg-calltoaction.jpg","id":3705},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]}},"elements":[],"widgetType":"image"}],"isInner":true}],"isInner":true},{"id":"85d1f14","elType":"widget","settings":{"editor":"<p>While filtering through the traffic, a pedestrian crossing without any care ran into Dicta\u2019s bike and broke the right side mirror ( I could see fire coming out of RC\u2019s nose and ears fortunately Kanu rode up diffusing the situation).<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"5f06a15","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"7d2fcbb","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"1c06a47","elType":"widget","settings":{"editor":"<blockquote><p>The rest of the journey through to Lagos was cool. Lucky for us traffic was light and we made very good time. We ended the journey at the Cauldron in Alausa with thanks to the Almighty for journey mercies<\/p><\/blockquote>","typography_typography":"custom","typography_font_family":"Teko","typography_font_size":{"unit":"px","size":24,"sizes":[]},"typography_text_transform":"uppercase","_background_background":"classic"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"a4e3960","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"d5f9e19","elType":"column","settings":{"_column_size":50,"_inline_size":38.034999999999996589394868351519107818603515625,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"4558206","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-3.jpg","id":3720},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"left","_element_vertical_align":"flex-end","_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"b2da0c4","elType":"column","settings":{"_column_size":50,"_inline_size":61.965000000000003410605131648480892181396484375,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"b12c8c8","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/blog-6.jpg","id":3784},"image_size":"custom","image_custom_dimension":{"width":"545","height":"261"},"align":"right","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"9ec1b7c","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"30","right":0,"bottom":"30","left":0,"isLinked":true}},"elements":[{"id":"ac18e9f","elType":"column","settings":{"_column_size":50,"_inline_size":61.85000000000000142108547152020037174224853515625,"margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"e775b7a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-1.jpg","id":3718},"image_size":"custom","image_custom_dimension":{"width":"540","height":"261"},"align":"left","_element_vertical_align":"flex-end","width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"f65b757","elType":"column","settings":{"_column_size":50,"_inline_size":38.14999999999999857891452847979962825775146484375},"elements":[{"id":"3d48c45","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/report-9.jpg","id":3717},"image_size":"custom","image_custom_dimension":{"width":"330","height":"261"},"align":"right","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"width_mobile":{"unit":"%","size":100,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"c99da1d","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"299aedf","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"dc0d7a7","elType":"widget","settings":{"editor":"<p>There was a point where i was overtaking a trailer on the rather rough side of the rode and right there the road suddenly went rougher, wetin man wan do na, so you increase your speed get past the trailer and bring your bike onto the road .<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"tab-ourmission":[{"id":"0e538d2","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"7144199","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"8fa0cc6","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_mis_banner1.jpg","id":6124},"image_size":"full","image_custom_dimension":{"width":"650","height":"400"},"align_tablet":"left","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"224bf76","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"65","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"d3f6e8b","elType":"widget","settings":{"editor":"<p>For example, club members must adhere to a code of conduct while wearing their outlaw club\'s colors, and women who associate with the groups are expected to behave in specific ways. In fact, many of these bikers appreciate a military-style hierarchy. Rules are integral to life in an outlaw biker club.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"bfbeabe","elType":"widget","settings":{"icon_list":[{"text":"You must be at least 16 years old, preferably 18 or older","icon":"fa fa-check-circle-o","_id":"e219ba9","link":{"url":"","is_external":"","nofollow":""}},{"text":"You must have your profile, wall and friends set to public","icon":"fa fa-check-circle-o","_id":"ee7e8a7","link":{"url":"","is_external":"","nofollow":""}},{"text":"Members will observe all State\/Provincial traffic laws at all times.","icon":"fa fa-check-circle-o","_id":"7b48ed6","link":{"url":"","is_external":"","nofollow":""}},{"text":"Meetings have strict protocols","icon":"fa fa-check-circle-o","_id":"2b7fbc5","link":{"url":"","is_external":"","nofollow":""}},{"text":"Attendance at all meetings is mandatory","icon":"fa fa-check-circle-o","_id":"336e72e","link":{"url":"","is_external":"","nofollow":""}}],"icon_font_size":{"unit":"px","size":16,"sizes":[]},"list_item_margin":{"unit":"px","top":"10","right":"0","bottom":"10","left":"0","isLinked":false},"text_indent":{"unit":"px","size":15,"sizes":[]},"icon_typography_typography":"custom","icon_typography_font_family":"Noto Sans","icon_typography_line_height":{"unit":"px","size":30,"sizes":[]},"text_color":"#c6c6c6","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"icon-list"}],"isInner":false}],"isInner":false}],"header-01":[{"id":"7fea3eb","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"7","right":"30","bottom":"7","left":"30","isLinked":false},"background_background":"classic","background_color":"#1d1d1d","hide_mobile":"hidden-phone"},"elements":[{"id":"aa73e72","elType":"column","settings":{"_column_size":50,"_inline_size":85.2450000000000045474735088646411895751953125,"space_between_widgets":0},"elements":[{"id":"14dc29c","elType":"widget","settings":{"editor":"<p>Welcome to our club!<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"77d641a","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"7464cb0","elType":"widget","settings":{"editor":"<p><a href=\"mailto:info@example.com\">info@example.com<\/a><\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":14,"sizes":[]},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"text-editor"},{"id":"333aab8","elType":"widget","settings":{"icon":"opal-icon-diamond","size":{"unit":"px","size":5,"sizes":[]},"_margin":{"unit":"px","top":"-4","right":"15","bottom":"0","left":"15","isLinked":false},"_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"icon"},{"id":"0681bb3","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"53695d6","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-linkedin","_id":"0f53b59","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"1152568","link":{"url":"#","is_external":"true","nofollow":""}},{"social":"fa fa-youtube","_id":"e128dab","link":{"url":"#","is_external":"true","nofollow":""}}],"shape":"circle","icon_color":"custom","icon_primary_color":"rgba(0,0,0,0)","icon_secondary_color":"#777777","icon_size":{"unit":"px","size":14,"sizes":[]},"icon_padding":{"unit":"em","size":0,"sizes":[]},"icon_spacing":{"unit":"px","size":20,"sizes":[]},"hover_primary_color":"rgba(0,0,0,0)","_element_width":"auto","_element_vertical_align":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":false},{"id":"8833d21","elType":"column","settings":{"_column_size":50,"_inline_size":14.7550000000000007815970093361102044582366943359375},"elements":[{"id":"90c8d01","elType":"widget","settings":{"title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"Search...","button_text":"Search","text_account":"","title_cart":"","title_cart_hover":"","show_count":"yes","show_account":"yes","show_icon_account":"yes","show_search":"yes","show_cart":"yes","toggle_size":{"unit":"px","size":18,"sizes":[]},"config_account_margin":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"overlay_background_color":"rgba(0,0,0,0.7)","input_text_color":"#ffffff","input_border_color":"#ffffff","input_text_color_focus":"#ffffff","input_border_color_focus":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0,"sizes":[]},"toggle_color":"#ffffff","toggle_color_hover":"#e81938","toggle_icon_size":{"unit":"px","size":100,"sizes":[]},"icon_color":"#ffffff","icon_hover_color":"#e81938","icon_account_size":{"unit":"px","size":18,"sizes":[]}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"62ee0a8","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1760,"sizes":[]},"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"34","right":"30","bottom":"34","left":"30","isLinked":false},"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"rgba(255,255,255,0.2)","background_background":"classic","border_width_tablet":{"unit":"px","top":"1","right":"0","bottom":"1","left":"0","isLinked":false},"border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"25","right":"30","bottom":"25","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false}},"elements":[{"id":"4d631f7","elType":"column","settings":{"_column_size":50,"_inline_size":14.6910000000000007247535904753021895885467529296875,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"83fad5e","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width_mobile":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"14b706d","elType":"column","settings":{"_column_size":50,"_inline_size":85.308999999999997498889570124447345733642578125,"space_between_widgets":0,"content_position":"center","align":"flex-end","_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"7ed7317","elType":"widget","settings":{"menu":"mainmenu","align_items":"center","align_items_tablet":"center","indicator":"angle","subMenusMinWidth":{"unit":"px","size":250,"sizes":[]},"dropdown":"mobile","toggle_align":"right","menu-toggle-title":"","content_delay_time":"0.50","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":18,"sizes":[]},"menu_typography_font_size_tablet":{"unit":"px","size":16,"sizes":[]},"menu_typography_text_transform":"uppercase","color_menu_item":"#ffffff","show_dot_item":"yes","padding_horizontal_menu_item":{"unit":"px","size":25,"sizes":[]},"padding_horizontal_menu_item_tablet":{"unit":"px","size":20,"sizes":[]},"padding_vertical_menu_item":{"unit":"px","size":10,"sizes":[]},"padding_vertical_menu_item_tablet":{"unit":"px","size":5,"sizes":[]},"menu_space_between":{"unit":"px","size":0,"sizes":[]},"background_color_dropdown_item":"#ffffff","background_color_dropdown_item_hover":"rgba(0,0,0,0.065)","dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":16,"sizes":[]},"dropdown_typography_font_weight":"500","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item":{"unit":"px","size":25,"sizes":[]},"padding_vertical_dropdown_item":{"unit":"px","size":10,"sizes":[]},"spacing_vertical_dropdown_item":{"unit":"px","size":0,"sizes":[]},"dropdown_top_distance":{"unit":"px","size":0,"sizes":[]},"dropdown_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"toggle_icon_color":"#ffffff","toggle_icon_color_hover":"#e81938","toggle_background_color_hover":"rgba(0,0,0,0)","toggle_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_element_width":"auto","_element_width_tablet":"inherit","_element_vertical_align":"center","full_width":"stretch","dropdown_layout":"canvas","size_icon_togle_mobile":{"unit":"px","size":25,"sizes":[]}},"elements":[],"widgetType":"opal-nav-menu"},{"id":"3b2c2bb","elType":"widget","settings":{"text":"join the club","_element_width":"auto","_element_vertical_align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"40","isLinked":false},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","contact_slug":"contact-form"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"demo":[{"id":"313c6f9","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"3c677c9","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"0baa7ff","elType":"widget","settings":{"button_type":"","text":"Click here"},"elements":[],"widgetType":"button"},{"id":"4a6a384","elType":"widget","settings":{"text":"explore our rides"},"elements":[],"widgetType":"button"},{"id":"8e21bfa","elType":"widget","settings":{"button_type":"secondary","text":"Click here"},"elements":[],"widgetType":"button"},{"id":"0cacce1","elType":"widget","settings":{"button_type":"outline_primary","text":"Click here"},"elements":[],"widgetType":"button"},{"id":"c03fc99","elType":"widget","settings":{"button_type":"outline_secondary","text":"Click here"},"elements":[],"widgetType":"button"},{"id":"b875c3e","elType":"widget","settings":{"text":"Click here","size":"xs"},"elements":[],"widgetType":"button"},{"id":"402a246","elType":"widget","settings":{"text":"Click here","size":"sm"},"elements":[],"widgetType":"button"},{"id":"3a90f55","elType":"widget","settings":{"text":"Click here"},"elements":[],"widgetType":"button"},{"id":"1b531c7","elType":"widget","settings":{"text":"Click here","size":"lg"},"elements":[],"widgetType":"button"},{"id":"2f87efb","elType":"widget","settings":{"text":"Click here","size":"xl"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"c289e4d","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"e6bef89","elType":"widget","settings":{"cf_id":"4","form_name":"Contact form"},"elements":[],"widgetType":"opal-contactform7"}],"isInner":false}],"isInner":false},{"id":"f0c1160","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"f3c34c2","elType":"column","settings":{"_column_size":100},"elements":[{"id":"83a5fd0","elType":"widget","settings":{"team_items":[{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"fe0849a"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"47023c2"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"b1d6488"},{"thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"view":"traditional","name":"John Doe","image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"job":"Designer","description":"","link":{"url":"","is_external":"","nofollow":""},"facebook":"www.facebook.com\/opalwordpress","instagram":"#","twitter":"https:\/\/twitter.com\/opalwordpress","youtube":"https:\/\/www.youtube.com\/user\/WPOpalTheme","_id":"b285d61"}],"columns":"2","columns_tablet":"1","gutter":{"unit":"px","size":30,"sizes":[]},"enable_carousel":"yes"},"elements":[],"widgetType":"opal-team-box"}],"isInner":false}],"isInner":false},{"id":"1385ecb","elType":"section","settings":{"content_delay_time":"0.50"},"elements":[{"id":"5d32545","elType":"column","settings":{"_column_size":100},"elements":[{"id":"a5b341d","elType":"widget","settings":{"username":"instagram","per_row":"5","per_row_tablet":"2","per_row_mobile":"3","size":"large","image_spacing":{"unit":"px","size":"","sizes":[]}},"elements":[],"widgetType":"opal-instagram"}],"isInner":false}],"isInner":false},{"id":"74bb159","elType":"section","settings":{"content_delay_time":"0.50","structure":"20"},"elements":[{"id":"a6662d8","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[],"isInner":false},{"id":"1851385","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[],"isInner":false}],"isInner":false}],"home-3":[{"id":"2457b0a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"layout":"full_width","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"8b3d9b7","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"4b4b59c","elType":"widget","settings":{"rev_alias":"slide-home1"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"3e4686e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg1.jpg","id":6060},"background_position":"initial","background_position_tablet":"center right","background_xpos":{"unit":"px","size":80,"sizes":[]},"background_repeat":"no-repeat","background_size":"initial","background_size_mobile":"initial","background_bg_width":{"unit":"px","size":975,"sizes":[]},"background_bg_width_mobile":{"unit":"px","size":0,"sizes":[]},"background_overlay_background":"gradient","background_overlay_color":"rgba(20,20,20,0)","background_overlay_color_stop":{"unit":"%","size":70,"sizes":[]},"background_overlay_color_b":"#1a1a1a","background_overlay_color_b_stop":{"unit":"%","size":30,"sizes":[]},"background_overlay_gradient_angle":{"unit":"deg","size":90,"sizes":[]},"background_overlay_gradient_position":"center right","background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"osf_section_parallax_layer":[]},"elements":[{"id":"8d3672d","elType":"column","settings":{"_column_size":50,"_inline_size":57.36399999999999721467247582040727138519287109375,"space_between_widgets":0,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast","hide_mobile":"hidden-phone"},"elements":[{"id":"0f55619","elType":"widget","settings":{"title":"More than<br> <span style=\"font-size: 120px\"> 25<\/span><br> years of age","align":"right","typography_typography":"custom","typography_font_size":{"unit":"px","size":40,"sizes":[]},"typography_text_transform":"uppercase","_animation":"opal-scale-up","_element_width":"auto","_element_width_tablet":"auto","_position":"absolute","_offset_orientation_h":"end","_offset_x_end":{"unit":"px","size":80,"sizes":[]},"_offset_x_end_tablet":{"size":24,"unit":"%"},"_offset_x_end_mobile":{"size":33.04299999999999926103555480949580669403076171875,"unit":"px"},"_offset_orientation_v":"end","_offset_y_end":{"unit":"px","size":80,"sizes":[]},"_offset_y_end_tablet":{"size":31,"unit":"%"},"_offset_y_end_mobile":{"size":-61,"unit":"px"},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"9040be1","elType":"column","settings":{"_column_size":50,"_inline_size":42.63600000000000278532752417959272861480712890625,"space_between_widgets":0,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"110","isLinked":false},"background_background":"classic","background_color":"#1a1a1a"},"elements":[{"id":"99188e7","elType":"widget","settings":{"title":"Vintage Motorcycle Club of<span style=\"color: #e81938;\"> Western Australia<\/span>","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"38b53cd","elType":"widget","settings":{"editor":"<p>Ride with us on a journey into the unknown. Explore new frontiers. Wake up in the morning with the thrill of being somewhere you have never been before.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"105","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"70","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"cde1129","elType":"widget","settings":{"video_link":"https:\/\/vimeo.com\/197046147","icon_font":"fa fa-play","wrapper_padding":{"unit":"px","top":"120","right":"30","bottom":"120","left":"30","isLinked":false},"video_size":{"unit":"px","size":20,"sizes":[]},"video_color":"#ffffff","_background_background":"classic","_background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg_video.jpg","id":402},"video_hover_color":"#e81938","video_width":{"unit":"px","size":44,"sizes":[]},"video_height":{"unit":"px","size":44,"sizes":[]},"border_video_border":"solid","border_video_width":{"unit":"px","top":"4","right":"4","bottom":"4","left":"4","isLinked":true},"video_border_radius":{"unit":"%","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","_background_position":"center center","_background_repeat":"no-repeat","_background_size":"cover"},"elements":[],"widgetType":"opal-video-popup"}],"isInner":false}],"isInner":false},{"id":"96c5bdf","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"50","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_banner2.jpg","id":485},"background_position":"initial","background_position_tablet":"center left","background_xpos":{"unit":"%","size":88,"sizes":[]},"background_repeat":"no-repeat","background_size_mobile":"initial","background_bg_width_mobile":{"unit":"px","size":0,"sizes":[]},"background_overlay_background":"gradient","background_overlay_color":"#1a1a1a","background_overlay_color_stop":{"unit":"%","size":30,"sizes":[]},"background_overlay_color_b":"rgba(26,26,26,0)","background_overlay_color_b_stop":{"unit":"%","size":70,"sizes":[]},"background_overlay_gradient_angle":{"unit":"deg","size":90,"sizes":[]},"background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"osf_section_parallax_layer":[]},"elements":[{"id":"e50d21e","elType":"column","settings":{"_column_size":50,"_inline_size":42.63600000000000278532752417959272861480712890625,"space_between_widgets":0,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast","background_background":"classic","background_color":"#1a1a1a","padding":{"unit":"px","top":"0","right":"110","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"21cb014","elType":"widget","settings":{"title":"we kept what we loved about the bike","typography_typography":"custom","typography_font_size":{"unit":"px","size":60,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"title_color":"#ffffff","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"0ef92a7","elType":"widget","settings":{"editor":"<p>Our club encourages family involvement in a fun environment while following strict Motorcycling Australia guidelines for safety.<\/p>","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"07c8dc5","elType":"widget","settings":{"icon":"opal-icon-pistons","title_text":"support","description_text":"Establish a brotherhood of other like minded bikers who take an oath to stand with us, to support all members","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":17,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","icon_size":{"unit":"px","size":70,"sizes":[]},"title_typography_font_family":"Teko","title_typography_font_weight":"500","_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"icon_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"title_bottom_space_mobile":{"unit":"px","size":15,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"icon-box"},{"id":"b177d3e","elType":"widget","settings":{"icon":"opal-icon-helmet","title_text":"communities","description_text":"Provide an opportunity to give back to communities as well as provide assistance to veterans related injuries ","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"title_bottom_space":{"unit":"px","size":17,"sizes":[]},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","icon_size":{"unit":"px","size":70,"sizes":[]},"title_typography_font_family":"Teko","title_typography_font_weight":"500","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"icon_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"title_bottom_space_mobile":{"unit":"px","size":15,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"icon-box"},{"id":"1ed8261","elType":"widget","settings":{"weight":{"unit":"px","size":3,"sizes":[]},"color":"#e81938","gap":{"unit":"px","size":0,"sizes":[]},"text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false},{"id":"6ae3650","elType":"column","settings":{"_column_size":50,"_inline_size":57.36399999999999721467247582040727138519287109375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"110","isLinked":false},"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false},"background_background":"classic","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"isInner":false}],"isInner":false},{"id":"35fcd19","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"f1e569e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"0ec2799","elType":"widget","settings":{"title":"Club history","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"Our story","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"18e743f","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"c7d1f01","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"a61cc32","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/img-timeline.jpg","id":5389},"image_size":"full","align":"left","_css_classes":"img-animated","align_tablet":"center","width_tablet":{"unit":"%","size":70,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"bf1fa8c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"83ce5df","elType":"widget","settings":{"tabs":[{"st_year":"1935","st_heading":"The McCook Outlaws Motorcycle Club","st_content":"The McCook Outlaws Motorcycle Club was established out of Matilda`s Bar on old Route 66 in McCook, Illinois, just outside of Chicago.<br>\nAlthough the Club stayed together their activities had been limited during World War II. In May of 1946, the first major post-war motorcycle event was held at Soldier Field in Chicago.<br>\nWith new members coming from all over the Chicago area, the Club was growing in size from its early beginnings of 1935. Moving out of McCook and re-establishing itself in Chicago, the club decided to change its name. <br>The \u201cMcCook Outlaws\u201d became The \u201cChicago Outlaws\u201d. The club logo also underwent a change; a small skull replaced the winged motorcycle .<br><br>","_id":"4756c50"},{"st_year":"1954","st_heading":"A set of Crossed Pistons","st_content":"<p>A set of Crossed Pistons were added to the small skull. This time the design was embroidered on black western style shirts with white piping.<br \/>The Skull and Crossed Pistons were redesigned, making them much larger with more detail.<br \/>The AMA (American Motorcycle Association) that supervises all official races in the USA, banned the word Outlaws from all race clothing. Club members who raced adapted and wore an \u201cOMC\u201d on their outfits till 1963.<br \/>The Outlaws became the first true 1%er Club east of the Mississippi.<br \/>On the 4th of July, the \u201cGipsy Outlaws\u201d from Milwaukee became the second chapter to join the club.\u00a0<\/p><p>\u00a0<\/p>","_id":"e695041"},{"st_year":"1965","st_heading":"The first chapter outside the USA ","st_content":"<p>In July, 1967, the \u201cOutlaws\u201d National President and a few more members went down from Chicago, and sanctioned the first chapter in Florida.<br \/>\u201cGod forgives, Outlaws don\'t\u201c became the club\'s motto.<br \/>The first chapter outside the USA was formed in Canada. The \u201cSatan\'s Choice\u201d became \u201cOutlaws\u201d.<br \/>For the first time a member not belonging to the Mother chapter became \u201cNational President\u201d.<br \/>The abbreviation \u201cMC\u201d was added to the backpatch.<br \/>France became the first European chapter.<br \/>Formerly independent, the \u201cAustralian Outlaws\u201d joined the AOA. The \u201cMC 44\u201d from France became a chapter. The bottom rocker on their backpatch read \u201cEurope\u201d.<br \/><br \/><\/p>","_id":"8c8fe92"},{"st_year":"1995","st_heading":"The Chicago chapter had grown","st_content":"The Chicago chapter had grown and is split into three groups: the Mother Chapter (Southside), Westside and Northside. Norway became the second European chapter.<br>The Belgian \u201cOutlaws MC\u201d, already existing independently for 25 years, became a member of the AOA.<br>14 chapters of the English and welsh \u201cOutlaws MC\u201c, until then an independent MC, joined the AOA. Later that year Norway was added as the first Scandinavian chapter.<br>\nWith new chapters in Ireland and Jersey, a country off the English coast, the club began to expand. In Germany the \u201cGhost Riders MC\u201d joined the AOA.<br><br><br>","_id":"20038a9"},{"st_year":"2002","st_heading":"Original Mustang Shop Tour","st_content":" The first Asian chapter was established in Thailand and Sweden became the second Scandinavian chapter. <br>\nGermany started the first official Support MC of the AOA Nation. The new \u201cBlack Pistons MC\u201d soon appeared in other countries: the USA, Canada, Great Britain, Poland and Norway for starters. The AOA expanded again, this time with new chapters in Italy and Poland.<br>\nThe \u201cOutlaws MC\u201d had grown to hold a presence in 19 states of the USA. The French \u201cMC Drome\u201d came over and joined the AOA.<br>\nAt the end of 2004, the AOA started its first prospective chapter in Russia.<br><br><br>\n\n","_id":"3bec932"},{"st_year":"2005","st_heading":"The Outlaws MC World","st_content":"The Outlaws MC World celebrated its 70th Anniversary as a Motorcycle Club and the 40th Anniversary as the AOA. In June Charlie landed in Russia, as the chapter received full membership Status.<br>\nThe end of 2006 marked the AOA starting its first chapter in Japan.<br>\nAsia grew again, with the first chapter in Philippines starting in March.<br>The A.O.A. starts a chapter in Spain, in January.<br>The A.O.A. starts a chapter in Serbia and Austria.<br>\nThe A.O.A. starts a chapter in Switzerland and Czechia.<br>\nBiking & Brotherhood since 1935. The Outlaws MC World celebrate 2015 the 80th Anniversary as a Motorcycle Club and 50th Anniversary as the AOA (Outlaws Nation)\n<br><br>\n<br>","_id":"256ca79"}],"height_wrapper":{"unit":"px","size":580,"sizes":[]},"content_padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"milestone_typography_typography":"custom","content_typography_typography":"custom"},"elements":[],"widgetType":"opal-scroll-timeline"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"1b78e84","elType":"section","settings":{"gap":"no","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"60","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"8614e09","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"733748d","elType":"widget","settings":{"title":"why choose us","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"sub_title":"Our benefits","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#ffffff","subtitle_typography_typography":"custom","subtitle_typography_line_height":{"unit":"px","size":"","sizes":[]},"subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast","subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"c6f2185","elType":"section","settings":{"layout":"full_width","gap":"no","structure":"30","content_delay_time":"0.50","osf_section_parallax_layer":[]},"elements":[{"id":"5bfe410","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"6b63ed4","elType":"widget","settings":{"icon":"opal-icon-motocross","title_text":"heritage","description_text":"Our club has been active in the Ottawa area for over 35 years, and our members know all the best local roads.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"icon_size":{"unit":"px","size":64,"sizes":[]},"title_bottom_space":{"unit":"px","size":15,"sizes":[]},"title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","icon_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"507315a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":150},"elements":[{"id":"85c8b64","elType":"widget","settings":{"icon":"opal-icon-tyre","title_text":"Club Rides","description_text":"Join us on one of our many rides throughout the season.  Try day rides, getaways, tours, and even international travel.","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"icon_size":{"unit":"px","size":64,"sizes":[]},"title_bottom_space":{"unit":"px","size":15,"sizes":[]},"title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","icon_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"d4981f9","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"74876e9","elType":"widget","settings":{"icon":"opal-icon-helmet","title_text":"Social","description_text":"We have regular dinner meetings with interesting guest speakers.  We home pot lucks, cafe clubs and even picnics.  ","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false},"icon_size":{"unit":"px","size":64,"sizes":[]},"title_bottom_space":{"unit":"px","size":15,"sizes":[]},"title_typography_typography":"custom","title_typography_font_family":"Teko","title_typography_font_size":{"unit":"px","size":30,"sizes":[]},"title_typography_text_transform":"uppercase","icon_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"_padding":{"unit":"px","top":"50","right":"40","bottom":"50","left":"40","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#131313"},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"e46ea1b","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg.jpg","id":3822},"background_overlay_background":"classic","background_overlay_color":"#000000","background_overlay_opacity":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625,"sizes":[]},"padding":{"unit":"px","top":"160","right":"30","bottom":"160","left":"30","isLinked":false},"section_parallax_on":"yes","margin":{"unit":"px","top":"0","right":0,"bottom":"150","left":0,"isLinked":false},"background_position_mobile":"bottom left","background_size_mobile":"cover","background_bg_width_mobile":{"unit":"%","size":400,"sizes":[]},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"40b6d7f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"b819e48","elType":"widget","settings":{"title":"ultimate ride","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":18,"sizes":[]},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"45","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"27e753a","elType":"widget","settings":{"title":"keep memory alive","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":120,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":80,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":60,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"3051aa3","elType":"widget","settings":{"text":"view gallery","align":"center","_animation":"opal-move-up","animation_duration":"fast","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/photos-album\/","is_external":"","nofollow":""}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"d0397b6","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"130","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"70","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"80","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"6d73b6e","elType":"column","settings":{"_column_size":50,"_inline_size":25.580999999999999516830939683131873607635498046875,"space_between_widgets":0,"_inline_size_tablet":30,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"content_position":"space-between"},"elements":[{"id":"1acb0b7","elType":"widget","settings":{"title":"recent posts","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"latest news","align":"left","sub_title_color":"#ffffff","sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"animation_duration":"fast","subtitle_typography_text_transform":"uppercase"},"elements":[],"widgetType":"heading"},{"id":"c847dff","elType":"widget","settings":{"text":"see all news","size":"lg","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/news\/","is_external":"","nofollow":""},"align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"45958b3","elType":"column","settings":{"_column_size":50,"_inline_size":74.4189999999999969304553815163671970367431640625,"space_between_widgets":0,"_inline_size_tablet":70,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"89a510f","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","column_tablet":"1"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"03b11a4","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_delay_time":"0.50","padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"content_position":"middle","overflow":"hidden","osf_section_parallax_layer":[]},"elements":[{"id":"c906561","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"16380f3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_img.jpg","id":3842},"image_size":"custom","image_custom_dimension":{"width":"645","height":"760"},"_z_index":5,"_css_classes":"img-animated","width_tablet":{"unit":"%","size":70,"sizes":[]},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"fe0ea71","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#ffffff","_inline_size_tablet":100},"elements":[{"id":"c5701a3","elType":"section","settings":{"layout":"full_width","gap":"no","overflow":"hidden","content_delay_time":"0.50","osf_section_parallax_switcher":"yes","osf_section_parallax_layer":[{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape1.png","id":3853},"osf_section_parallax_position_h":{"unit":"px","size":-130},"osf_section_parallax_position_v":{"unit":"px","size":-125},"_id":"8627540"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape2.png","id":3854},"osf_section_parallax_position_h":{"unit":"%","size":-1},"osf_section_parallax_position_v":{"unit":"%","size":90},"_id":"5106c33"},{"osf_section_parallax_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_shape3.png","id":3855},"osf_section_parallax_position_h":{"unit":"%","size":51},"osf_section_parallax_position_v":{"unit":"%","size":80},"_id":"810a9ee"}]},"elements":[{"id":"b56779c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"55","right":"110","bottom":"55","left":"110","isLinked":false},"padding_tablet":{"unit":"px","top":"50","right":"30","bottom":"50","left":"30","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false}},"elements":[{"id":"c3797a6","elType":"widget","settings":{"title":"WHAT our members SAY","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","sub_title":"TESTIMONIALS","align":"left","typography_font_size_tablet":{"unit":"px","size":40,"sizes":[]},"sub_title_color":"#000000","sub_title_spacing":{"unit":"px","size":15,"sizes":[]},"show_decor":"yes","_animation":"opal-move-up","animation_duration":"fast","subtitle_typography_typography":"custom","subtitle_typography_letter_spacing":{"unit":"px","size":3.600000000000000088817841970012523233890533447265625,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"subtitle_typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"8ba3b1b","elType":"widget","settings":{"testimonials":[{"testimonial_content":"\u201cWe met some really great people that you wouldn\u2019t necessarily expect to meet in your normal day-to-day living. It gave me a really great insight into the diverse ways Americans think.\u201d","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team7.jpg","id":3957},"testimonial_name":"Alex Bold","testimonial_job":"member","due_date":"","_id":"e5c390b"},{"testimonial_content":"\"Definitely worth the investment. Nice work on your motorcyle club. Nice work on your motorcyle club. I could probably go into sales for you.\"","testimonial_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/lexrider_team6.jpg","id":3956},"testimonial_name":"John Doe","testimonial_job":"member","due_date":"","_id":"3587f8f"}],"testimonial_image_size":"custom","testimonial_image_custom_dimension":{"width":"60","height":"60"},"testimonial_alignment":"left","wrapper_bgcolor":"#ffffff","wrapper_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"wrapper_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_content_color":"#000000","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":24,"sizes":[]},"content_typography_font_style":"italic","content_typography_line_height":{"unit":"em","size":1.6699999999999999289457264239899814128875732421875,"sizes":[]},"enable_carousel":"yes","navigation":"arrows","_animation":"opal-move-up","animation_duration":"fast","content_typography_font_size_mobile":{"unit":"px","size":18,"sizes":[]},"content_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"name_typography_typography":"custom","name_typography_text_transform":"uppercase","job_typography_typography":"custom","job_typography_text_transform":"uppercase"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"ce6d2f7","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2019\/04\/h3_bg3.jpg","id":3996},"section_parallax_on":"yes","background_overlay_background":"gradient","background_overlay_color":"#1a1a1a","background_overlay_color_stop":{"unit":"%","size":6,"sizes":[]},"background_overlay_color_b":"rgba(26,26,26,0.52)","background_overlay_opacity":{"unit":"px","size":1,"sizes":[]},"padding":{"unit":"px","top":"200","right":"30","bottom":"160","left":"30","isLinked":false},"structure":"20","background_position_tablet":"center right","background_size_tablet":"initial","background_size_mobile":"cover","background_bg_width_tablet":{"unit":"%","size":150,"sizes":[]},"padding_tablet":{"unit":"px","top":"150","right":"30","bottom":"110","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"150","right":"15","bottom":"110","left":"15","isLinked":false},"osf_section_parallax_layer":[]},"elements":[{"id":"19c830e","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"_inline_size":null,"_inline_size_tablet":100},"elements":[{"id":"5c7552a","elType":"widget","settings":{"title":"join the club","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":80,"sizes":[]},"typography_text_transform":"uppercase","_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"align_mobile":"center","typography_font_size_tablet":{"unit":"px","size":50,"sizes":[]},"typography_font_size_mobile":{"unit":"px","size":35,"sizes":[]},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"e261b76","elType":"widget","settings":{"editor":"<p>187 members and the family keeps growing!<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":20,"sizes":[]},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"align_mobile":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"b93feac","elType":"widget","settings":{"width_input":{"unit":"%","size":70,"sizes":[]},"width_input_mobile":{"unit":"%","size":100,"sizes":[]},"width_button":{"unit":"%","size":30,"sizes":[]},"width_button_mobile":{"unit":"%","size":100,"sizes":[]},"input_bacground":"#f0f0f0","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":false},{"id":"a86030d","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"_inline_size":null,"_inline_size_tablet":100},"elements":[],"isInner":false}],"isInner":false},{"id":"149dd7b","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50","animation":"opal-move-up","animation_duration":"fast","osf_section_parallax_layer":[]},"elements":[{"id":"6effa4b","elType":"column","settings":{"_column_size":100},"elements":[{"id":"ac0631a","elType":"widget","settings":{"thumbnail_size":"full","carousel":[{"id":6555,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-9.jpg"},{"id":6554,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-8.jpg"},{"id":6551,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-5.jpg"},{"id":6549,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-3.jpg"},{"id":6548,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-2.jpg"},{"id":6550,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-4.jpg"},{"id":6552,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-6.jpg"},{"id":6553,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-7.jpg"},{"id":6547,"url":"https:\/\/demo2wpopal.b-cdn.net\/lexrider\/wp-content\/uploads\/2021\/03\/gallery-1.jpg"}],"slides_to_show":"6","navigation":"none","_margin":{"unit":"px","top":"0","right":"0","bottom":"-9","left":"0","isLinked":false},"slides_to_show_tablet":"4","slides_to_show_mobile":"2"},"elements":[],"widgetType":"image-carousel"}],"isInner":false}],"isInner":false}]}', true);
    }
}

return new OSF_Import();
